UsagePattern

Struct UsagePattern 

pub struct UsagePattern(/* private fields */);
This enum defines the usage pattern of a QOpenGLBuffer object.

C++ enum: QOpenGLBuffer::UsagePattern.

C++ documentation:

This enum defines the usage pattern of a QOpenGLBuffer object.

Implementations

Source

impl UsagePattern

pub fn to_int(&self) -> c_int

Source

impl UsagePattern

pub const StreamDraw: UsagePattern

The data will be set once and used a few times for drawing operations. Under OpenGL/ES 1.1 this is identical to StaticDraw. (C++ enum variant: StreamDraw = 35040)

pub const StreamRead: UsagePattern

The data will be set once and used a few times for reading data back from the OpenGL server. Not supported under OpenGL/ES. (C++ enum variant: StreamRead = 35041)

pub const StreamCopy: UsagePattern

The data will be set once and used a few times for reading data back from the OpenGL server for use in further drawing operations. Not supported under OpenGL/ES. (C++ enum variant: StreamCopy = 35042)

pub const StaticDraw: UsagePattern

The data will be set once and used many times for drawing operations. (C++ enum variant: StaticDraw = 35044)

pub const StaticRead: UsagePattern

The data will be set once and used many times for reading data back from the OpenGL server. Not supported under OpenGL/ES. (C++ enum variant: StaticRead = 35045)

pub const StaticCopy: UsagePattern

The data will be set once and used many times for reading data back from the OpenGL server for use in further drawing operations. Not supported under OpenGL/ES. (C++ enum variant: StaticCopy = 35046)

pub const DynamicDraw: UsagePattern

The data will be modified repeatedly and used many times for drawing operations. (C++ enum variant: DynamicDraw = 35048)

pub const DynamicRead: UsagePattern

The data will be modified repeatedly and used many times for reading data back from the OpenGL server. Not supported under OpenGL/ES. (C++ enum variant: DynamicRead = 35049)

pub const DynamicCopy: UsagePattern

The data will be modified repeatedly and used many times for reading data back from the OpenGL server for use in further drawing operations. Not supported under OpenGL/ES. (C++ enum variant: DynamicCopy = 35050)