QColor

Struct QColor 

pub struct QColor { /* private fields */ }
C++ class: QColor.

Implementations

Source

impl QColor

pub unsafe fn alpha(&self) -> c_int

Calls C++ function: int QColor::alpha() const.

pub unsafe fn alpha_f(&self) -> c_double

Calls C++ function: double QColor::alphaF() const.

pub unsafe fn black(&self) -> c_int

Calls C++ function: int QColor::black() const.

pub unsafe fn black_f(&self) -> c_double

Calls C++ function: double QColor::blackF() const.

pub unsafe fn blue(&self) -> c_int

Calls C++ function: int QColor::blue() const.

pub unsafe fn blue_f(&self) -> c_double

Calls C++ function: double QColor::blueF() const.

pub unsafe fn color_names() -> CppBox<QStringList>

Calls C++ function: static QStringList QColor::colorNames().

pub unsafe fn convert_to(&self, color_spec: Spec) -> CppBox<QColor>

Calls C++ function: QColor QColor::convertTo(QColor::Spec colorSpec) const.

pub unsafe fn copy_from_q_color( &self, arg1: impl CastInto<Ref<QColor>>, ) -> Ref<QColor>

Calls C++ function: QColor& QColor::operator=(const QColor& arg1).

pub unsafe fn copy_from_global_color(&self, color: GlobalColor) -> Ref<QColor>

Calls C++ function: QColor& QColor::operator=(Qt::GlobalColor color).

pub unsafe fn cyan(&self) -> c_int

Calls C++ function: int QColor::cyan() const.

pub unsafe fn cyan_f(&self) -> c_double

Calls C++ function: double QColor::cyanF() const.

pub unsafe fn dark_1a(&self, f: c_int) -> CppBox<QColor>

Calls C++ function: QColor QColor::dark(int f = …) const.

pub unsafe fn dark_0a(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::dark() const.

pub unsafe fn darker_1a(&self, f: c_int) -> CppBox<QColor>

Calls C++ function: QColor QColor::darker(int f = …) const.

pub unsafe fn darker_0a(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::darker() const.

pub unsafe fn from_cmyk_5a( c: c_int, m: c_int, y: c_int, k: c_int, a: c_int, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromCmyk(int c, int m, int y, int k, int a = …).

pub unsafe fn from_cmyk_4a( c: c_int, m: c_int, y: c_int, k: c_int, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromCmyk(int c, int m, int y, int k).

pub unsafe fn from_cmyk_f_5a( c: c_double, m: c_double, y: c_double, k: c_double, a: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromCmykF(double c, double m, double y, double k, double a = …).

pub unsafe fn from_cmyk_f_4a( c: c_double, m: c_double, y: c_double, k: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromCmykF(double c, double m, double y, double k).

pub unsafe fn from_hsl_4a( h: c_int, s: c_int, l: c_int, a: c_int, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHsl(int h, int s, int l, int a = …).

pub unsafe fn from_hsl_3a(h: c_int, s: c_int, l: c_int) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHsl(int h, int s, int l).

pub unsafe fn from_hsl_f_4a( h: c_double, s: c_double, l: c_double, a: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHslF(double h, double s, double l, double a = …).

pub unsafe fn from_hsl_f_3a( h: c_double, s: c_double, l: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHslF(double h, double s, double l).

pub unsafe fn from_hsv_4a( h: c_int, s: c_int, v: c_int, a: c_int, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHsv(int h, int s, int v, int a = …).

pub unsafe fn from_hsv_3a(h: c_int, s: c_int, v: c_int) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHsv(int h, int s, int v).

pub unsafe fn from_hsv_f_4a( h: c_double, s: c_double, v: c_double, a: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHsvF(double h, double s, double v, double a = …).

pub unsafe fn from_hsv_f_3a( h: c_double, s: c_double, v: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromHsvF(double h, double s, double v).

pub unsafe fn from_rgb_1a(rgb: c_uint) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgb(unsigned int rgb).

pub unsafe fn from_rgb_4a( r: c_int, g: c_int, b: c_int, a: c_int, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgb(int r, int g, int b, int a = …).

pub unsafe fn from_rgb_3a(r: c_int, g: c_int, b: c_int) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgb(int r, int g, int b).

pub unsafe fn from_rgb_f_4a( r: c_double, g: c_double, b: c_double, a: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgbF(double r, double g, double b, double a = …).

pub unsafe fn from_rgb_f_3a( r: c_double, g: c_double, b: c_double, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgbF(double r, double g, double b).

pub unsafe fn from_rgba(rgba: c_uint) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgba(unsigned int rgba).

pub unsafe fn from_rgba64_4a( r: c_ushort, g: c_ushort, b: c_ushort, a: c_ushort, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgba64(unsigned short r, unsigned short g, unsigned short b, unsigned short a = …).

pub unsafe fn from_rgba64_1a( rgba: impl CastInto<Ref<QRgba64>>, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgba64(QRgba64 rgba).

pub unsafe fn from_rgba64_3a( r: c_ushort, g: c_ushort, b: c_ushort, ) -> CppBox<QColor>

Calls C++ function: static QColor QColor::fromRgba64(unsigned short r, unsigned short g, unsigned short b).

pub unsafe fn get_cmyk_5a_mut( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, a: *mut c_int, )

Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k, int* a = …).

pub unsafe fn get_cmyk_5a( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, a: *mut c_int, )

Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k, int* a = …) const.

pub unsafe fn get_cmyk_4a_mut( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, )

Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k).

pub unsafe fn get_cmyk_4a( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, )

Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k) const.

pub unsafe fn get_cmyk_f_5a_mut( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, a: *mut c_double, )

Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k, double* a = …).

pub unsafe fn get_cmyk_f_5a( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, a: *mut c_double, )

Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k, double* a = …) const.

pub unsafe fn get_cmyk_f_4a_mut( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, )

Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k).

pub unsafe fn get_cmyk_f_4a( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, )

Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k) const.

pub unsafe fn get_hsl_4a( &self, h: *mut c_int, s: *mut c_int, l: *mut c_int, a: *mut c_int, )

Calls C++ function: void QColor::getHsl(int* h, int* s, int* l, int* a = …) const.

pub unsafe fn get_hsl_3a(&self, h: *mut c_int, s: *mut c_int, l: *mut c_int)

Calls C++ function: void QColor::getHsl(int* h, int* s, int* l) const.

pub unsafe fn get_hsl_f_4a( &self, h: *mut c_double, s: *mut c_double, l: *mut c_double, a: *mut c_double, )

Calls C++ function: void QColor::getHslF(double* h, double* s, double* l, double* a = …) const.

pub unsafe fn get_hsl_f_3a( &self, h: *mut c_double, s: *mut c_double, l: *mut c_double, )

Calls C++ function: void QColor::getHslF(double* h, double* s, double* l) const.

pub unsafe fn get_hsv_4a( &self, h: *mut c_int, s: *mut c_int, v: *mut c_int, a: *mut c_int, )

Calls C++ function: void QColor::getHsv(int* h, int* s, int* v, int* a = …) const.

pub unsafe fn get_hsv_3a(&self, h: *mut c_int, s: *mut c_int, v: *mut c_int)

Calls C++ function: void QColor::getHsv(int* h, int* s, int* v) const.

pub unsafe fn get_hsv_f_4a( &self, h: *mut c_double, s: *mut c_double, v: *mut c_double, a: *mut c_double, )

Calls C++ function: void QColor::getHsvF(double* h, double* s, double* v, double* a = …) const.

pub unsafe fn get_hsv_f_3a( &self, h: *mut c_double, s: *mut c_double, v: *mut c_double, )

Calls C++ function: void QColor::getHsvF(double* h, double* s, double* v) const.

pub unsafe fn get_rgb_4a( &self, r: *mut c_int, g: *mut c_int, b: *mut c_int, a: *mut c_int, )

Calls C++ function: void QColor::getRgb(int* r, int* g, int* b, int* a = …) const.

pub unsafe fn get_rgb_3a(&self, r: *mut c_int, g: *mut c_int, b: *mut c_int)

Calls C++ function: void QColor::getRgb(int* r, int* g, int* b) const.

pub unsafe fn get_rgb_f_4a( &self, r: *mut c_double, g: *mut c_double, b: *mut c_double, a: *mut c_double, )

Calls C++ function: void QColor::getRgbF(double* r, double* g, double* b, double* a = …) const.

pub unsafe fn get_rgb_f_3a( &self, r: *mut c_double, g: *mut c_double, b: *mut c_double, )

Calls C++ function: void QColor::getRgbF(double* r, double* g, double* b) const.

pub unsafe fn green(&self) -> c_int

Calls C++ function: int QColor::green() const.

pub unsafe fn green_f(&self) -> c_double

Calls C++ function: double QColor::greenF() const.

pub unsafe fn hsl_hue(&self) -> c_int

Calls C++ function: int QColor::hslHue() const.

pub unsafe fn hsl_hue_f(&self) -> c_double

Calls C++ function: double QColor::hslHueF() const.

pub unsafe fn hsl_saturation(&self) -> c_int

Calls C++ function: int QColor::hslSaturation() const.

pub unsafe fn hsl_saturation_f(&self) -> c_double

Calls C++ function: double QColor::hslSaturationF() const.

pub unsafe fn hsv_hue(&self) -> c_int

Calls C++ function: int QColor::hsvHue() const.

pub unsafe fn hsv_hue_f(&self) -> c_double

Calls C++ function: double QColor::hsvHueF() const.

pub unsafe fn hsv_saturation(&self) -> c_int

Calls C++ function: int QColor::hsvSaturation() const.

pub unsafe fn hsv_saturation_f(&self) -> c_double

Calls C++ function: double QColor::hsvSaturationF() const.

pub unsafe fn hue(&self) -> c_int

Calls C++ function: int QColor::hue() const.

pub unsafe fn hue_f(&self) -> c_double

Calls C++ function: double QColor::hueF() const.

pub unsafe fn is_valid(&self) -> bool

Calls C++ function: bool QColor::isValid() const.

pub unsafe fn is_valid_color_q_string(name: impl CastInto<Ref<QString>>) -> bool

Calls C++ function: static bool QColor::isValidColor(const QString& name).

pub unsafe fn is_valid_color_q_string_view( arg1: impl CastInto<Ref<QStringView>>, ) -> bool

Calls C++ function: static bool QColor::isValidColor(QStringView arg1).

pub unsafe fn is_valid_color_q_latin1_string( arg1: impl CastInto<Ref<QLatin1String>>, ) -> bool

Calls C++ function: static bool QColor::isValidColor(QLatin1String arg1).

pub unsafe fn light_1a(&self, f: c_int) -> CppBox<QColor>

Calls C++ function: QColor QColor::light(int f = …) const.

pub unsafe fn light_0a(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::light() const.

pub unsafe fn lighter_1a(&self, f: c_int) -> CppBox<QColor>

Calls C++ function: QColor QColor::lighter(int f = …) const.

pub unsafe fn lighter_0a(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::lighter() const.

pub unsafe fn lightness(&self) -> c_int

Calls C++ function: int QColor::lightness() const.

pub unsafe fn lightness_f(&self) -> c_double

Calls C++ function: double QColor::lightnessF() const.

pub unsafe fn magenta(&self) -> c_int

Calls C++ function: int QColor::magenta() const.

pub unsafe fn magenta_f(&self) -> c_double

Calls C++ function: double QColor::magentaF() const.

pub unsafe fn name_0a(&self) -> CppBox<QString>

Calls C++ function: QString QColor::name() const.

pub unsafe fn name_1a(&self, format: NameFormat) -> CppBox<QString>

Calls C++ function: QString QColor::name(QColor::NameFormat format) const.

pub unsafe fn new() -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor().

pub unsafe fn from_global_color(color: GlobalColor) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(Qt::GlobalColor color).

pub unsafe fn from_4_int( r: c_int, g: c_int, b: c_int, a: c_int, ) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(int r, int g, int b, int a = …).

pub unsafe fn from_uint(rgb: c_uint) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(unsigned int rgb).

pub unsafe fn from_q_rgba64( rgba64: impl CastInto<Ref<QRgba64>>, ) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(QRgba64 rgba64).

pub unsafe fn from_q_string(name: impl CastInto<Ref<QString>>) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(const QString& name).

pub unsafe fn from_q_string_view( name: impl CastInto<Ref<QStringView>>, ) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(QStringView name).

pub unsafe fn from_char(aname: *const c_char) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(const char* aname).

pub unsafe fn from_q_latin1_string( name: impl CastInto<Ref<QLatin1String>>, ) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(QLatin1String name).

pub unsafe fn from_spec(spec: Spec) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(QColor::Spec spec).

pub unsafe fn from_spec5_ushort( spec: Spec, a1: c_ushort, a2: c_ushort, a3: c_ushort, a4: c_ushort, a5: c_ushort, ) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(QColor::Spec spec, unsigned short a1, unsigned short a2, unsigned short a3, unsigned short a4, unsigned short a5 = …).

pub unsafe fn from_3_int(r: c_int, g: c_int, b: c_int) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(int r, int g, int b).

pub unsafe fn from_spec4_ushort( spec: Spec, a1: c_ushort, a2: c_ushort, a3: c_ushort, a4: c_ushort, ) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(QColor::Spec spec, unsigned short a1, unsigned short a2, unsigned short a3, unsigned short a4).

pub unsafe fn new_copy(color: impl CastInto<Ref<QColor>>) -> CppBox<QColor>

Calls C++ function: [constructor] void QColor::QColor(const QColor& color).

pub unsafe fn red(&self) -> c_int

Calls C++ function: int QColor::red() const.

pub unsafe fn red_f(&self) -> c_double

Calls C++ function: double QColor::redF() const.

pub unsafe fn rgb(&self) -> c_uint

Calls C++ function: unsigned int QColor::rgb() const.

pub unsafe fn rgba(&self) -> c_uint

Calls C++ function: unsigned int QColor::rgba() const.

pub unsafe fn rgba64(&self) -> CppBox<QRgba64>

Calls C++ function: QRgba64 QColor::rgba64() const.

pub unsafe fn saturation(&self) -> c_int

Calls C++ function: int QColor::saturation() const.

pub unsafe fn saturation_f(&self) -> c_double

Calls C++ function: double QColor::saturationF() const.

pub unsafe fn set_alpha(&self, alpha: c_int)

Calls C++ function: void QColor::setAlpha(int alpha).

pub unsafe fn set_alpha_f(&self, alpha: c_double)

Calls C++ function: void QColor::setAlphaF(double alpha).

pub unsafe fn set_blue(&self, blue: c_int)

Calls C++ function: void QColor::setBlue(int blue).

pub unsafe fn set_blue_f(&self, blue: c_double)

Calls C++ function: void QColor::setBlueF(double blue).

pub unsafe fn set_cmyk_5a( &self, c: c_int, m: c_int, y: c_int, k: c_int, a: c_int, )

Calls C++ function: void QColor::setCmyk(int c, int m, int y, int k, int a = …).

pub unsafe fn set_cmyk_4a(&self, c: c_int, m: c_int, y: c_int, k: c_int)

Calls C++ function: void QColor::setCmyk(int c, int m, int y, int k).

pub unsafe fn set_cmyk_f_5a( &self, c: c_double, m: c_double, y: c_double, k: c_double, a: c_double, )

Calls C++ function: void QColor::setCmykF(double c, double m, double y, double k, double a = …).

pub unsafe fn set_cmyk_f_4a( &self, c: c_double, m: c_double, y: c_double, k: c_double, )

Calls C++ function: void QColor::setCmykF(double c, double m, double y, double k).

pub unsafe fn set_green(&self, green: c_int)

Calls C++ function: void QColor::setGreen(int green).

pub unsafe fn set_green_f(&self, green: c_double)

Calls C++ function: void QColor::setGreenF(double green).

pub unsafe fn set_hsl_4a(&self, h: c_int, s: c_int, l: c_int, a: c_int)

Calls C++ function: void QColor::setHsl(int h, int s, int l, int a = …).

pub unsafe fn set_hsl_3a(&self, h: c_int, s: c_int, l: c_int)

Calls C++ function: void QColor::setHsl(int h, int s, int l).

pub unsafe fn set_hsl_f_4a( &self, h: c_double, s: c_double, l: c_double, a: c_double, )

Calls C++ function: void QColor::setHslF(double h, double s, double l, double a = …).

pub unsafe fn set_hsl_f_3a(&self, h: c_double, s: c_double, l: c_double)

Calls C++ function: void QColor::setHslF(double h, double s, double l).

pub unsafe fn set_hsv_4a(&self, h: c_int, s: c_int, v: c_int, a: c_int)

Calls C++ function: void QColor::setHsv(int h, int s, int v, int a = …).

pub unsafe fn set_hsv_3a(&self, h: c_int, s: c_int, v: c_int)

Calls C++ function: void QColor::setHsv(int h, int s, int v).

pub unsafe fn set_hsv_f_4a( &self, h: c_double, s: c_double, v: c_double, a: c_double, )

Calls C++ function: void QColor::setHsvF(double h, double s, double v, double a = …).

pub unsafe fn set_hsv_f_3a(&self, h: c_double, s: c_double, v: c_double)

Calls C++ function: void QColor::setHsvF(double h, double s, double v).

pub unsafe fn set_named_color_q_string(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QColor::setNamedColor(const QString& name).

pub unsafe fn set_named_color_q_string_view( &self, name: impl CastInto<Ref<QStringView>>, )

Calls C++ function: void QColor::setNamedColor(QStringView name).

pub unsafe fn set_named_color_q_latin1_string( &self, name: impl CastInto<Ref<QLatin1String>>, )

Calls C++ function: void QColor::setNamedColor(QLatin1String name).

pub unsafe fn set_red(&self, red: c_int)

Calls C++ function: void QColor::setRed(int red).

pub unsafe fn set_red_f(&self, red: c_double)

Calls C++ function: void QColor::setRedF(double red).

pub unsafe fn set_rgb_4a(&self, r: c_int, g: c_int, b: c_int, a: c_int)

Calls C++ function: void QColor::setRgb(int r, int g, int b, int a = …).

pub unsafe fn set_rgb_1a(&self, rgb: c_uint)

Calls C++ function: void QColor::setRgb(unsigned int rgb).

pub unsafe fn set_rgb_3a(&self, r: c_int, g: c_int, b: c_int)

Calls C++ function: void QColor::setRgb(int r, int g, int b).

pub unsafe fn set_rgb_f_4a( &self, r: c_double, g: c_double, b: c_double, a: c_double, )

Calls C++ function: void QColor::setRgbF(double r, double g, double b, double a = …).

pub unsafe fn set_rgb_f_3a(&self, r: c_double, g: c_double, b: c_double)

Calls C++ function: void QColor::setRgbF(double r, double g, double b).

pub unsafe fn set_rgba(&self, rgba: c_uint)

Calls C++ function: void QColor::setRgba(unsigned int rgba).

pub unsafe fn set_rgba64(&self, rgba: impl CastInto<Ref<QRgba64>>)

Calls C++ function: void QColor::setRgba64(QRgba64 rgba).

pub unsafe fn spec(&self) -> Spec

Calls C++ function: QColor::Spec QColor::spec() const.

pub unsafe fn to_cmyk(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::toCmyk() const.

pub unsafe fn to_extended_rgb(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::toExtendedRgb() const.

pub unsafe fn to_hsl(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::toHsl() const.

pub unsafe fn to_hsv(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::toHsv() const.

pub unsafe fn to_q_variant(&self) -> CppBox<QVariant>

Calls C++ function: QVariant QColor::operator QVariant() const.

pub unsafe fn to_rgb(&self) -> CppBox<QColor>

Calls C++ function: QColor QColor::toRgb() const.

pub unsafe fn value(&self) -> c_int

Calls C++ function: int QColor::value() const.

pub unsafe fn value_f(&self) -> c_double

Calls C++ function: double QColor::valueF() const.

pub unsafe fn yellow(&self) -> c_int

Calls C++ function: int QColor::yellow() const.

pub unsafe fn yellow_f(&self) -> c_double

Calls C++ function: double QColor::yellowF() const.