QInputMethod

Struct QInputMethod 

pub struct QInputMethod { /* private fields */ }
C++ class: QInputMethod.

Implementations

Source

impl QInputMethod

pub fn slot_show(&self) -> Receiver<()>

Returns a built-in Qt slot QInputMethod::show that can be passed to qt_core::Signal::connect.

pub fn slot_hide(&self) -> Receiver<()>

Returns a built-in Qt slot QInputMethod::hide that can be passed to qt_core::Signal::connect.

pub fn slot_update(&self) -> Receiver<(c_int,)>

Returns a built-in Qt slot QInputMethod::update that can be passed to qt_core::Signal::connect.

pub fn slot_reset(&self) -> Receiver<()>

Returns a built-in Qt slot QInputMethod::reset that can be passed to qt_core::Signal::connect.

pub fn slot_commit(&self) -> Receiver<()>

Returns a built-in Qt slot QInputMethod::commit that can be passed to qt_core::Signal::connect.

pub fn slot_invoke_action(&self) -> Receiver<(Action, c_int)>

Returns a built-in Qt slot QInputMethod::invokeAction that can be passed to qt_core::Signal::connect.

pub fn cursor_rectangle_changed(&self) -> Signal<()>

Returns a built-in Qt signal QInputMethod::cursorRectangleChanged that can be passed to qt_core::Signal::connect.

pub fn anchor_rectangle_changed(&self) -> Signal<()>

Returns a built-in Qt signal QInputMethod::anchorRectangleChanged that can be passed to qt_core::Signal::connect.

pub fn keyboard_rectangle_changed(&self) -> Signal<()>

Returns a built-in Qt signal QInputMethod::keyboardRectangleChanged that can be passed to qt_core::Signal::connect.

pub fn input_item_clip_rectangle_changed(&self) -> Signal<()>

Returns a built-in Qt signal QInputMethod::inputItemClipRectangleChanged that can be passed to qt_core::Signal::connect.

pub fn visible_changed(&self) -> Signal<()>

Returns a built-in Qt signal QInputMethod::visibleChanged that can be passed to qt_core::Signal::connect.

pub fn animating_changed(&self) -> Signal<()>

Returns a built-in Qt signal QInputMethod::animatingChanged that can be passed to qt_core::Signal::connect.

pub fn locale_changed(&self) -> Signal<()>

Returns a built-in Qt signal QInputMethod::localeChanged that can be passed to qt_core::Signal::connect.

pub fn input_direction_changed(&self) -> Signal<(LayoutDirection,)>

Returns a built-in Qt signal QInputMethod::inputDirectionChanged that can be passed to qt_core::Signal::connect.

pub unsafe fn anchor_rectangle(&self) -> CppBox<QRectF>

Calls C++ function: QRectF QInputMethod::anchorRectangle() const.

pub unsafe fn commit(&self)

Calls C++ function: [slot] void QInputMethod::commit().

pub unsafe fn cursor_rectangle(&self) -> CppBox<QRectF>

Calls C++ function: QRectF QInputMethod::cursorRectangle() const.

pub unsafe fn hide(&self)

Calls C++ function: [slot] void QInputMethod::hide().

pub unsafe fn input_direction(&self) -> LayoutDirection

Calls C++ function: Qt::LayoutDirection QInputMethod::inputDirection() const.

pub unsafe fn input_item_clip_rectangle(&self) -> CppBox<QRectF>

Calls C++ function: QRectF QInputMethod::inputItemClipRectangle() const.

pub unsafe fn input_item_rectangle(&self) -> CppBox<QRectF>

Calls C++ function: QRectF QInputMethod::inputItemRectangle() const.

pub unsafe fn input_item_transform(&self) -> CppBox<QTransform>

Calls C++ function: QTransform QInputMethod::inputItemTransform() const.

pub unsafe fn invoke_action(&self, a: Action, cursor_position: c_int)

Calls C++ function: [slot] void QInputMethod::invokeAction(QInputMethod::Action a, int cursorPosition).

pub unsafe fn is_animating(&self) -> bool

Calls C++ function: bool QInputMethod::isAnimating() const.

pub unsafe fn is_visible(&self) -> bool

Calls C++ function: bool QInputMethod::isVisible() const.

pub unsafe fn keyboard_rectangle(&self) -> CppBox<QRectF>

Calls C++ function: QRectF QInputMethod::keyboardRectangle() const.

pub unsafe fn locale(&self) -> CppBox<QLocale>

Calls C++ function: QLocale QInputMethod::locale() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QInputMethod::metaObject() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QInputMethod::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QInputMethod::qt_metacast(const char* arg1).

pub unsafe fn query_focus_object( query: InputMethodQuery, argument: impl CastInto<Ref<QVariant>>, ) -> CppBox<QVariant>

Calls C++ function: static QVariant QInputMethod::queryFocusObject(Qt::InputMethodQuery query, QVariant argument).

pub unsafe fn reset(&self)

Calls C++ function: [slot] void QInputMethod::reset().

pub unsafe fn set_input_item_rectangle(&self, rect: impl CastInto<Ref<QRectF>>)

Calls C++ function: void QInputMethod::setInputItemRectangle(const QRectF& rect).

pub unsafe fn set_input_item_transform( &self, transform: impl CastInto<Ref<QTransform>>, )

Calls C++ function: void QInputMethod::setInputItemTransform(const QTransform& transform).

pub unsafe fn set_visible(&self, visible: bool)

Calls C++ function: void QInputMethod::setVisible(bool visible).

pub unsafe fn show(&self)

Calls C++ function: [slot] void QInputMethod::show().

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QInputMethod::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QInputMethod::trUtf8(const char* s, const char* c, int n).

pub unsafe fn update(&self, queries: QFlags<InputMethodQuery>)

Calls C++ function: [slot] void QInputMethod::update(QFlags<Qt::InputMethodQuery> queries).

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const i8) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: i32)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: i32) -> i32

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.