QMatrix4X4

Struct QMatrix4X4 

pub struct QMatrix4X4 { /* private fields */ }
C++ class: QMatrix4x4.

Implementations

Source

impl QMatrix4X4

pub unsafe fn add_assign( &self, other: impl CastInto<Ref<QMatrix4X4>>, ) -> Ref<QMatrix4X4>

Calls C++ function: QMatrix4x4& QMatrix4x4::operator+=(const QMatrix4x4& other).

pub unsafe fn call(&self, row: c_int, column: c_int) -> *const c_float

Calls C++ function: const float& QMatrix4x4::operator()(int row, int column) const.

pub unsafe fn call_mut(&self, row: c_int, column: c_int) -> *mut c_float

Calls C++ function: float& QMatrix4x4::operator()(int row, int column).

pub unsafe fn column(&self, index: c_int) -> CppBox<QVector4D>

Calls C++ function: QVector4D QMatrix4x4::column(int index) const.

pub unsafe fn const_data(&self) -> *const c_float

Calls C++ function: const float* QMatrix4x4::constData() const.

pub unsafe fn copy_data_to(&self, values: *mut c_float)

Calls C++ function: void QMatrix4x4::copyDataTo(float* values) const.

pub unsafe fn copy_from( &self, other: impl CastInto<Ref<QMatrix4X4>>, ) -> Ref<QMatrix4X4>

Calls C++ function: QMatrix4x4& QMatrix4x4::operator=(const QMatrix4x4& other).

pub unsafe fn data_mut(&self) -> *mut c_float

Calls C++ function: float* QMatrix4x4::data().

pub unsafe fn data(&self) -> *const c_float

Calls C++ function: const float* QMatrix4x4::data() const.

pub unsafe fn determinant(&self) -> c_double

Calls C++ function: double QMatrix4x4::determinant() const.

pub unsafe fn div_assign(&self, divisor: c_float) -> Ref<QMatrix4X4>

Calls C++ function: QMatrix4x4& QMatrix4x4::operator/=(float divisor).

pub unsafe fn fill(&self, value: c_float)

Calls C++ function: void QMatrix4x4::fill(float value).

pub unsafe fn flip_coordinates(&self)

Calls C++ function: void QMatrix4x4::flipCoordinates().

pub unsafe fn frustum( &self, left: c_float, right: c_float, bottom: c_float, top: c_float, near_plane: c_float, far_plane: c_float, )

Calls C++ function: void QMatrix4x4::frustum(float left, float right, float bottom, float top, float nearPlane, float farPlane).

pub unsafe fn inverted_1a(&self, invertible: *mut bool) -> CppBox<QMatrix4X4>

Calls C++ function: QMatrix4x4 QMatrix4x4::inverted(bool* invertible = …) const.

pub unsafe fn inverted_0a(&self) -> CppBox<QMatrix4X4>

Calls C++ function: QMatrix4x4 QMatrix4x4::inverted() const.

pub unsafe fn is_affine(&self) -> bool

Calls C++ function: bool QMatrix4x4::isAffine() const.

pub unsafe fn is_identity(&self) -> bool

Calls C++ function: bool QMatrix4x4::isIdentity() const.

pub unsafe fn look_at( &self, eye: impl CastInto<Ref<QVector3D>>, center: impl CastInto<Ref<QVector3D>>, up: impl CastInto<Ref<QVector3D>>, )

Calls C++ function: void QMatrix4x4::lookAt(const QVector3D& eye, const QVector3D& center, const QVector3D& up).

pub unsafe fn map_q_point( &self, point: impl CastInto<Ref<QPoint>>, ) -> CppBox<QPoint>

Calls C++ function: QPoint QMatrix4x4::map(const QPoint& point) const.

pub unsafe fn map_q_point_f( &self, point: impl CastInto<Ref<QPointF>>, ) -> CppBox<QPointF>

Calls C++ function: QPointF QMatrix4x4::map(const QPointF& point) const.

pub unsafe fn map_q_vector_3d( &self, point: impl CastInto<Ref<QVector3D>>, ) -> CppBox<QVector3D>

Calls C++ function: QVector3D QMatrix4x4::map(const QVector3D& point) const.

pub unsafe fn map_q_vector_4d( &self, point: impl CastInto<Ref<QVector4D>>, ) -> CppBox<QVector4D>

Calls C++ function: QVector4D QMatrix4x4::map(const QVector4D& point) const.

pub unsafe fn map_rect_q_rect( &self, rect: impl CastInto<Ref<QRect>>, ) -> CppBox<QRect>

Calls C++ function: QRect QMatrix4x4::mapRect(const QRect& rect) const.

pub unsafe fn map_rect_q_rect_f( &self, rect: impl CastInto<Ref<QRectF>>, ) -> CppBox<QRectF>

Calls C++ function: QRectF QMatrix4x4::mapRect(const QRectF& rect) const.

pub unsafe fn map_vector( &self, vector: impl CastInto<Ref<QVector3D>>, ) -> CppBox<QVector3D>

Calls C++ function: QVector3D QMatrix4x4::mapVector(const QVector3D& vector) const.

pub unsafe fn mul_assign_q_matrix4_x4( &self, other: impl CastInto<Ref<QMatrix4X4>>, ) -> Ref<QMatrix4X4>

Calls C++ function: QMatrix4x4& QMatrix4x4::operator*=(const QMatrix4x4& other).

pub unsafe fn mul_assign_float(&self, factor: c_float) -> Ref<QMatrix4X4>

Calls C++ function: QMatrix4x4& QMatrix4x4::operator*=(float factor).

pub unsafe fn neg(&self) -> CppBox<QMatrix4X4>

Calls C++ function: QMatrix4x4 operator-(const QMatrix4x4& matrix).

pub unsafe fn new() -> CppBox<QMatrix4X4>

Calls C++ function: [constructor] void QMatrix4x4::QMatrix4x4().

pub unsafe fn from_float(values: *const c_float) -> CppBox<QMatrix4X4>

Calls C++ function: [constructor] void QMatrix4x4::QMatrix4x4(const float* values).

pub unsafe fn from_16_float( m11: c_float, m12: c_float, m13: c_float, m14: c_float, m21: c_float, m22: c_float, m23: c_float, m24: c_float, m31: c_float, m32: c_float, m33: c_float, m34: c_float, m41: c_float, m42: c_float, m43: c_float, m44: c_float, ) -> CppBox<QMatrix4X4>

Calls C++ function: [constructor] void QMatrix4x4::QMatrix4x4(float m11, float m12, float m13, float m14, float m21, float m22, float m23, float m24, float m31, float m32, float m33, float m34, float m41, float m42, float m43, float m44).

pub unsafe fn from_float2_int( values: *const c_float, cols: c_int, rows: c_int, ) -> CppBox<QMatrix4X4>

Calls C++ function: [constructor] void QMatrix4x4::QMatrix4x4(const float* values, int cols, int rows).

pub unsafe fn from_q_transform( transform: impl CastInto<Ref<QTransform>>, ) -> CppBox<QMatrix4X4>

Calls C++ function: [constructor] void QMatrix4x4::QMatrix4x4(const QTransform& transform).

pub unsafe fn from_q_matrix( matrix: impl CastInto<Ref<QMatrix>>, ) -> CppBox<QMatrix4X4>

Calls C++ function: [constructor] void QMatrix4x4::QMatrix4x4(const QMatrix& matrix).

pub unsafe fn new_copy( other: impl CastInto<Ref<QMatrix4X4>>, ) -> CppBox<QMatrix4X4>

Calls C++ function: [constructor] void QMatrix4x4::QMatrix4x4(const QMatrix4x4& other).

pub unsafe fn optimize(&self)

Calls C++ function: void QMatrix4x4::optimize().

pub unsafe fn ortho_q_rect(&self, rect: impl CastInto<Ref<QRect>>)

Calls C++ function: void QMatrix4x4::ortho(const QRect& rect).

pub unsafe fn ortho_q_rect_f(&self, rect: impl CastInto<Ref<QRectF>>)

Calls C++ function: void QMatrix4x4::ortho(const QRectF& rect).

pub unsafe fn ortho_6_float( &self, left: c_float, right: c_float, bottom: c_float, top: c_float, near_plane: c_float, far_plane: c_float, )

Calls C++ function: void QMatrix4x4::ortho(float left, float right, float bottom, float top, float nearPlane, float farPlane).

pub unsafe fn perspective( &self, vertical_angle: c_float, aspect_ratio: c_float, near_plane: c_float, far_plane: c_float, )

Calls C++ function: void QMatrix4x4::perspective(float verticalAngle, float aspectRatio, float nearPlane, float farPlane).

pub unsafe fn rotate_2a( &self, angle: c_float, vector: impl CastInto<Ref<QVector3D>>, )

Calls C++ function: void QMatrix4x4::rotate(float angle, const QVector3D& vector).

pub unsafe fn rotate_4a( &self, angle: c_float, x: c_float, y: c_float, z: c_float, )

Calls C++ function: void QMatrix4x4::rotate(float angle, float x, float y, float z = …).

pub unsafe fn rotate_1a(&self, quaternion: impl CastInto<Ref<QQuaternion>>)

Calls C++ function: void QMatrix4x4::rotate(const QQuaternion& quaternion).

pub unsafe fn rotate_3a(&self, angle: c_float, x: c_float, y: c_float)

Calls C++ function: void QMatrix4x4::rotate(float angle, float x, float y).

pub unsafe fn row(&self, index: c_int) -> CppBox<QVector4D>

Calls C++ function: QVector4D QMatrix4x4::row(int index) const.

pub unsafe fn scale_q_vector_3d(&self, vector: impl CastInto<Ref<QVector3D>>)

Calls C++ function: void QMatrix4x4::scale(const QVector3D& vector).

pub unsafe fn scale_2_float(&self, x: c_float, y: c_float)

Calls C++ function: void QMatrix4x4::scale(float x, float y).

pub unsafe fn scale_3_float(&self, x: c_float, y: c_float, z: c_float)

Calls C++ function: void QMatrix4x4::scale(float x, float y, float z).

pub unsafe fn scale_float(&self, factor: c_float)

Calls C++ function: void QMatrix4x4::scale(float factor).

pub unsafe fn set_column( &self, index: c_int, value: impl CastInto<Ref<QVector4D>>, )

Calls C++ function: void QMatrix4x4::setColumn(int index, const QVector4D& value).

pub unsafe fn set_row(&self, index: c_int, value: impl CastInto<Ref<QVector4D>>)

Calls C++ function: void QMatrix4x4::setRow(int index, const QVector4D& value).

pub unsafe fn set_to_identity(&self)

Calls C++ function: void QMatrix4x4::setToIdentity().

pub unsafe fn sub_assign( &self, other: impl CastInto<Ref<QMatrix4X4>>, ) -> Ref<QMatrix4X4>

Calls C++ function: QMatrix4x4& QMatrix4x4::operator-=(const QMatrix4x4& other).

pub unsafe fn to_affine(&self) -> CppBox<QMatrix>

Calls C++ function: QMatrix QMatrix4x4::toAffine() const.

pub unsafe fn to_q_variant(&self) -> CppBox<QVariant>

Calls C++ function: QVariant QMatrix4x4::operator QVariant() const.

pub unsafe fn to_transform_0a(&self) -> CppBox<QTransform>

Calls C++ function: QTransform QMatrix4x4::toTransform() const.

pub unsafe fn to_transform_1a( &self, distance_to_plane: c_float, ) -> CppBox<QTransform>

Calls C++ function: QTransform QMatrix4x4::toTransform(float distanceToPlane) const.

pub unsafe fn translate_1a(&self, vector: impl CastInto<Ref<QVector3D>>)

Calls C++ function: void QMatrix4x4::translate(const QVector3D& vector).

pub unsafe fn translate_2a(&self, x: c_float, y: c_float)

Calls C++ function: void QMatrix4x4::translate(float x, float y).

pub unsafe fn translate_3a(&self, x: c_float, y: c_float, z: c_float)

Calls C++ function: void QMatrix4x4::translate(float x, float y, float z).

pub unsafe fn transposed(&self) -> CppBox<QMatrix4X4>

Calls C++ function: QMatrix4x4 QMatrix4x4::transposed() const.

pub unsafe fn viewport_1a(&self, rect: impl CastInto<Ref<QRectF>>)

Calls C++ function: void QMatrix4x4::viewport(const QRectF& rect).

pub unsafe fn viewport_6a( &self, left: c_float, bottom: c_float, width: c_float, height: c_float, near_plane: c_float, far_plane: c_float, )

Calls C++ function: void QMatrix4x4::viewport(float left, float bottom, float width, float height, float nearPlane = …, float farPlane = …).

pub unsafe fn viewport_5a( &self, left: c_float, bottom: c_float, width: c_float, height: c_float, near_plane: c_float, )

Calls C++ function: void QMatrix4x4::viewport(float left, float bottom, float width, float height, float nearPlane = …).

pub unsafe fn viewport_4a( &self, left: c_float, bottom: c_float, width: c_float, height: c_float, )

Calls C++ function: void QMatrix4x4::viewport(float left, float bottom, float width, float height).