QMovie

Struct QMovie 

pub struct QMovie { /* private fields */ }
C++ class: QMovie.

Implementations

Source

impl QMovie

pub fn started(&self) -> Signal<()>

Returns a built-in Qt signal QMovie::started that can be passed to qt_core::Signal::connect.

pub fn resized(&self) -> Signal<(*const QSize,)>

Returns a built-in Qt signal QMovie::resized that can be passed to qt_core::Signal::connect.

pub fn updated(&self) -> Signal<(*const QRect,)>

Returns a built-in Qt signal QMovie::updated that can be passed to qt_core::Signal::connect.

pub fn state_changed(&self) -> Signal<(MovieState,)>

Returns a built-in Qt signal QMovie::stateChanged that can be passed to qt_core::Signal::connect.

pub fn error(&self) -> Signal<(ImageReaderError,)>

Returns a built-in Qt signal QMovie::error that can be passed to qt_core::Signal::connect.

pub fn finished(&self) -> Signal<()>

Returns a built-in Qt signal QMovie::finished that can be passed to qt_core::Signal::connect.

pub fn frame_changed(&self) -> Signal<(c_int,)>

Returns a built-in Qt signal QMovie::frameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_start(&self) -> Receiver<()>

Returns a built-in Qt slot QMovie::start that can be passed to qt_core::Signal::connect.

pub fn slot_jump_to_next_frame(&self) -> Receiver<()>

Returns a built-in Qt slot QMovie::jumpToNextFrame that can be passed to qt_core::Signal::connect.

pub fn slot_set_paused(&self) -> Receiver<(bool,)>

Returns a built-in Qt slot QMovie::setPaused that can be passed to qt_core::Signal::connect.

pub fn slot_stop(&self) -> Receiver<()>

Returns a built-in Qt slot QMovie::stop that can be passed to qt_core::Signal::connect.

pub fn slot_set_speed(&self) -> Receiver<(c_int,)>

Returns a built-in Qt slot QMovie::setSpeed that can be passed to qt_core::Signal::connect.

pub unsafe fn background_color(&self) -> CppBox<QColor>

Calls C++ function: QColor QMovie::backgroundColor() const.

pub unsafe fn cache_mode(&self) -> CacheMode

Calls C++ function: QMovie::CacheMode QMovie::cacheMode() const.

pub unsafe fn current_frame_number(&self) -> c_int

Calls C++ function: int QMovie::currentFrameNumber() const.

pub unsafe fn current_image(&self) -> CppBox<QImage>

Calls C++ function: QImage QMovie::currentImage() const.

pub unsafe fn current_pixmap(&self) -> CppBox<QPixmap>

Calls C++ function: QPixmap QMovie::currentPixmap() const.

pub unsafe fn device(&self) -> QPtr<QIODevice>

Calls C++ function: QIODevice* QMovie::device() const.

pub unsafe fn file_name(&self) -> CppBox<QString>

Calls C++ function: QString QMovie::fileName() const.

pub unsafe fn format(&self) -> CppBox<QByteArray>

Calls C++ function: QByteArray QMovie::format() const.

pub unsafe fn frame_count(&self) -> c_int

Calls C++ function: int QMovie::frameCount() const.

pub unsafe fn frame_rect(&self) -> CppBox<QRect>

Calls C++ function: QRect QMovie::frameRect() const.

pub unsafe fn is_valid(&self) -> bool

Calls C++ function: bool QMovie::isValid() const.

pub unsafe fn jump_to_frame(&self, frame_number: c_int) -> bool

Calls C++ function: bool QMovie::jumpToFrame(int frameNumber).

pub unsafe fn jump_to_next_frame(&self) -> bool

Calls C++ function: [slot] bool QMovie::jumpToNextFrame().

pub unsafe fn last_error(&self) -> ImageReaderError

Calls C++ function: QImageReader::ImageReaderError QMovie::lastError() const.

pub unsafe fn last_error_string(&self) -> CppBox<QString>

Calls C++ function: QString QMovie::lastErrorString() const.

pub unsafe fn loop_count(&self) -> c_int

Calls C++ function: int QMovie::loopCount() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QMovie::metaObject() const.

pub unsafe fn from_q_object(parent: impl CastInto<Ptr<QObject>>) -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie(QObject* parent = …).

pub unsafe fn from_q_io_device_q_byte_array_q_object( device: impl CastInto<Ptr<QIODevice>>, format: impl CastInto<Ref<QByteArray>>, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie(QIODevice* device, const QByteArray& format = …, QObject* parent = …).

pub unsafe fn from_q_string_q_byte_array_q_object( file_name: impl CastInto<Ref<QString>>, format: impl CastInto<Ref<QByteArray>>, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie(const QString& fileName, const QByteArray& format = …, QObject* parent = …).

pub unsafe fn new() -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie().

pub unsafe fn from_q_io_device_q_byte_array( device: impl CastInto<Ptr<QIODevice>>, format: impl CastInto<Ref<QByteArray>>, ) -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie(QIODevice* device, const QByteArray& format = …).

pub unsafe fn from_q_io_device( device: impl CastInto<Ptr<QIODevice>>, ) -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie(QIODevice* device).

pub unsafe fn from_q_string_q_byte_array( file_name: impl CastInto<Ref<QString>>, format: impl CastInto<Ref<QByteArray>>, ) -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie(const QString& fileName, const QByteArray& format = …).

pub unsafe fn from_q_string( file_name: impl CastInto<Ref<QString>>, ) -> QBox<QMovie>

Calls C++ function: [constructor] void QMovie::QMovie(const QString& fileName).

pub unsafe fn next_frame_delay(&self) -> c_int

Calls C++ function: int QMovie::nextFrameDelay() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QMovie::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QMovie::qt_metacast(const char* arg1).

pub unsafe fn scaled_size(&self) -> CppBox<QSize>

Calls C++ function: QSize QMovie::scaledSize().

pub unsafe fn set_background_color(&self, color: impl CastInto<Ref<QColor>>)

Calls C++ function: void QMovie::setBackgroundColor(const QColor& color).

pub unsafe fn set_cache_mode(&self, mode: CacheMode)

Calls C++ function: void QMovie::setCacheMode(QMovie::CacheMode mode).

pub unsafe fn set_device(&self, device: impl CastInto<Ptr<QIODevice>>)

Calls C++ function: void QMovie::setDevice(QIODevice* device).

pub unsafe fn set_file_name(&self, file_name: impl CastInto<Ref<QString>>)

Calls C++ function: void QMovie::setFileName(const QString& fileName).

pub unsafe fn set_format(&self, format: impl CastInto<Ref<QByteArray>>)

Calls C++ function: void QMovie::setFormat(const QByteArray& format).

pub unsafe fn set_paused(&self, paused: bool)

Calls C++ function: [slot] void QMovie::setPaused(bool paused).

pub unsafe fn set_scaled_size(&self, size: impl CastInto<Ref<QSize>>)

Calls C++ function: void QMovie::setScaledSize(const QSize& size).

pub unsafe fn set_speed(&self, percent_speed: c_int)

Calls C++ function: [slot] void QMovie::setSpeed(int percentSpeed).

pub unsafe fn speed(&self) -> c_int

Calls C++ function: int QMovie::speed() const.

pub unsafe fn start(&self)

Calls C++ function: [slot] void QMovie::start().

pub unsafe fn state(&self) -> MovieState

Calls C++ function: QMovie::MovieState QMovie::state() const.

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn stop(&self)

Calls C++ function: [slot] void QMovie::stop().

pub unsafe fn supported_formats() -> CppBox<QListOfQByteArray>

Calls C++ function: static QList<QByteArray> QMovie::supportedFormats().

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QMovie::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QMovie::trUtf8(const char* s, const char* c, int n).

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const i8) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: i32)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: i32) -> i32

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.