QOpenGLContext

Struct QOpenGLContext 

pub struct QOpenGLContext { /* private fields */ }
C++ class: QOpenGLContext.

Implementations

Source

impl QOpenGLContext

pub fn about_to_be_destroyed(&self) -> Signal<()>

Returns a built-in Qt signal QOpenGLContext::aboutToBeDestroyed that can be passed to qt_core::Signal::connect.

pub unsafe fn are_sharing( first: impl CastInto<Ptr<QOpenGLContext>>, second: impl CastInto<Ptr<QOpenGLContext>>, ) -> bool

Calls C++ function: static bool QOpenGLContext::areSharing(QOpenGLContext* first, QOpenGLContext* second).

pub unsafe fn create(&self) -> bool

Calls C++ function: bool QOpenGLContext::create().

pub unsafe fn current_context() -> QPtr<QOpenGLContext>

Calls C++ function: static QOpenGLContext* QOpenGLContext::currentContext().

pub unsafe fn default_framebuffer_object(&self) -> c_uint

Calls C++ function: unsigned int QOpenGLContext::defaultFramebufferObject() const.

pub unsafe fn done_current(&self)

Calls C++ function: void QOpenGLContext::doneCurrent().

pub unsafe fn extensions(&self) -> CppBox<QSetOfQByteArray>

Calls C++ function: QSet<QByteArray> QOpenGLContext::extensions() const.

pub unsafe fn extra_functions(&self) -> Ptr<QOpenGLExtraFunctions>

Calls C++ function: QOpenGLExtraFunctions* QOpenGLContext::extraFunctions() const.

pub unsafe fn format(&self) -> CppBox<QSurfaceFormat>

Calls C++ function: QSurfaceFormat QOpenGLContext::format() const.

pub unsafe fn functions(&self) -> Ptr<QOpenGLFunctions>

Calls C++ function: QOpenGLFunctions* QOpenGLContext::functions() const.

pub unsafe fn get_proc_address_q_byte_array( &self, proc_name: impl CastInto<Ref<QByteArray>>, ) -> Option<extern "C" fn()>

Calls C++ function: void (*FN_PTR)() QOpenGLContext::getProcAddress(const QByteArray& procName) const.

pub unsafe fn get_proc_address_char( &self, proc_name: *const c_char, ) -> Option<extern "C" fn()>

Calls C++ function: void (*FN_PTR)() QOpenGLContext::getProcAddress(const char* procName) const.

pub unsafe fn global_share_context() -> QPtr<QOpenGLContext>

Calls C++ function: static QOpenGLContext* QOpenGLContext::globalShareContext().

pub unsafe fn has_extension( &self, extension: impl CastInto<Ref<QByteArray>>, ) -> bool

Calls C++ function: bool QOpenGLContext::hasExtension(const QByteArray& extension) const.

pub unsafe fn is_opengl_e_s(&self) -> bool

Calls C++ function: bool QOpenGLContext::isOpenGLES() const.

pub unsafe fn is_valid(&self) -> bool

Calls C++ function: bool QOpenGLContext::isValid() const.

pub unsafe fn make_current(&self, surface: impl CastInto<Ptr<QSurface>>) -> bool

Calls C++ function: bool QOpenGLContext::makeCurrent(QSurface* surface).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QOpenGLContext::metaObject() const.

pub unsafe fn native_handle(&self) -> CppBox<QVariant>

Calls C++ function: QVariant QOpenGLContext::nativeHandle() const.

pub unsafe fn new_1a( parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QOpenGLContext>

Calls C++ function: [constructor] void QOpenGLContext::QOpenGLContext(QObject* parent = …).

pub unsafe fn new_0a() -> QBox<QOpenGLContext>

Calls C++ function: [constructor] void QOpenGLContext::QOpenGLContext().

pub unsafe fn opengl_module_handle() -> *mut c_void

Calls C++ function: static void* QOpenGLContext::openGLModuleHandle().

pub unsafe fn opengl_module_type() -> OpenGLModuleType

Calls C++ function: static QOpenGLContext::OpenGLModuleType QOpenGLContext::openGLModuleType().

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QOpenGLContext::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QOpenGLContext::qt_metacast(const char* arg1).

pub unsafe fn screen(&self) -> QPtr<QScreen>

Calls C++ function: QScreen* QOpenGLContext::screen() const.

pub unsafe fn set_format(&self, format: impl CastInto<Ref<QSurfaceFormat>>)

Calls C++ function: void QOpenGLContext::setFormat(const QSurfaceFormat& format).

pub unsafe fn set_native_handle(&self, handle: impl CastInto<Ref<QVariant>>)

Calls C++ function: void QOpenGLContext::setNativeHandle(const QVariant& handle).

pub unsafe fn set_screen(&self, screen: impl CastInto<Ptr<QScreen>>)

Calls C++ function: void QOpenGLContext::setScreen(QScreen* screen).

pub unsafe fn set_share_context( &self, share_context: impl CastInto<Ptr<QOpenGLContext>>, )

Calls C++ function: void QOpenGLContext::setShareContext(QOpenGLContext* shareContext).

pub unsafe fn share_context(&self) -> QPtr<QOpenGLContext>

Calls C++ function: QOpenGLContext* QOpenGLContext::shareContext() const.

pub unsafe fn share_group(&self) -> QPtr<QOpenGLContextGroup>

Calls C++ function: QOpenGLContextGroup* QOpenGLContext::shareGroup() const.

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn supports_threaded_opengl() -> bool

Calls C++ function: static bool QOpenGLContext::supportsThreadedOpenGL().

pub unsafe fn surface(&self) -> Ptr<QSurface>

Calls C++ function: QSurface* QOpenGLContext::surface() const.

pub unsafe fn swap_buffers(&self, surface: impl CastInto<Ptr<QSurface>>)

Calls C++ function: void QOpenGLContext::swapBuffers(QSurface* surface).

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QOpenGLContext::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QOpenGLContext::trUtf8(const char* s, const char* c, int n).

pub unsafe fn version_functions_1a( &self, version_profile: impl CastInto<Ref<QOpenGLVersionProfile>>, ) -> Ptr<QAbstractOpenGLFunctions>

Calls C++ function: QAbstractOpenGLFunctions* QOpenGLContext::versionFunctions(const QOpenGLVersionProfile& versionProfile = …) const.

pub unsafe fn version_functions_0a(&self) -> Ptr<QAbstractOpenGLFunctions>

Calls C++ function: QAbstractOpenGLFunctions* QOpenGLContext::versionFunctions() const.

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const i8) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: i32)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: i32) -> i32

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.