pub struct QOpenGLFramebufferObject { /* private fields */ }Expand description
C++ class: QOpenGLFramebufferObject.
Implementations
Sourceimpl QOpenGLFramebufferObject
impl QOpenGLFramebufferObject
Sourcepub unsafe fn add_color_attachment_q_size_uint(
&self,
size: impl CastInto<Ref<QSize>>,
internal_format: c_uint,
)
pub unsafe fn add_color_attachment_q_size_uint( &self, size: impl CastInto<Ref<QSize>>, internal_format: c_uint, )
Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(const QSize& size, unsigned int internalFormat = …).
Sourcepub unsafe fn add_color_attachment_2_int_uint(
&self,
width: c_int,
height: c_int,
internal_format: c_uint,
)
pub unsafe fn add_color_attachment_2_int_uint( &self, width: c_int, height: c_int, internal_format: c_uint, )
Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(int width, int height, unsigned int internalFormat = …).
Sourcepub unsafe fn add_color_attachment_q_size(
&self,
size: impl CastInto<Ref<QSize>>,
)
pub unsafe fn add_color_attachment_q_size( &self, size: impl CastInto<Ref<QSize>>, )
Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(const QSize& size).
Sourcepub unsafe fn add_color_attachment_2_int(&self, width: c_int, height: c_int)
pub unsafe fn add_color_attachment_2_int(&self, width: c_int, height: c_int)
Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(int width, int height).
Sourcepub unsafe fn attachment(&self) -> Attachment
pub unsafe fn attachment(&self) -> Attachment
Calls C++ function: QOpenGLFramebufferObject::Attachment QOpenGLFramebufferObject::attachment() const.
Sourcepub unsafe fn bind_default() -> bool
pub unsafe fn bind_default() -> bool
Calls C++ function: static bool QOpenGLFramebufferObject::bindDefault().
Sourcepub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint2_int_framebuffer_restore_policy(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
target_rect: impl CastInto<Ref<QRect>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source_rect: impl CastInto<Ref<QRect>>,
buffers: c_uint,
filter: c_uint,
read_color_attachment_index: c_int,
draw_color_attachment_index: c_int,
restore_policy: FramebufferRestorePolicy,
)
pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint2_int_framebuffer_restore_policy( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, filter: c_uint, read_color_attachment_index: c_int, draw_color_attachment_index: c_int, restore_policy: FramebufferRestorePolicy, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers, unsigned int filter, int readColorAttachmentIndex, int drawColorAttachmentIndex, QOpenGLFramebufferObject::FramebufferRestorePolicy restorePolicy).
Sourcepub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint2_int(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
target_rect: impl CastInto<Ref<QRect>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source_rect: impl CastInto<Ref<QRect>>,
buffers: c_uint,
filter: c_uint,
read_color_attachment_index: c_int,
draw_color_attachment_index: c_int,
)
pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint2_int( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, filter: c_uint, read_color_attachment_index: c_int, draw_color_attachment_index: c_int, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers, unsigned int filter, int readColorAttachmentIndex, int drawColorAttachmentIndex).
Sourcepub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
target_rect: impl CastInto<Ref<QRect>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source_rect: impl CastInto<Ref<QRect>>,
buffers: c_uint,
filter: c_uint,
)
pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, filter: c_uint, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers = …, unsigned int filter = …).
Sourcepub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object2_uint(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
buffers: c_uint,
filter: c_uint,
)
pub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object2_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, buffers: c_uint, filter: c_uint, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, QOpenGLFramebufferObject* source, unsigned int buffers = …, unsigned int filter = …).
Sourcepub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect_uint(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
target_rect: impl CastInto<Ref<QRect>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source_rect: impl CastInto<Ref<QRect>>,
buffers: c_uint,
)
pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers = …).
Sourcepub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
target_rect: impl CastInto<Ref<QRect>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source_rect: impl CastInto<Ref<QRect>>,
)
pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect).
Sourcepub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object_uint(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
buffers: c_uint,
)
pub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, buffers: c_uint, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, QOpenGLFramebufferObject* source, unsigned int buffers = …).
Sourcepub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object(
target: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
source: impl CastInto<Ptr<QOpenGLFramebufferObject>>,
)
pub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, )
Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, QOpenGLFramebufferObject* source).
Sourcepub unsafe fn format(&self) -> CppBox<QOpenGLFramebufferObjectFormat>
pub unsafe fn format(&self) -> CppBox<QOpenGLFramebufferObjectFormat>
Calls C++ function: QOpenGLFramebufferObjectFormat QOpenGLFramebufferObject::format() const.
Sourcepub unsafe fn handle(&self) -> c_uint
pub unsafe fn handle(&self) -> c_uint
Calls C++ function: unsigned int QOpenGLFramebufferObject::handle() const.
Sourcepub unsafe fn has_opengl_framebuffer_blit() -> bool
pub unsafe fn has_opengl_framebuffer_blit() -> bool
Calls C++ function: static bool QOpenGLFramebufferObject::hasOpenGLFramebufferBlit().
Sourcepub unsafe fn has_opengl_framebuffer_objects() -> bool
pub unsafe fn has_opengl_framebuffer_objects() -> bool
Calls C++ function: static bool QOpenGLFramebufferObject::hasOpenGLFramebufferObjects().
Sourcepub unsafe fn height(&self) -> c_int
pub unsafe fn height(&self) -> c_int
Calls C++ function: int QOpenGLFramebufferObject::height() const.
Sourcepub unsafe fn is_bound(&self) -> bool
pub unsafe fn is_bound(&self) -> bool
Calls C++ function: bool QOpenGLFramebufferObject::isBound() const.
Sourcepub unsafe fn is_valid(&self) -> bool
pub unsafe fn is_valid(&self) -> bool
Calls C++ function: bool QOpenGLFramebufferObject::isValid() const.
Sourcepub unsafe fn from_q_size_uint(
size: impl CastInto<Ref<QSize>>,
target: c_uint,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_q_size_uint( size: impl CastInto<Ref<QSize>>, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, unsigned int target = …).
Sourcepub unsafe fn from_2_int_uint(
width: c_int,
height: c_int,
target: c_uint,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_2_int_uint( width: c_int, height: c_int, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, unsigned int target = …).
Sourcepub unsafe fn from_q_size_attachment2_uint(
size: impl CastInto<Ref<QSize>>,
attachment: Attachment,
target: c_uint,
internal_format: c_uint,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_q_size_attachment2_uint( size: impl CastInto<Ref<QSize>>, attachment: Attachment, target: c_uint, internal_format: c_uint, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …, unsigned int internalFormat = …).
Sourcepub unsafe fn from_2_int_attachment2_uint(
width: c_int,
height: c_int,
attachment: Attachment,
target: c_uint,
internal_format: c_uint,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_2_int_attachment2_uint( width: c_int, height: c_int, attachment: Attachment, target: c_uint, internal_format: c_uint, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …, unsigned int internalFormat = …).
Sourcepub unsafe fn from_q_size_q_opengl_framebuffer_object_format(
size: impl CastInto<Ref<QSize>>,
format: impl CastInto<Ref<QOpenGLFramebufferObjectFormat>>,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_q_size_q_opengl_framebuffer_object_format( size: impl CastInto<Ref<QSize>>, format: impl CastInto<Ref<QOpenGLFramebufferObjectFormat>>, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, const QOpenGLFramebufferObjectFormat& format).
Sourcepub unsafe fn from_2_int_q_opengl_framebuffer_object_format(
width: c_int,
height: c_int,
format: impl CastInto<Ref<QOpenGLFramebufferObjectFormat>>,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_2_int_q_opengl_framebuffer_object_format( width: c_int, height: c_int, format: impl CastInto<Ref<QOpenGLFramebufferObjectFormat>>, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, const QOpenGLFramebufferObjectFormat& format).
Sourcepub unsafe fn from_q_size(
size: impl CastInto<Ref<QSize>>,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_q_size( size: impl CastInto<Ref<QSize>>, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size).
Sourcepub unsafe fn from_2_int(
width: c_int,
height: c_int,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_2_int( width: c_int, height: c_int, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height).
Sourcepub unsafe fn from_q_size_attachment_uint(
size: impl CastInto<Ref<QSize>>,
attachment: Attachment,
target: c_uint,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_q_size_attachment_uint( size: impl CastInto<Ref<QSize>>, attachment: Attachment, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …).
Sourcepub unsafe fn from_q_size_attachment(
size: impl CastInto<Ref<QSize>>,
attachment: Attachment,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_q_size_attachment( size: impl CastInto<Ref<QSize>>, attachment: Attachment, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, QOpenGLFramebufferObject::Attachment attachment).
Sourcepub unsafe fn from_2_int_attachment_uint(
width: c_int,
height: c_int,
attachment: Attachment,
target: c_uint,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_2_int_attachment_uint( width: c_int, height: c_int, attachment: Attachment, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …).
Sourcepub unsafe fn from_2_int_attachment(
width: c_int,
height: c_int,
attachment: Attachment,
) -> CppBox<QOpenGLFramebufferObject>
pub unsafe fn from_2_int_attachment( width: c_int, height: c_int, attachment: Attachment, ) -> CppBox<QOpenGLFramebufferObject>
Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, QOpenGLFramebufferObject::Attachment attachment).
Sourcepub unsafe fn release(&self) -> bool
pub unsafe fn release(&self) -> bool
Calls C++ function: bool QOpenGLFramebufferObject::release().
Sourcepub unsafe fn set_attachment(&self, attachment: Attachment)
pub unsafe fn set_attachment(&self, attachment: Attachment)
Calls C++ function: void QOpenGLFramebufferObject::setAttachment(QOpenGLFramebufferObject::Attachment attachment).
Sourcepub unsafe fn size(&self) -> CppBox<QSize>
pub unsafe fn size(&self) -> CppBox<QSize>
Calls C++ function: QSize QOpenGLFramebufferObject::size() const.
Sourcepub unsafe fn sizes(&self) -> CppBox<QVectorOfQSize>
pub unsafe fn sizes(&self) -> CppBox<QVectorOfQSize>
Calls C++ function: QVector<QSize> QOpenGLFramebufferObject::sizes() const.
Sourcepub unsafe fn take_texture_0a(&self) -> c_uint
pub unsafe fn take_texture_0a(&self) -> c_uint
Calls C++ function: unsigned int QOpenGLFramebufferObject::takeTexture().
Sourcepub unsafe fn take_texture_1a(&self, color_attachment_index: c_int) -> c_uint
pub unsafe fn take_texture_1a(&self, color_attachment_index: c_int) -> c_uint
Calls C++ function: unsigned int QOpenGLFramebufferObject::takeTexture(int colorAttachmentIndex).
Sourcepub unsafe fn texture(&self) -> c_uint
pub unsafe fn texture(&self) -> c_uint
Calls C++ function: unsigned int QOpenGLFramebufferObject::texture() const.
Sourcepub unsafe fn textures(&self) -> CppBox<QVectorOfUint>
pub unsafe fn textures(&self) -> CppBox<QVectorOfUint>
Calls C++ function: QVector<unsigned int> QOpenGLFramebufferObject::textures() const.
Sourcepub unsafe fn to_image_0a(&self) -> CppBox<QImage>
pub unsafe fn to_image_0a(&self) -> CppBox<QImage>
Calls C++ function: QImage QOpenGLFramebufferObject::toImage() const.
Sourcepub unsafe fn to_image_1a(&self, flipped: bool) -> CppBox<QImage>
pub unsafe fn to_image_1a(&self, flipped: bool) -> CppBox<QImage>
Calls C++ function: QImage QOpenGLFramebufferObject::toImage(bool flipped) const.