pub struct QOpenGLFunctions { /* private fields */ }Expand description
C++ class: QOpenGLFunctions.
Implementations
Sourceimpl QOpenGLFunctions
impl QOpenGLFunctions
Sourcepub unsafe fn copy_from(
&self,
other: impl CastInto<Ref<QOpenGLFunctions>>,
) -> Ref<QOpenGLFunctions>
pub unsafe fn copy_from( &self, other: impl CastInto<Ref<QOpenGLFunctions>>, ) -> Ref<QOpenGLFunctions>
Calls C++ function: QOpenGLFunctions& QOpenGLFunctions::operator=(const QOpenGLFunctions& other).
Sourcepub unsafe fn gl_active_texture(&self, texture: c_uint)
pub unsafe fn gl_active_texture(&self, texture: c_uint)
Calls C++ function: void QOpenGLFunctions::glActiveTexture(unsigned int texture).
Sourcepub unsafe fn gl_attach_shader(&self, program: c_uint, shader: c_uint)
pub unsafe fn gl_attach_shader(&self, program: c_uint, shader: c_uint)
Calls C++ function: void QOpenGLFunctions::glAttachShader(unsigned int program, unsigned int shader).
Sourcepub unsafe fn gl_bind_attrib_location(
&self,
program: c_uint,
index: c_uint,
name: *const c_char,
)
pub unsafe fn gl_bind_attrib_location( &self, program: c_uint, index: c_uint, name: *const c_char, )
Calls C++ function: void QOpenGLFunctions::glBindAttribLocation(unsigned int program, unsigned int index, const char* name).
Sourcepub unsafe fn gl_bind_buffer(&self, target: c_uint, buffer: c_uint)
pub unsafe fn gl_bind_buffer(&self, target: c_uint, buffer: c_uint)
Calls C++ function: void QOpenGLFunctions::glBindBuffer(unsigned int target, unsigned int buffer).
Sourcepub unsafe fn gl_bind_framebuffer(&self, target: c_uint, framebuffer: c_uint)
pub unsafe fn gl_bind_framebuffer(&self, target: c_uint, framebuffer: c_uint)
Calls C++ function: void QOpenGLFunctions::glBindFramebuffer(unsigned int target, unsigned int framebuffer).
Sourcepub unsafe fn gl_bind_renderbuffer(&self, target: c_uint, renderbuffer: c_uint)
pub unsafe fn gl_bind_renderbuffer(&self, target: c_uint, renderbuffer: c_uint)
Calls C++ function: void QOpenGLFunctions::glBindRenderbuffer(unsigned int target, unsigned int renderbuffer).
Sourcepub unsafe fn gl_bind_texture(&self, target: c_uint, texture: c_uint)
pub unsafe fn gl_bind_texture(&self, target: c_uint, texture: c_uint)
Calls C++ function: void QOpenGLFunctions::glBindTexture(unsigned int target, unsigned int texture).
Sourcepub unsafe fn gl_blend_color(
&self,
red: c_float,
green: c_float,
blue: c_float,
alpha: c_float,
)
pub unsafe fn gl_blend_color( &self, red: c_float, green: c_float, blue: c_float, alpha: c_float, )
Calls C++ function: void QOpenGLFunctions::glBlendColor(float red, float green, float blue, float alpha).
Sourcepub unsafe fn gl_blend_equation(&self, mode: c_uint)
pub unsafe fn gl_blend_equation(&self, mode: c_uint)
Calls C++ function: void QOpenGLFunctions::glBlendEquation(unsigned int mode).
Sourcepub unsafe fn gl_blend_equation_separate(
&self,
mode_r_g_b: c_uint,
mode_alpha: c_uint,
)
pub unsafe fn gl_blend_equation_separate( &self, mode_r_g_b: c_uint, mode_alpha: c_uint, )
Calls C++ function: void QOpenGLFunctions::glBlendEquationSeparate(unsigned int modeRGB, unsigned int modeAlpha).
Sourcepub unsafe fn gl_blend_func(&self, sfactor: c_uint, dfactor: c_uint)
pub unsafe fn gl_blend_func(&self, sfactor: c_uint, dfactor: c_uint)
Calls C++ function: void QOpenGLFunctions::glBlendFunc(unsigned int sfactor, unsigned int dfactor).
Sourcepub unsafe fn gl_blend_func_separate(
&self,
src_r_g_b: c_uint,
dst_r_g_b: c_uint,
src_alpha: c_uint,
dst_alpha: c_uint,
)
pub unsafe fn gl_blend_func_separate( &self, src_r_g_b: c_uint, dst_r_g_b: c_uint, src_alpha: c_uint, dst_alpha: c_uint, )
Calls C++ function: void QOpenGLFunctions::glBlendFuncSeparate(unsigned int srcRGB, unsigned int dstRGB, unsigned int srcAlpha, unsigned int dstAlpha).
Sourcepub unsafe fn gl_buffer_data(
&self,
target: c_uint,
size: c_long,
data: *const c_void,
usage: c_uint,
)
pub unsafe fn gl_buffer_data( &self, target: c_uint, size: c_long, data: *const c_void, usage: c_uint, )
Calls C++ function: void QOpenGLFunctions::glBufferData(unsigned int target, long size, const void* data, unsigned int usage).
Sourcepub unsafe fn gl_buffer_sub_data(
&self,
target: c_uint,
offset: c_long,
size: c_long,
data: *const c_void,
)
pub unsafe fn gl_buffer_sub_data( &self, target: c_uint, offset: c_long, size: c_long, data: *const c_void, )
Calls C++ function: void QOpenGLFunctions::glBufferSubData(unsigned int target, long offset, long size, const void* data).
Sourcepub unsafe fn gl_check_framebuffer_status(&self, target: c_uint) -> c_uint
pub unsafe fn gl_check_framebuffer_status(&self, target: c_uint) -> c_uint
Calls C++ function: unsigned int QOpenGLFunctions::glCheckFramebufferStatus(unsigned int target).
Sourcepub unsafe fn gl_clear(&self, mask: c_uint)
pub unsafe fn gl_clear(&self, mask: c_uint)
Calls C++ function: void QOpenGLFunctions::glClear(unsigned int mask).
Sourcepub unsafe fn gl_clear_color(
&self,
red: c_float,
green: c_float,
blue: c_float,
alpha: c_float,
)
pub unsafe fn gl_clear_color( &self, red: c_float, green: c_float, blue: c_float, alpha: c_float, )
Calls C++ function: void QOpenGLFunctions::glClearColor(float red, float green, float blue, float alpha).
Sourcepub unsafe fn gl_clear_depthf(&self, depth: c_float)
pub unsafe fn gl_clear_depthf(&self, depth: c_float)
Calls C++ function: void QOpenGLFunctions::glClearDepthf(float depth).
Sourcepub unsafe fn gl_clear_stencil(&self, s: c_int)
pub unsafe fn gl_clear_stencil(&self, s: c_int)
Calls C++ function: void QOpenGLFunctions::glClearStencil(int s).
Sourcepub unsafe fn gl_color_mask(
&self,
red: c_uchar,
green: c_uchar,
blue: c_uchar,
alpha: c_uchar,
)
pub unsafe fn gl_color_mask( &self, red: c_uchar, green: c_uchar, blue: c_uchar, alpha: c_uchar, )
Calls C++ function: void QOpenGLFunctions::glColorMask(unsigned char red, unsigned char green, unsigned char blue, unsigned char alpha).
Sourcepub unsafe fn gl_compile_shader(&self, shader: c_uint)
pub unsafe fn gl_compile_shader(&self, shader: c_uint)
Calls C++ function: void QOpenGLFunctions::glCompileShader(unsigned int shader).
Sourcepub unsafe fn gl_compressed_tex_image_2d(
&self,
target: c_uint,
level: c_int,
internalformat: c_uint,
width: c_int,
height: c_int,
border: c_int,
image_size: c_int,
data: *const c_void,
)
pub unsafe fn gl_compressed_tex_image_2d( &self, target: c_uint, level: c_int, internalformat: c_uint, width: c_int, height: c_int, border: c_int, image_size: c_int, data: *const c_void, )
Calls C++ function: void QOpenGLFunctions::glCompressedTexImage2D(unsigned int target, int level, unsigned int internalformat, int width, int height, int border, int imageSize, const void* data).
Sourcepub unsafe fn gl_compressed_tex_sub_image_2d(
&self,
target: c_uint,
level: c_int,
xoffset: c_int,
yoffset: c_int,
width: c_int,
height: c_int,
format: c_uint,
image_size: c_int,
data: *const c_void,
)
pub unsafe fn gl_compressed_tex_sub_image_2d( &self, target: c_uint, level: c_int, xoffset: c_int, yoffset: c_int, width: c_int, height: c_int, format: c_uint, image_size: c_int, data: *const c_void, )
Calls C++ function: void QOpenGLFunctions::glCompressedTexSubImage2D(unsigned int target, int level, int xoffset, int yoffset, int width, int height, unsigned int format, int imageSize, const void* data).
Sourcepub unsafe fn gl_copy_tex_image_2d(
&self,
target: c_uint,
level: c_int,
internalformat: c_uint,
x: c_int,
y: c_int,
width: c_int,
height: c_int,
border: c_int,
)
pub unsafe fn gl_copy_tex_image_2d( &self, target: c_uint, level: c_int, internalformat: c_uint, x: c_int, y: c_int, width: c_int, height: c_int, border: c_int, )
Calls C++ function: void QOpenGLFunctions::glCopyTexImage2D(unsigned int target, int level, unsigned int internalformat, int x, int y, int width, int height, int border).
Sourcepub unsafe fn gl_copy_tex_sub_image_2d(
&self,
target: c_uint,
level: c_int,
xoffset: c_int,
yoffset: c_int,
x: c_int,
y: c_int,
width: c_int,
height: c_int,
)
pub unsafe fn gl_copy_tex_sub_image_2d( &self, target: c_uint, level: c_int, xoffset: c_int, yoffset: c_int, x: c_int, y: c_int, width: c_int, height: c_int, )
Calls C++ function: void QOpenGLFunctions::glCopyTexSubImage2D(unsigned int target, int level, int xoffset, int yoffset, int x, int y, int width, int height).
Sourcepub unsafe fn gl_create_program(&self) -> c_uint
pub unsafe fn gl_create_program(&self) -> c_uint
Calls C++ function: unsigned int QOpenGLFunctions::glCreateProgram().
Sourcepub unsafe fn gl_create_shader(&self, type_: c_uint) -> c_uint
pub unsafe fn gl_create_shader(&self, type_: c_uint) -> c_uint
Calls C++ function: unsigned int QOpenGLFunctions::glCreateShader(unsigned int type).
Sourcepub unsafe fn gl_cull_face(&self, mode: c_uint)
pub unsafe fn gl_cull_face(&self, mode: c_uint)
Calls C++ function: void QOpenGLFunctions::glCullFace(unsigned int mode).
Sourcepub unsafe fn gl_delete_buffers(&self, n: c_int, buffers: *const c_uint)
pub unsafe fn gl_delete_buffers(&self, n: c_int, buffers: *const c_uint)
Calls C++ function: void QOpenGLFunctions::glDeleteBuffers(int n, const unsigned int* buffers).
Sourcepub unsafe fn gl_delete_framebuffers(
&self,
n: c_int,
framebuffers: *const c_uint,
)
pub unsafe fn gl_delete_framebuffers( &self, n: c_int, framebuffers: *const c_uint, )
Calls C++ function: void QOpenGLFunctions::glDeleteFramebuffers(int n, const unsigned int* framebuffers).
Sourcepub unsafe fn gl_delete_program(&self, program: c_uint)
pub unsafe fn gl_delete_program(&self, program: c_uint)
Calls C++ function: void QOpenGLFunctions::glDeleteProgram(unsigned int program).
Sourcepub unsafe fn gl_delete_renderbuffers(
&self,
n: c_int,
renderbuffers: *const c_uint,
)
pub unsafe fn gl_delete_renderbuffers( &self, n: c_int, renderbuffers: *const c_uint, )
Calls C++ function: void QOpenGLFunctions::glDeleteRenderbuffers(int n, const unsigned int* renderbuffers).
Sourcepub unsafe fn gl_delete_shader(&self, shader: c_uint)
pub unsafe fn gl_delete_shader(&self, shader: c_uint)
Calls C++ function: void QOpenGLFunctions::glDeleteShader(unsigned int shader).
Sourcepub unsafe fn gl_delete_textures(&self, n: c_int, textures: *const c_uint)
pub unsafe fn gl_delete_textures(&self, n: c_int, textures: *const c_uint)
Calls C++ function: void QOpenGLFunctions::glDeleteTextures(int n, const unsigned int* textures).
Sourcepub unsafe fn gl_depth_func(&self, func: c_uint)
pub unsafe fn gl_depth_func(&self, func: c_uint)
Calls C++ function: void QOpenGLFunctions::glDepthFunc(unsigned int func).
Sourcepub unsafe fn gl_depth_mask(&self, flag: c_uchar)
pub unsafe fn gl_depth_mask(&self, flag: c_uchar)
Calls C++ function: void QOpenGLFunctions::glDepthMask(unsigned char flag).
Sourcepub unsafe fn gl_depth_rangef(&self, z_near: c_float, z_far: c_float)
pub unsafe fn gl_depth_rangef(&self, z_near: c_float, z_far: c_float)
Calls C++ function: void QOpenGLFunctions::glDepthRangef(float zNear, float zFar).
Sourcepub unsafe fn gl_detach_shader(&self, program: c_uint, shader: c_uint)
pub unsafe fn gl_detach_shader(&self, program: c_uint, shader: c_uint)
Calls C++ function: void QOpenGLFunctions::glDetachShader(unsigned int program, unsigned int shader).
Sourcepub unsafe fn gl_disable(&self, cap: c_uint)
pub unsafe fn gl_disable(&self, cap: c_uint)
Calls C++ function: void QOpenGLFunctions::glDisable(unsigned int cap).
Sourcepub unsafe fn gl_disable_vertex_attrib_array(&self, index: c_uint)
pub unsafe fn gl_disable_vertex_attrib_array(&self, index: c_uint)
Calls C++ function: void QOpenGLFunctions::glDisableVertexAttribArray(unsigned int index).
Sourcepub unsafe fn gl_draw_arrays(&self, mode: c_uint, first: c_int, count: c_int)
pub unsafe fn gl_draw_arrays(&self, mode: c_uint, first: c_int, count: c_int)
Calls C++ function: void QOpenGLFunctions::glDrawArrays(unsigned int mode, int first, int count).
Sourcepub unsafe fn gl_draw_elements(
&self,
mode: c_uint,
count: c_int,
type_: c_uint,
indices: *const c_void,
)
pub unsafe fn gl_draw_elements( &self, mode: c_uint, count: c_int, type_: c_uint, indices: *const c_void, )
Calls C++ function: void QOpenGLFunctions::glDrawElements(unsigned int mode, int count, unsigned int type, const void* indices).
Sourcepub unsafe fn gl_enable(&self, cap: c_uint)
pub unsafe fn gl_enable(&self, cap: c_uint)
Calls C++ function: void QOpenGLFunctions::glEnable(unsigned int cap).
Sourcepub unsafe fn gl_enable_vertex_attrib_array(&self, index: c_uint)
pub unsafe fn gl_enable_vertex_attrib_array(&self, index: c_uint)
Calls C++ function: void QOpenGLFunctions::glEnableVertexAttribArray(unsigned int index).
Sourcepub unsafe fn gl_framebuffer_renderbuffer(
&self,
target: c_uint,
attachment: c_uint,
renderbuffertarget: c_uint,
renderbuffer: c_uint,
)
pub unsafe fn gl_framebuffer_renderbuffer( &self, target: c_uint, attachment: c_uint, renderbuffertarget: c_uint, renderbuffer: c_uint, )
Calls C++ function: void QOpenGLFunctions::glFramebufferRenderbuffer(unsigned int target, unsigned int attachment, unsigned int renderbuffertarget, unsigned int renderbuffer).
Sourcepub unsafe fn gl_framebuffer_texture_2d(
&self,
target: c_uint,
attachment: c_uint,
textarget: c_uint,
texture: c_uint,
level: c_int,
)
pub unsafe fn gl_framebuffer_texture_2d( &self, target: c_uint, attachment: c_uint, textarget: c_uint, texture: c_uint, level: c_int, )
Calls C++ function: void QOpenGLFunctions::glFramebufferTexture2D(unsigned int target, unsigned int attachment, unsigned int textarget, unsigned int texture, int level).
Sourcepub unsafe fn gl_front_face(&self, mode: c_uint)
pub unsafe fn gl_front_face(&self, mode: c_uint)
Calls C++ function: void QOpenGLFunctions::glFrontFace(unsigned int mode).
Sourcepub unsafe fn gl_gen_buffers(&self, n: c_int, buffers: *mut c_uint)
pub unsafe fn gl_gen_buffers(&self, n: c_int, buffers: *mut c_uint)
Calls C++ function: void QOpenGLFunctions::glGenBuffers(int n, unsigned int* buffers).
Sourcepub unsafe fn gl_gen_framebuffers(&self, n: c_int, framebuffers: *mut c_uint)
pub unsafe fn gl_gen_framebuffers(&self, n: c_int, framebuffers: *mut c_uint)
Calls C++ function: void QOpenGLFunctions::glGenFramebuffers(int n, unsigned int* framebuffers).
Sourcepub unsafe fn gl_gen_renderbuffers(&self, n: c_int, renderbuffers: *mut c_uint)
pub unsafe fn gl_gen_renderbuffers(&self, n: c_int, renderbuffers: *mut c_uint)
Calls C++ function: void QOpenGLFunctions::glGenRenderbuffers(int n, unsigned int* renderbuffers).
Sourcepub unsafe fn gl_gen_textures(&self, n: c_int, textures: *mut c_uint)
pub unsafe fn gl_gen_textures(&self, n: c_int, textures: *mut c_uint)
Calls C++ function: void QOpenGLFunctions::glGenTextures(int n, unsigned int* textures).
Sourcepub unsafe fn gl_generate_mipmap(&self, target: c_uint)
pub unsafe fn gl_generate_mipmap(&self, target: c_uint)
Calls C++ function: void QOpenGLFunctions::glGenerateMipmap(unsigned int target).
Sourcepub unsafe fn gl_get_active_attrib(
&self,
program: c_uint,
index: c_uint,
bufsize: c_int,
length: *mut c_int,
size: *mut c_int,
type_: *mut c_uint,
name: *mut c_char,
)
pub unsafe fn gl_get_active_attrib( &self, program: c_uint, index: c_uint, bufsize: c_int, length: *mut c_int, size: *mut c_int, type_: *mut c_uint, name: *mut c_char, )
Calls C++ function: void QOpenGLFunctions::glGetActiveAttrib(unsigned int program, unsigned int index, int bufsize, int* length, int* size, unsigned int* type, char* name).
Sourcepub unsafe fn gl_get_active_uniform(
&self,
program: c_uint,
index: c_uint,
bufsize: c_int,
length: *mut c_int,
size: *mut c_int,
type_: *mut c_uint,
name: *mut c_char,
)
pub unsafe fn gl_get_active_uniform( &self, program: c_uint, index: c_uint, bufsize: c_int, length: *mut c_int, size: *mut c_int, type_: *mut c_uint, name: *mut c_char, )
Calls C++ function: void QOpenGLFunctions::glGetActiveUniform(unsigned int program, unsigned int index, int bufsize, int* length, int* size, unsigned int* type, char* name).
Sourcepub unsafe fn gl_get_attached_shaders(
&self,
program: c_uint,
maxcount: c_int,
count: *mut c_int,
shaders: *mut c_uint,
)
pub unsafe fn gl_get_attached_shaders( &self, program: c_uint, maxcount: c_int, count: *mut c_int, shaders: *mut c_uint, )
Calls C++ function: void QOpenGLFunctions::glGetAttachedShaders(unsigned int program, int maxcount, int* count, unsigned int* shaders).
Sourcepub unsafe fn gl_get_attrib_location(
&self,
program: c_uint,
name: *const c_char,
) -> c_int
pub unsafe fn gl_get_attrib_location( &self, program: c_uint, name: *const c_char, ) -> c_int
Calls C++ function: int QOpenGLFunctions::glGetAttribLocation(unsigned int program, const char* name).
Sourcepub unsafe fn gl_get_booleanv(&self, pname: c_uint, params: *mut c_uchar)
pub unsafe fn gl_get_booleanv(&self, pname: c_uint, params: *mut c_uchar)
Calls C++ function: void QOpenGLFunctions::glGetBooleanv(unsigned int pname, unsigned char* params).
Sourcepub unsafe fn gl_get_buffer_parameteriv(
&self,
target: c_uint,
pname: c_uint,
params: *mut c_int,
)
pub unsafe fn gl_get_buffer_parameteriv( &self, target: c_uint, pname: c_uint, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetBufferParameteriv(unsigned int target, unsigned int pname, int* params).
Sourcepub unsafe fn gl_get_error(&self) -> c_uint
pub unsafe fn gl_get_error(&self) -> c_uint
Calls C++ function: unsigned int QOpenGLFunctions::glGetError().
Sourcepub unsafe fn gl_get_floatv(&self, pname: c_uint, params: *mut c_float)
pub unsafe fn gl_get_floatv(&self, pname: c_uint, params: *mut c_float)
Calls C++ function: void QOpenGLFunctions::glGetFloatv(unsigned int pname, float* params).
Sourcepub unsafe fn gl_get_framebuffer_attachment_parameteriv(
&self,
target: c_uint,
attachment: c_uint,
pname: c_uint,
params: *mut c_int,
)
pub unsafe fn gl_get_framebuffer_attachment_parameteriv( &self, target: c_uint, attachment: c_uint, pname: c_uint, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetFramebufferAttachmentParameteriv(unsigned int target, unsigned int attachment, unsigned int pname, int* params).
Sourcepub unsafe fn gl_get_integerv(&self, pname: c_uint, params: *mut c_int)
pub unsafe fn gl_get_integerv(&self, pname: c_uint, params: *mut c_int)
Calls C++ function: void QOpenGLFunctions::glGetIntegerv(unsigned int pname, int* params).
Sourcepub unsafe fn gl_get_program_info_log(
&self,
program: c_uint,
bufsize: c_int,
length: *mut c_int,
infolog: *mut c_char,
)
pub unsafe fn gl_get_program_info_log( &self, program: c_uint, bufsize: c_int, length: *mut c_int, infolog: *mut c_char, )
Calls C++ function: void QOpenGLFunctions::glGetProgramInfoLog(unsigned int program, int bufsize, int* length, char* infolog).
Sourcepub unsafe fn gl_get_programiv(
&self,
program: c_uint,
pname: c_uint,
params: *mut c_int,
)
pub unsafe fn gl_get_programiv( &self, program: c_uint, pname: c_uint, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetProgramiv(unsigned int program, unsigned int pname, int* params).
Sourcepub unsafe fn gl_get_renderbuffer_parameteriv(
&self,
target: c_uint,
pname: c_uint,
params: *mut c_int,
)
pub unsafe fn gl_get_renderbuffer_parameteriv( &self, target: c_uint, pname: c_uint, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetRenderbufferParameteriv(unsigned int target, unsigned int pname, int* params).
Sourcepub unsafe fn gl_get_shader_info_log(
&self,
shader: c_uint,
bufsize: c_int,
length: *mut c_int,
infolog: *mut c_char,
)
pub unsafe fn gl_get_shader_info_log( &self, shader: c_uint, bufsize: c_int, length: *mut c_int, infolog: *mut c_char, )
Calls C++ function: void QOpenGLFunctions::glGetShaderInfoLog(unsigned int shader, int bufsize, int* length, char* infolog).
Sourcepub unsafe fn gl_get_shader_precision_format(
&self,
shadertype: c_uint,
precisiontype: c_uint,
range: *mut c_int,
precision: *mut c_int,
)
pub unsafe fn gl_get_shader_precision_format( &self, shadertype: c_uint, precisiontype: c_uint, range: *mut c_int, precision: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetShaderPrecisionFormat(unsigned int shadertype, unsigned int precisiontype, int* range, int* precision).
Sourcepub unsafe fn gl_get_shader_source(
&self,
shader: c_uint,
bufsize: c_int,
length: *mut c_int,
source: *mut c_char,
)
pub unsafe fn gl_get_shader_source( &self, shader: c_uint, bufsize: c_int, length: *mut c_int, source: *mut c_char, )
Calls C++ function: void QOpenGLFunctions::glGetShaderSource(unsigned int shader, int bufsize, int* length, char* source).
Sourcepub unsafe fn gl_get_shaderiv(
&self,
shader: c_uint,
pname: c_uint,
params: *mut c_int,
)
pub unsafe fn gl_get_shaderiv( &self, shader: c_uint, pname: c_uint, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetShaderiv(unsigned int shader, unsigned int pname, int* params).
Sourcepub unsafe fn gl_get_string(&self, name: c_uint) -> *const c_uchar
pub unsafe fn gl_get_string(&self, name: c_uint) -> *const c_uchar
Calls C++ function: const unsigned char* QOpenGLFunctions::glGetString(unsigned int name).
Sourcepub unsafe fn gl_get_tex_parameterfv(
&self,
target: c_uint,
pname: c_uint,
params: *mut c_float,
)
pub unsafe fn gl_get_tex_parameterfv( &self, target: c_uint, pname: c_uint, params: *mut c_float, )
Calls C++ function: void QOpenGLFunctions::glGetTexParameterfv(unsigned int target, unsigned int pname, float* params).
Sourcepub unsafe fn gl_get_tex_parameteriv(
&self,
target: c_uint,
pname: c_uint,
params: *mut c_int,
)
pub unsafe fn gl_get_tex_parameteriv( &self, target: c_uint, pname: c_uint, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetTexParameteriv(unsigned int target, unsigned int pname, int* params).
Sourcepub unsafe fn gl_get_uniform_location(
&self,
program: c_uint,
name: *const c_char,
) -> c_int
pub unsafe fn gl_get_uniform_location( &self, program: c_uint, name: *const c_char, ) -> c_int
Calls C++ function: int QOpenGLFunctions::glGetUniformLocation(unsigned int program, const char* name).
Sourcepub unsafe fn gl_get_uniformfv(
&self,
program: c_uint,
location: c_int,
params: *mut c_float,
)
pub unsafe fn gl_get_uniformfv( &self, program: c_uint, location: c_int, params: *mut c_float, )
Calls C++ function: void QOpenGLFunctions::glGetUniformfv(unsigned int program, int location, float* params).
Sourcepub unsafe fn gl_get_uniformiv(
&self,
program: c_uint,
location: c_int,
params: *mut c_int,
)
pub unsafe fn gl_get_uniformiv( &self, program: c_uint, location: c_int, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetUniformiv(unsigned int program, int location, int* params).
Sourcepub unsafe fn gl_get_vertex_attrib_pointerv(
&self,
index: c_uint,
pname: c_uint,
pointer: *mut *mut c_void,
)
pub unsafe fn gl_get_vertex_attrib_pointerv( &self, index: c_uint, pname: c_uint, pointer: *mut *mut c_void, )
Calls C++ function: void QOpenGLFunctions::glGetVertexAttribPointerv(unsigned int index, unsigned int pname, void** pointer).
Sourcepub unsafe fn gl_get_vertex_attribfv(
&self,
index: c_uint,
pname: c_uint,
params: *mut c_float,
)
pub unsafe fn gl_get_vertex_attribfv( &self, index: c_uint, pname: c_uint, params: *mut c_float, )
Calls C++ function: void QOpenGLFunctions::glGetVertexAttribfv(unsigned int index, unsigned int pname, float* params).
Sourcepub unsafe fn gl_get_vertex_attribiv(
&self,
index: c_uint,
pname: c_uint,
params: *mut c_int,
)
pub unsafe fn gl_get_vertex_attribiv( &self, index: c_uint, pname: c_uint, params: *mut c_int, )
Calls C++ function: void QOpenGLFunctions::glGetVertexAttribiv(unsigned int index, unsigned int pname, int* params).
Sourcepub unsafe fn gl_hint(&self, target: c_uint, mode: c_uint)
pub unsafe fn gl_hint(&self, target: c_uint, mode: c_uint)
Calls C++ function: void QOpenGLFunctions::glHint(unsigned int target, unsigned int mode).
Sourcepub unsafe fn gl_is_buffer(&self, buffer: c_uint) -> c_uchar
pub unsafe fn gl_is_buffer(&self, buffer: c_uint) -> c_uchar
Calls C++ function: unsigned char QOpenGLFunctions::glIsBuffer(unsigned int buffer).
Sourcepub unsafe fn gl_is_enabled(&self, cap: c_uint) -> c_uchar
pub unsafe fn gl_is_enabled(&self, cap: c_uint) -> c_uchar
Calls C++ function: unsigned char QOpenGLFunctions::glIsEnabled(unsigned int cap).
Sourcepub unsafe fn gl_is_framebuffer(&self, framebuffer: c_uint) -> c_uchar
pub unsafe fn gl_is_framebuffer(&self, framebuffer: c_uint) -> c_uchar
Calls C++ function: unsigned char QOpenGLFunctions::glIsFramebuffer(unsigned int framebuffer).
Sourcepub unsafe fn gl_is_program(&self, program: c_uint) -> c_uchar
pub unsafe fn gl_is_program(&self, program: c_uint) -> c_uchar
Calls C++ function: unsigned char QOpenGLFunctions::glIsProgram(unsigned int program).
Sourcepub unsafe fn gl_is_renderbuffer(&self, renderbuffer: c_uint) -> c_uchar
pub unsafe fn gl_is_renderbuffer(&self, renderbuffer: c_uint) -> c_uchar
Calls C++ function: unsigned char QOpenGLFunctions::glIsRenderbuffer(unsigned int renderbuffer).
Sourcepub unsafe fn gl_is_shader(&self, shader: c_uint) -> c_uchar
pub unsafe fn gl_is_shader(&self, shader: c_uint) -> c_uchar
Calls C++ function: unsigned char QOpenGLFunctions::glIsShader(unsigned int shader).
Sourcepub unsafe fn gl_is_texture(&self, texture: c_uint) -> c_uchar
pub unsafe fn gl_is_texture(&self, texture: c_uint) -> c_uchar
Calls C++ function: unsigned char QOpenGLFunctions::glIsTexture(unsigned int texture).
Sourcepub unsafe fn gl_line_width(&self, width: c_float)
pub unsafe fn gl_line_width(&self, width: c_float)
Calls C++ function: void QOpenGLFunctions::glLineWidth(float width).
Sourcepub unsafe fn gl_link_program(&self, program: c_uint)
pub unsafe fn gl_link_program(&self, program: c_uint)
Calls C++ function: void QOpenGLFunctions::glLinkProgram(unsigned int program).
Sourcepub unsafe fn gl_pixel_storei(&self, pname: c_uint, param: c_int)
pub unsafe fn gl_pixel_storei(&self, pname: c_uint, param: c_int)
Calls C++ function: void QOpenGLFunctions::glPixelStorei(unsigned int pname, int param).
Sourcepub unsafe fn gl_polygon_offset(&self, factor: c_float, units: c_float)
pub unsafe fn gl_polygon_offset(&self, factor: c_float, units: c_float)
Calls C++ function: void QOpenGLFunctions::glPolygonOffset(float factor, float units).
Sourcepub unsafe fn gl_read_pixels(
&self,
x: c_int,
y: c_int,
width: c_int,
height: c_int,
format: c_uint,
type_: c_uint,
pixels: *mut c_void,
)
pub unsafe fn gl_read_pixels( &self, x: c_int, y: c_int, width: c_int, height: c_int, format: c_uint, type_: c_uint, pixels: *mut c_void, )
Calls C++ function: void QOpenGLFunctions::glReadPixels(int x, int y, int width, int height, unsigned int format, unsigned int type, void* pixels).
Sourcepub unsafe fn gl_release_shader_compiler(&self)
pub unsafe fn gl_release_shader_compiler(&self)
Calls C++ function: void QOpenGLFunctions::glReleaseShaderCompiler().
Sourcepub unsafe fn gl_renderbuffer_storage(
&self,
target: c_uint,
internalformat: c_uint,
width: c_int,
height: c_int,
)
pub unsafe fn gl_renderbuffer_storage( &self, target: c_uint, internalformat: c_uint, width: c_int, height: c_int, )
Calls C++ function: void QOpenGLFunctions::glRenderbufferStorage(unsigned int target, unsigned int internalformat, int width, int height).
Sourcepub unsafe fn gl_sample_coverage(&self, value: c_float, invert: c_uchar)
pub unsafe fn gl_sample_coverage(&self, value: c_float, invert: c_uchar)
Calls C++ function: void QOpenGLFunctions::glSampleCoverage(float value, unsigned char invert).
Sourcepub unsafe fn gl_scissor(&self, x: c_int, y: c_int, width: c_int, height: c_int)
pub unsafe fn gl_scissor(&self, x: c_int, y: c_int, width: c_int, height: c_int)
Calls C++ function: void QOpenGLFunctions::glScissor(int x, int y, int width, int height).
Sourcepub unsafe fn gl_shader_binary(
&self,
n: c_int,
shaders: *const c_uint,
binaryformat: c_uint,
binary: *const c_void,
length: c_int,
)
pub unsafe fn gl_shader_binary( &self, n: c_int, shaders: *const c_uint, binaryformat: c_uint, binary: *const c_void, length: c_int, )
Calls C++ function: void QOpenGLFunctions::glShaderBinary(int n, const unsigned int* shaders, unsigned int binaryformat, const void* binary, int length).
Sourcepub unsafe fn gl_shader_source(
&self,
shader: c_uint,
count: c_int,
string: *mut *const c_char,
length: *const c_int,
)
pub unsafe fn gl_shader_source( &self, shader: c_uint, count: c_int, string: *mut *const c_char, length: *const c_int, )
Calls C++ function: void QOpenGLFunctions::glShaderSource(unsigned int shader, int count, const char** string, const int* length).
Sourcepub unsafe fn gl_stencil_func(&self, func: c_uint, ref_: c_int, mask: c_uint)
pub unsafe fn gl_stencil_func(&self, func: c_uint, ref_: c_int, mask: c_uint)
Calls C++ function: void QOpenGLFunctions::glStencilFunc(unsigned int func, int ref, unsigned int mask).
Sourcepub unsafe fn gl_stencil_func_separate(
&self,
face: c_uint,
func: c_uint,
ref_: c_int,
mask: c_uint,
)
pub unsafe fn gl_stencil_func_separate( &self, face: c_uint, func: c_uint, ref_: c_int, mask: c_uint, )
Calls C++ function: void QOpenGLFunctions::glStencilFuncSeparate(unsigned int face, unsigned int func, int ref, unsigned int mask).
Sourcepub unsafe fn gl_stencil_mask(&self, mask: c_uint)
pub unsafe fn gl_stencil_mask(&self, mask: c_uint)
Calls C++ function: void QOpenGLFunctions::glStencilMask(unsigned int mask).
Sourcepub unsafe fn gl_stencil_mask_separate(&self, face: c_uint, mask: c_uint)
pub unsafe fn gl_stencil_mask_separate(&self, face: c_uint, mask: c_uint)
Calls C++ function: void QOpenGLFunctions::glStencilMaskSeparate(unsigned int face, unsigned int mask).
Sourcepub unsafe fn gl_stencil_op(&self, fail: c_uint, zfail: c_uint, zpass: c_uint)
pub unsafe fn gl_stencil_op(&self, fail: c_uint, zfail: c_uint, zpass: c_uint)
Calls C++ function: void QOpenGLFunctions::glStencilOp(unsigned int fail, unsigned int zfail, unsigned int zpass).
Sourcepub unsafe fn gl_stencil_op_separate(
&self,
face: c_uint,
fail: c_uint,
zfail: c_uint,
zpass: c_uint,
)
pub unsafe fn gl_stencil_op_separate( &self, face: c_uint, fail: c_uint, zfail: c_uint, zpass: c_uint, )
Calls C++ function: void QOpenGLFunctions::glStencilOpSeparate(unsigned int face, unsigned int fail, unsigned int zfail, unsigned int zpass).
Sourcepub unsafe fn gl_tex_image_2d(
&self,
target: c_uint,
level: c_int,
internalformat: c_int,
width: c_int,
height: c_int,
border: c_int,
format: c_uint,
type_: c_uint,
pixels: *const c_void,
)
pub unsafe fn gl_tex_image_2d( &self, target: c_uint, level: c_int, internalformat: c_int, width: c_int, height: c_int, border: c_int, format: c_uint, type_: c_uint, pixels: *const c_void, )
Calls C++ function: void QOpenGLFunctions::glTexImage2D(unsigned int target, int level, int internalformat, int width, int height, int border, unsigned int format, unsigned int type, const void* pixels).
Sourcepub unsafe fn gl_tex_parameterf(
&self,
target: c_uint,
pname: c_uint,
param: c_float,
)
pub unsafe fn gl_tex_parameterf( &self, target: c_uint, pname: c_uint, param: c_float, )
Calls C++ function: void QOpenGLFunctions::glTexParameterf(unsigned int target, unsigned int pname, float param).
Sourcepub unsafe fn gl_tex_parameterfv(
&self,
target: c_uint,
pname: c_uint,
params: *const c_float,
)
pub unsafe fn gl_tex_parameterfv( &self, target: c_uint, pname: c_uint, params: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glTexParameterfv(unsigned int target, unsigned int pname, const float* params).
Sourcepub unsafe fn gl_tex_parameteri(
&self,
target: c_uint,
pname: c_uint,
param: c_int,
)
pub unsafe fn gl_tex_parameteri( &self, target: c_uint, pname: c_uint, param: c_int, )
Calls C++ function: void QOpenGLFunctions::glTexParameteri(unsigned int target, unsigned int pname, int param).
Sourcepub unsafe fn gl_tex_parameteriv(
&self,
target: c_uint,
pname: c_uint,
params: *const c_int,
)
pub unsafe fn gl_tex_parameteriv( &self, target: c_uint, pname: c_uint, params: *const c_int, )
Calls C++ function: void QOpenGLFunctions::glTexParameteriv(unsigned int target, unsigned int pname, const int* params).
Sourcepub unsafe fn gl_tex_sub_image_2d(
&self,
target: c_uint,
level: c_int,
xoffset: c_int,
yoffset: c_int,
width: c_int,
height: c_int,
format: c_uint,
type_: c_uint,
pixels: *const c_void,
)
pub unsafe fn gl_tex_sub_image_2d( &self, target: c_uint, level: c_int, xoffset: c_int, yoffset: c_int, width: c_int, height: c_int, format: c_uint, type_: c_uint, pixels: *const c_void, )
Calls C++ function: void QOpenGLFunctions::glTexSubImage2D(unsigned int target, int level, int xoffset, int yoffset, int width, int height, unsigned int format, unsigned int type, const void* pixels).
Sourcepub unsafe fn gl_uniform_1f(&self, location: c_int, x: c_float)
pub unsafe fn gl_uniform_1f(&self, location: c_int, x: c_float)
Calls C++ function: void QOpenGLFunctions::glUniform1f(int location, float x).
Sourcepub unsafe fn gl_uniform_1fv(
&self,
location: c_int,
count: c_int,
v: *const c_float,
)
pub unsafe fn gl_uniform_1fv( &self, location: c_int, count: c_int, v: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glUniform1fv(int location, int count, const float* v).
Sourcepub unsafe fn gl_uniform_1i(&self, location: c_int, x: c_int)
pub unsafe fn gl_uniform_1i(&self, location: c_int, x: c_int)
Calls C++ function: void QOpenGLFunctions::glUniform1i(int location, int x).
Sourcepub unsafe fn gl_uniform_1iv(
&self,
location: c_int,
count: c_int,
v: *const c_int,
)
pub unsafe fn gl_uniform_1iv( &self, location: c_int, count: c_int, v: *const c_int, )
Calls C++ function: void QOpenGLFunctions::glUniform1iv(int location, int count, const int* v).
Sourcepub unsafe fn gl_uniform_2f(&self, location: c_int, x: c_float, y: c_float)
pub unsafe fn gl_uniform_2f(&self, location: c_int, x: c_float, y: c_float)
Calls C++ function: void QOpenGLFunctions::glUniform2f(int location, float x, float y).
Sourcepub unsafe fn gl_uniform_2fv(
&self,
location: c_int,
count: c_int,
v: *const c_float,
)
pub unsafe fn gl_uniform_2fv( &self, location: c_int, count: c_int, v: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glUniform2fv(int location, int count, const float* v).
Sourcepub unsafe fn gl_uniform_2i(&self, location: c_int, x: c_int, y: c_int)
pub unsafe fn gl_uniform_2i(&self, location: c_int, x: c_int, y: c_int)
Calls C++ function: void QOpenGLFunctions::glUniform2i(int location, int x, int y).
Sourcepub unsafe fn gl_uniform_2iv(
&self,
location: c_int,
count: c_int,
v: *const c_int,
)
pub unsafe fn gl_uniform_2iv( &self, location: c_int, count: c_int, v: *const c_int, )
Calls C++ function: void QOpenGLFunctions::glUniform2iv(int location, int count, const int* v).
Sourcepub unsafe fn gl_uniform_3f(
&self,
location: c_int,
x: c_float,
y: c_float,
z: c_float,
)
pub unsafe fn gl_uniform_3f( &self, location: c_int, x: c_float, y: c_float, z: c_float, )
Calls C++ function: void QOpenGLFunctions::glUniform3f(int location, float x, float y, float z).
Sourcepub unsafe fn gl_uniform_3fv(
&self,
location: c_int,
count: c_int,
v: *const c_float,
)
pub unsafe fn gl_uniform_3fv( &self, location: c_int, count: c_int, v: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glUniform3fv(int location, int count, const float* v).
Sourcepub unsafe fn gl_uniform_3i(
&self,
location: c_int,
x: c_int,
y: c_int,
z: c_int,
)
pub unsafe fn gl_uniform_3i( &self, location: c_int, x: c_int, y: c_int, z: c_int, )
Calls C++ function: void QOpenGLFunctions::glUniform3i(int location, int x, int y, int z).
Sourcepub unsafe fn gl_uniform_3iv(
&self,
location: c_int,
count: c_int,
v: *const c_int,
)
pub unsafe fn gl_uniform_3iv( &self, location: c_int, count: c_int, v: *const c_int, )
Calls C++ function: void QOpenGLFunctions::glUniform3iv(int location, int count, const int* v).
Sourcepub unsafe fn gl_uniform_4f(
&self,
location: c_int,
x: c_float,
y: c_float,
z: c_float,
w: c_float,
)
pub unsafe fn gl_uniform_4f( &self, location: c_int, x: c_float, y: c_float, z: c_float, w: c_float, )
Calls C++ function: void QOpenGLFunctions::glUniform4f(int location, float x, float y, float z, float w).
Sourcepub unsafe fn gl_uniform_4fv(
&self,
location: c_int,
count: c_int,
v: *const c_float,
)
pub unsafe fn gl_uniform_4fv( &self, location: c_int, count: c_int, v: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glUniform4fv(int location, int count, const float* v).
Sourcepub unsafe fn gl_uniform_4i(
&self,
location: c_int,
x: c_int,
y: c_int,
z: c_int,
w: c_int,
)
pub unsafe fn gl_uniform_4i( &self, location: c_int, x: c_int, y: c_int, z: c_int, w: c_int, )
Calls C++ function: void QOpenGLFunctions::glUniform4i(int location, int x, int y, int z, int w).
Sourcepub unsafe fn gl_uniform_4iv(
&self,
location: c_int,
count: c_int,
v: *const c_int,
)
pub unsafe fn gl_uniform_4iv( &self, location: c_int, count: c_int, v: *const c_int, )
Calls C++ function: void QOpenGLFunctions::glUniform4iv(int location, int count, const int* v).
Sourcepub unsafe fn gl_uniform_matrix_2fv(
&self,
location: c_int,
count: c_int,
transpose: c_uchar,
value: *const c_float,
)
pub unsafe fn gl_uniform_matrix_2fv( &self, location: c_int, count: c_int, transpose: c_uchar, value: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glUniformMatrix2fv(int location, int count, unsigned char transpose, const float* value).
Sourcepub unsafe fn gl_uniform_matrix_3fv(
&self,
location: c_int,
count: c_int,
transpose: c_uchar,
value: *const c_float,
)
pub unsafe fn gl_uniform_matrix_3fv( &self, location: c_int, count: c_int, transpose: c_uchar, value: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glUniformMatrix3fv(int location, int count, unsigned char transpose, const float* value).
Sourcepub unsafe fn gl_uniform_matrix_4fv(
&self,
location: c_int,
count: c_int,
transpose: c_uchar,
value: *const c_float,
)
pub unsafe fn gl_uniform_matrix_4fv( &self, location: c_int, count: c_int, transpose: c_uchar, value: *const c_float, )
Calls C++ function: void QOpenGLFunctions::glUniformMatrix4fv(int location, int count, unsigned char transpose, const float* value).
Sourcepub unsafe fn gl_use_program(&self, program: c_uint)
pub unsafe fn gl_use_program(&self, program: c_uint)
Calls C++ function: void QOpenGLFunctions::glUseProgram(unsigned int program).
Sourcepub unsafe fn gl_validate_program(&self, program: c_uint)
pub unsafe fn gl_validate_program(&self, program: c_uint)
Calls C++ function: void QOpenGLFunctions::glValidateProgram(unsigned int program).
Sourcepub unsafe fn gl_vertex_attrib_1f(&self, indx: c_uint, x: c_float)
pub unsafe fn gl_vertex_attrib_1f(&self, indx: c_uint, x: c_float)
Calls C++ function: void QOpenGLFunctions::glVertexAttrib1f(unsigned int indx, float x).
Sourcepub unsafe fn gl_vertex_attrib_1fv(&self, indx: c_uint, values: *const c_float)
pub unsafe fn gl_vertex_attrib_1fv(&self, indx: c_uint, values: *const c_float)
Calls C++ function: void QOpenGLFunctions::glVertexAttrib1fv(unsigned int indx, const float* values).
Sourcepub unsafe fn gl_vertex_attrib_2f(&self, indx: c_uint, x: c_float, y: c_float)
pub unsafe fn gl_vertex_attrib_2f(&self, indx: c_uint, x: c_float, y: c_float)
Calls C++ function: void QOpenGLFunctions::glVertexAttrib2f(unsigned int indx, float x, float y).
Sourcepub unsafe fn gl_vertex_attrib_2fv(&self, indx: c_uint, values: *const c_float)
pub unsafe fn gl_vertex_attrib_2fv(&self, indx: c_uint, values: *const c_float)
Calls C++ function: void QOpenGLFunctions::glVertexAttrib2fv(unsigned int indx, const float* values).
Sourcepub unsafe fn gl_vertex_attrib_3f(
&self,
indx: c_uint,
x: c_float,
y: c_float,
z: c_float,
)
pub unsafe fn gl_vertex_attrib_3f( &self, indx: c_uint, x: c_float, y: c_float, z: c_float, )
Calls C++ function: void QOpenGLFunctions::glVertexAttrib3f(unsigned int indx, float x, float y, float z).
Sourcepub unsafe fn gl_vertex_attrib_3fv(&self, indx: c_uint, values: *const c_float)
pub unsafe fn gl_vertex_attrib_3fv(&self, indx: c_uint, values: *const c_float)
Calls C++ function: void QOpenGLFunctions::glVertexAttrib3fv(unsigned int indx, const float* values).
Sourcepub unsafe fn gl_vertex_attrib_4f(
&self,
indx: c_uint,
x: c_float,
y: c_float,
z: c_float,
w: c_float,
)
pub unsafe fn gl_vertex_attrib_4f( &self, indx: c_uint, x: c_float, y: c_float, z: c_float, w: c_float, )
Calls C++ function: void QOpenGLFunctions::glVertexAttrib4f(unsigned int indx, float x, float y, float z, float w).
Sourcepub unsafe fn gl_vertex_attrib_4fv(&self, indx: c_uint, values: *const c_float)
pub unsafe fn gl_vertex_attrib_4fv(&self, indx: c_uint, values: *const c_float)
Calls C++ function: void QOpenGLFunctions::glVertexAttrib4fv(unsigned int indx, const float* values).
Sourcepub unsafe fn gl_vertex_attrib_pointer(
&self,
indx: c_uint,
size: c_int,
type_: c_uint,
normalized: c_uchar,
stride: c_int,
ptr: *const c_void,
)
pub unsafe fn gl_vertex_attrib_pointer( &self, indx: c_uint, size: c_int, type_: c_uint, normalized: c_uchar, stride: c_int, ptr: *const c_void, )
Calls C++ function: void QOpenGLFunctions::glVertexAttribPointer(unsigned int indx, int size, unsigned int type, unsigned char normalized, int stride, const void* ptr).
Sourcepub unsafe fn gl_viewport(
&self,
x: c_int,
y: c_int,
width: c_int,
height: c_int,
)
pub unsafe fn gl_viewport( &self, x: c_int, y: c_int, width: c_int, height: c_int, )
Calls C++ function: void QOpenGLFunctions::glViewport(int x, int y, int width, int height).
Sourcepub unsafe fn has_opengl_feature(&self, feature: OpenGLFeature) -> bool
pub unsafe fn has_opengl_feature(&self, feature: OpenGLFeature) -> bool
Calls C++ function: bool QOpenGLFunctions::hasOpenGLFeature(QOpenGLFunctions::OpenGLFeature feature) const.
Sourcepub unsafe fn initialize_opengl_functions(&self)
pub unsafe fn initialize_opengl_functions(&self)
Calls C++ function: void QOpenGLFunctions::initializeOpenGLFunctions().
Sourcepub unsafe fn new_0a() -> CppBox<QOpenGLFunctions>
pub unsafe fn new_0a() -> CppBox<QOpenGLFunctions>
Calls C++ function: [constructor] void QOpenGLFunctions::QOpenGLFunctions().
Sourcepub unsafe fn new_1a(
context: impl CastInto<Ptr<QOpenGLContext>>,
) -> CppBox<QOpenGLFunctions>
pub unsafe fn new_1a( context: impl CastInto<Ptr<QOpenGLContext>>, ) -> CppBox<QOpenGLFunctions>
Calls C++ function: [constructor] void QOpenGLFunctions::QOpenGLFunctions(QOpenGLContext* context).
Sourcepub unsafe fn new_copy(
other: impl CastInto<Ref<QOpenGLFunctions>>,
) -> CppBox<QOpenGLFunctions>
pub unsafe fn new_copy( other: impl CastInto<Ref<QOpenGLFunctions>>, ) -> CppBox<QOpenGLFunctions>
Calls C++ function: [constructor] void QOpenGLFunctions::QOpenGLFunctions(const QOpenGLFunctions& other).
Sourcepub unsafe fn opengl_features(&self) -> QFlags<OpenGLFeature>
pub unsafe fn opengl_features(&self) -> QFlags<OpenGLFeature>
Calls C++ function: QFlags<QOpenGLFunctions::OpenGLFeature> QOpenGLFunctions::openGLFeatures() const.