QOpenGLShaderProgram

Struct QOpenGLShaderProgram 

pub struct QOpenGLShaderProgram { /* private fields */ }
C++ class: QOpenGLShaderProgram.

Implementations

Source

impl QOpenGLShaderProgram

pub fn slot_shader_destroyed(&self) -> Receiver<()>

Returns a built-in Qt slot QOpenGLShaderProgram::shaderDestroyed that can be passed to qt_core::Signal::connect.

pub unsafe fn add_cacheable_shader_from_source_code_q_flags_shader_type_bit_char( &self, type_: QFlags<ShaderTypeBit>, source: *const c_char, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const char* source).

pub unsafe fn add_cacheable_shader_from_source_code_q_flags_shader_type_bit_q_byte_array( &self, type_: QFlags<ShaderTypeBit>, source: impl CastInto<Ref<QByteArray>>, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QByteArray& source).

pub unsafe fn add_cacheable_shader_from_source_code_q_flags_shader_type_bit_q_string( &self, type_: QFlags<ShaderTypeBit>, source: impl CastInto<Ref<QString>>, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addCacheableShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QString& source).

pub unsafe fn add_cacheable_shader_from_source_file( &self, type_: QFlags<ShaderTypeBit>, file_name: impl CastInto<Ref<QString>>, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addCacheableShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit> type, const QString& fileName).

pub unsafe fn add_shader( &self, shader: impl CastInto<Ptr<QOpenGLShader>>, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addShader(QOpenGLShader* shader).

pub unsafe fn add_shader_from_source_code_q_flags_shader_type_bit_char( &self, type_: QFlags<ShaderTypeBit>, source: *const c_char, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const char* source).

pub unsafe fn add_shader_from_source_code_q_flags_shader_type_bit_q_byte_array( &self, type_: QFlags<ShaderTypeBit>, source: impl CastInto<Ref<QByteArray>>, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QByteArray& source).

pub unsafe fn add_shader_from_source_code_q_flags_shader_type_bit_q_string( &self, type_: QFlags<ShaderTypeBit>, source: impl CastInto<Ref<QString>>, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addShaderFromSourceCode(QFlags<QOpenGLShader::ShaderTypeBit> type, const QString& source).

pub unsafe fn add_shader_from_source_file( &self, type_: QFlags<ShaderTypeBit>, file_name: impl CastInto<Ref<QString>>, ) -> bool

Calls C++ function: bool QOpenGLShaderProgram::addShaderFromSourceFile(QFlags<QOpenGLShader::ShaderTypeBit> type, const QString& fileName).

pub unsafe fn attribute_location_char(&self, name: *const c_char) -> c_int

Calls C++ function: int QOpenGLShaderProgram::attributeLocation(const char* name) const.

pub unsafe fn attribute_location_q_byte_array( &self, name: impl CastInto<Ref<QByteArray>>, ) -> c_int

Calls C++ function: int QOpenGLShaderProgram::attributeLocation(const QByteArray& name) const.

pub unsafe fn attribute_location_q_string( &self, name: impl CastInto<Ref<QString>>, ) -> c_int

Calls C++ function: int QOpenGLShaderProgram::attributeLocation(const QString& name) const.

pub unsafe fn bind(&self) -> bool

Calls C++ function: bool QOpenGLShaderProgram::bind().

pub unsafe fn bind_attribute_location_char_int( &self, name: *const c_char, location: c_int, )

Calls C++ function: void QOpenGLShaderProgram::bindAttributeLocation(const char* name, int location).

pub unsafe fn bind_attribute_location_q_byte_array_int( &self, name: impl CastInto<Ref<QByteArray>>, location: c_int, )

Calls C++ function: void QOpenGLShaderProgram::bindAttributeLocation(const QByteArray& name, int location).

pub unsafe fn bind_attribute_location_q_string_int( &self, name: impl CastInto<Ref<QString>>, location: c_int, )

Calls C++ function: void QOpenGLShaderProgram::bindAttributeLocation(const QString& name, int location).

pub unsafe fn create(&self) -> bool

Calls C++ function: bool QOpenGLShaderProgram::create().

pub unsafe fn default_inner_tessellation_levels(&self) -> CppBox<QVectorOfFloat>

Calls C++ function: QVector<float> QOpenGLShaderProgram::defaultInnerTessellationLevels() const.

pub unsafe fn default_outer_tessellation_levels(&self) -> CppBox<QVectorOfFloat>

Calls C++ function: QVector<float> QOpenGLShaderProgram::defaultOuterTessellationLevels() const.

pub unsafe fn disable_attribute_array_int(&self, location: c_int)

Calls C++ function: void QOpenGLShaderProgram::disableAttributeArray(int location).

pub unsafe fn disable_attribute_array_char(&self, name: *const c_char)

Calls C++ function: void QOpenGLShaderProgram::disableAttributeArray(const char* name).

pub unsafe fn enable_attribute_array_int(&self, location: c_int)

Calls C++ function: void QOpenGLShaderProgram::enableAttributeArray(int location).

pub unsafe fn enable_attribute_array_char(&self, name: *const c_char)

Calls C++ function: void QOpenGLShaderProgram::enableAttributeArray(const char* name).

pub unsafe fn has_opengl_shader_programs_1a( context: impl CastInto<Ptr<QOpenGLContext>>, ) -> bool

Calls C++ function: static bool QOpenGLShaderProgram::hasOpenGLShaderPrograms(QOpenGLContext* context = …).

pub unsafe fn has_opengl_shader_programs_0a() -> bool

Calls C++ function: static bool QOpenGLShaderProgram::hasOpenGLShaderPrograms().

pub unsafe fn is_linked(&self) -> bool

Calls C++ function: bool QOpenGLShaderProgram::isLinked() const.

Calls C++ function: virtual bool QOpenGLShaderProgram::link().

pub unsafe fn log(&self) -> CppBox<QString>

Calls C++ function: QString QOpenGLShaderProgram::log() const.

pub unsafe fn max_geometry_output_vertices(&self) -> c_int

Calls C++ function: int QOpenGLShaderProgram::maxGeometryOutputVertices() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QOpenGLShaderProgram::metaObject() const.

pub unsafe fn new_1a( parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QOpenGLShaderProgram>

Calls C++ function: [constructor] void QOpenGLShaderProgram::QOpenGLShaderProgram(QObject* parent = …).

pub unsafe fn new_0a() -> QBox<QOpenGLShaderProgram>

Calls C++ function: [constructor] void QOpenGLShaderProgram::QOpenGLShaderProgram().

pub unsafe fn patch_vertex_count(&self) -> c_int

Calls C++ function: int QOpenGLShaderProgram::patchVertexCount() const.

pub unsafe fn program_id(&self) -> c_uint

Calls C++ function: unsigned int QOpenGLShaderProgram::programId() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QOpenGLShaderProgram::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QOpenGLShaderProgram::qt_metacast(const char* arg1).

pub unsafe fn release(&self)

Calls C++ function: void QOpenGLShaderProgram::release().

pub unsafe fn remove_all_shaders(&self)

Calls C++ function: void QOpenGLShaderProgram::removeAllShaders().

pub unsafe fn remove_shader(&self, shader: impl CastInto<Ptr<QOpenGLShader>>)

Calls C++ function: void QOpenGLShaderProgram::removeShader(QOpenGLShader* shader).

pub unsafe fn set_attribute_array_int_float2_int( &self, location: c_int, values: *const c_float, tuple_size: c_int, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const float* values, int tupleSize, int stride = …).

pub unsafe fn set_attribute_array_int_q_vector_2d_int( &self, location: c_int, values: impl CastInto<Ptr<QVector2D>>, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const QVector2D* values, int stride = …).

pub unsafe fn set_attribute_array_int_q_vector_3d_int( &self, location: c_int, values: impl CastInto<Ptr<QVector3D>>, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const QVector3D* values, int stride = …).

pub unsafe fn set_attribute_array_int_q_vector_4d_int( &self, location: c_int, values: impl CastInto<Ptr<QVector4D>>, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const QVector4D* values, int stride = …).

pub unsafe fn set_attribute_array_int_uint_void2_int( &self, location: c_int, type_: c_uint, values: *const c_void, tuple_size: c_int, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, unsigned int type, const void* values, int tupleSize, int stride = …).

pub unsafe fn set_attribute_array_char_float2_int( &self, name: *const c_char, values: *const c_float, tuple_size: c_int, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const float* values, int tupleSize, int stride = …).

pub unsafe fn set_attribute_array_char_q_vector_2d_int( &self, name: *const c_char, values: impl CastInto<Ptr<QVector2D>>, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const QVector2D* values, int stride = …).

pub unsafe fn set_attribute_array_char_q_vector_3d_int( &self, name: *const c_char, values: impl CastInto<Ptr<QVector3D>>, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const QVector3D* values, int stride = …).

pub unsafe fn set_attribute_array_char_q_vector_4d_int( &self, name: *const c_char, values: impl CastInto<Ptr<QVector4D>>, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const QVector4D* values, int stride = …).

pub unsafe fn set_attribute_array_char_uint_void2_int( &self, name: *const c_char, type_: c_uint, values: *const c_void, tuple_size: c_int, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, unsigned int type, const void* values, int tupleSize, int stride = …).

pub unsafe fn set_attribute_array_int_float_int( &self, location: c_int, values: *const c_float, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const float* values, int tupleSize).

pub unsafe fn set_attribute_array_int_q_vector_2d( &self, location: c_int, values: impl CastInto<Ptr<QVector2D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const QVector2D* values).

pub unsafe fn set_attribute_array_int_q_vector_3d( &self, location: c_int, values: impl CastInto<Ptr<QVector3D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const QVector3D* values).

pub unsafe fn set_attribute_array_int_q_vector_4d( &self, location: c_int, values: impl CastInto<Ptr<QVector4D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, const QVector4D* values).

pub unsafe fn set_attribute_array_int_uint_void_int( &self, location: c_int, type_: c_uint, values: *const c_void, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(int location, unsigned int type, const void* values, int tupleSize).

pub unsafe fn set_attribute_array_char_float_int( &self, name: *const c_char, values: *const c_float, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const float* values, int tupleSize).

pub unsafe fn set_attribute_array_char_q_vector_2d( &self, name: *const c_char, values: impl CastInto<Ptr<QVector2D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const QVector2D* values).

pub unsafe fn set_attribute_array_char_q_vector_3d( &self, name: *const c_char, values: impl CastInto<Ptr<QVector3D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const QVector3D* values).

pub unsafe fn set_attribute_array_char_q_vector_4d( &self, name: *const c_char, values: impl CastInto<Ptr<QVector4D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, const QVector4D* values).

pub unsafe fn set_attribute_array_char_uint_void_int( &self, name: *const c_char, type_: c_uint, values: *const c_void, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeArray(const char* name, unsigned int type, const void* values, int tupleSize).

pub unsafe fn set_attribute_buffer_int_uint3_int( &self, location: c_int, type_: c_uint, offset: c_int, tuple_size: c_int, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeBuffer(int location, unsigned int type, int offset, int tupleSize, int stride = …).

pub unsafe fn set_attribute_buffer_char_uint3_int( &self, name: *const c_char, type_: c_uint, offset: c_int, tuple_size: c_int, stride: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeBuffer(const char* name, unsigned int type, int offset, int tupleSize, int stride = …).

pub unsafe fn set_attribute_buffer_int_uint2_int( &self, location: c_int, type_: c_uint, offset: c_int, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeBuffer(int location, unsigned int type, int offset, int tupleSize).

pub unsafe fn set_attribute_buffer_char_uint2_int( &self, name: *const c_char, type_: c_uint, offset: c_int, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeBuffer(const char* name, unsigned int type, int offset, int tupleSize).

pub unsafe fn set_attribute_value_int_float( &self, location: c_int, value: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, float value).

pub unsafe fn set_attribute_value_int2_float( &self, location: c_int, x: c_float, y: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, float x, float y).

pub unsafe fn set_attribute_value_int3_float( &self, location: c_int, x: c_float, y: c_float, z: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, float x, float y, float z).

pub unsafe fn set_attribute_value_int4_float( &self, location: c_int, x: c_float, y: c_float, z: c_float, w: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, float x, float y, float z, float w).

pub unsafe fn set_attribute_value_int_q_vector_2d( &self, location: c_int, value: impl CastInto<Ref<QVector2D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, const QVector2D& value).

pub unsafe fn set_attribute_value_int_q_vector_3d( &self, location: c_int, value: impl CastInto<Ref<QVector3D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, const QVector3D& value).

pub unsafe fn set_attribute_value_int_q_vector_4d( &self, location: c_int, value: impl CastInto<Ref<QVector4D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, const QVector4D& value).

pub unsafe fn set_attribute_value_int_q_color( &self, location: c_int, value: impl CastInto<Ref<QColor>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, const QColor& value).

pub unsafe fn set_attribute_value_int_float2_int( &self, location: c_int, values: *const c_float, columns: c_int, rows: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(int location, const float* values, int columns, int rows).

pub unsafe fn set_attribute_value_char_float( &self, name: *const c_char, value: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, float value).

pub unsafe fn set_attribute_value_char2_float( &self, name: *const c_char, x: c_float, y: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, float x, float y).

pub unsafe fn set_attribute_value_char3_float( &self, name: *const c_char, x: c_float, y: c_float, z: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, float x, float y, float z).

pub unsafe fn set_attribute_value_char4_float( &self, name: *const c_char, x: c_float, y: c_float, z: c_float, w: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, float x, float y, float z, float w).

pub unsafe fn set_attribute_value_char_q_vector_2d( &self, name: *const c_char, value: impl CastInto<Ref<QVector2D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, const QVector2D& value).

pub unsafe fn set_attribute_value_char_q_vector_3d( &self, name: *const c_char, value: impl CastInto<Ref<QVector3D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, const QVector3D& value).

pub unsafe fn set_attribute_value_char_q_vector_4d( &self, name: *const c_char, value: impl CastInto<Ref<QVector4D>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, const QVector4D& value).

pub unsafe fn set_attribute_value_char_q_color( &self, name: *const c_char, value: impl CastInto<Ref<QColor>>, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, const QColor& value).

pub unsafe fn set_attribute_value_char_float2_int( &self, name: *const c_char, values: *const c_float, columns: c_int, rows: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setAttributeValue(const char* name, const float* values, int columns, int rows).

pub unsafe fn set_default_inner_tessellation_levels( &self, levels: impl CastInto<Ref<QVectorOfFloat>>, )

Calls C++ function: void QOpenGLShaderProgram::setDefaultInnerTessellationLevels(const QVector<float>& levels).

pub unsafe fn set_default_outer_tessellation_levels( &self, levels: impl CastInto<Ref<QVectorOfFloat>>, )

Calls C++ function: void QOpenGLShaderProgram::setDefaultOuterTessellationLevels(const QVector<float>& levels).

pub unsafe fn set_patch_vertex_count(&self, count: c_int)

Calls C++ function: void QOpenGLShaderProgram::setPatchVertexCount(int count).

pub unsafe fn set_uniform_value_int_float( &self, location: c_int, value: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, float value).

pub unsafe fn set_uniform_value_2_int(&self, location: c_int, value: c_int)

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, int value).

pub unsafe fn set_uniform_value_int_uint(&self, location: c_int, value: c_uint)

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, unsigned int value).

pub unsafe fn set_uniform_value_int2_float( &self, location: c_int, x: c_float, y: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, float x, float y).

pub unsafe fn set_uniform_value_int3_float( &self, location: c_int, x: c_float, y: c_float, z: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, float x, float y, float z).

pub unsafe fn set_uniform_value_int4_float( &self, location: c_int, x: c_float, y: c_float, z: c_float, w: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, float x, float y, float z, float w).

pub unsafe fn set_uniform_value_int_q_vector_2d( &self, location: c_int, value: impl CastInto<Ref<QVector2D>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QVector2D& value).

pub unsafe fn set_uniform_value_int_q_vector_3d( &self, location: c_int, value: impl CastInto<Ref<QVector3D>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QVector3D& value).

pub unsafe fn set_uniform_value_int_q_vector_4d( &self, location: c_int, value: impl CastInto<Ref<QVector4D>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QVector4D& value).

pub unsafe fn set_uniform_value_int_q_color( &self, location: c_int, color: impl CastInto<Ref<QColor>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QColor& color).

pub unsafe fn set_uniform_value_int_q_point( &self, location: c_int, point: impl CastInto<Ref<QPoint>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QPoint& point).

pub unsafe fn set_uniform_value_int_q_point_f( &self, location: c_int, point: impl CastInto<Ref<QPointF>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QPointF& point).

pub unsafe fn set_uniform_value_int_q_size( &self, location: c_int, size: impl CastInto<Ref<QSize>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QSize& size).

pub unsafe fn set_uniform_value_int_q_size_f( &self, location: c_int, size: impl CastInto<Ref<QSizeF>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QSizeF& size).

pub unsafe fn set_uniform_value_int_q_matrix4_x4( &self, location: c_int, value: impl CastInto<Ref<QMatrix4X4>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QMatrix4x4& value).

pub unsafe fn set_uniform_value_int_q_transform( &self, location: c_int, value: impl CastInto<Ref<QTransform>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(int location, const QTransform& value).

pub unsafe fn set_uniform_value_char_float( &self, name: *const c_char, value: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, float value).

pub unsafe fn set_uniform_value_char_int( &self, name: *const c_char, value: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, int value).

pub unsafe fn set_uniform_value_char_uint( &self, name: *const c_char, value: c_uint, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, unsigned int value).

pub unsafe fn set_uniform_value_char2_float( &self, name: *const c_char, x: c_float, y: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, float x, float y).

pub unsafe fn set_uniform_value_char3_float( &self, name: *const c_char, x: c_float, y: c_float, z: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, float x, float y, float z).

pub unsafe fn set_uniform_value_char4_float( &self, name: *const c_char, x: c_float, y: c_float, z: c_float, w: c_float, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, float x, float y, float z, float w).

pub unsafe fn set_uniform_value_char_q_vector_2d( &self, name: *const c_char, value: impl CastInto<Ref<QVector2D>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QVector2D& value).

pub unsafe fn set_uniform_value_char_q_vector_3d( &self, name: *const c_char, value: impl CastInto<Ref<QVector3D>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QVector3D& value).

pub unsafe fn set_uniform_value_char_q_vector_4d( &self, name: *const c_char, value: impl CastInto<Ref<QVector4D>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QVector4D& value).

pub unsafe fn set_uniform_value_char_q_color( &self, name: *const c_char, color: impl CastInto<Ref<QColor>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QColor& color).

pub unsafe fn set_uniform_value_char_q_point( &self, name: *const c_char, point: impl CastInto<Ref<QPoint>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QPoint& point).

pub unsafe fn set_uniform_value_char_q_point_f( &self, name: *const c_char, point: impl CastInto<Ref<QPointF>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QPointF& point).

pub unsafe fn set_uniform_value_char_q_size( &self, name: *const c_char, size: impl CastInto<Ref<QSize>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QSize& size).

pub unsafe fn set_uniform_value_char_q_size_f( &self, name: *const c_char, size: impl CastInto<Ref<QSizeF>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QSizeF& size).

pub unsafe fn set_uniform_value_char_q_matrix4_x4( &self, name: *const c_char, value: impl CastInto<Ref<QMatrix4X4>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QMatrix4x4& value).

pub unsafe fn set_uniform_value_char_q_transform( &self, name: *const c_char, value: impl CastInto<Ref<QTransform>>, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValue(const char* name, const QTransform& value).

pub unsafe fn set_uniform_value_array_int_float2_int( &self, location: c_int, values: *const c_float, count: c_int, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(int location, const float* values, int count, int tupleSize).

pub unsafe fn set_uniform_value_array_int_int_int( &self, location: c_int, values: *const c_int, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(int location, const int* values, int count).

pub unsafe fn set_uniform_value_array_int_uint_int( &self, location: c_int, values: *const c_uint, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(int location, const unsigned int* values, int count).

pub unsafe fn set_uniform_value_array_int_q_vector_2d_int( &self, location: c_int, values: impl CastInto<Ptr<QVector2D>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(int location, const QVector2D* values, int count).

pub unsafe fn set_uniform_value_array_int_q_vector_3d_int( &self, location: c_int, values: impl CastInto<Ptr<QVector3D>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(int location, const QVector3D* values, int count).

pub unsafe fn set_uniform_value_array_int_q_vector_4d_int( &self, location: c_int, values: impl CastInto<Ptr<QVector4D>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(int location, const QVector4D* values, int count).

pub unsafe fn set_uniform_value_array_int_q_matrix4_x4_int( &self, location: c_int, values: impl CastInto<Ptr<QMatrix4X4>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(int location, const QMatrix4x4* values, int count).

pub unsafe fn set_uniform_value_array_char_float2_int( &self, name: *const c_char, values: *const c_float, count: c_int, tuple_size: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(const char* name, const float* values, int count, int tupleSize).

pub unsafe fn set_uniform_value_array_char_int_int( &self, name: *const c_char, values: *const c_int, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(const char* name, const int* values, int count).

pub unsafe fn set_uniform_value_array_char_uint_int( &self, name: *const c_char, values: *const c_uint, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(const char* name, const unsigned int* values, int count).

pub unsafe fn set_uniform_value_array_char_q_vector_2d_int( &self, name: *const c_char, values: impl CastInto<Ptr<QVector2D>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(const char* name, const QVector2D* values, int count).

pub unsafe fn set_uniform_value_array_char_q_vector_3d_int( &self, name: *const c_char, values: impl CastInto<Ptr<QVector3D>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(const char* name, const QVector3D* values, int count).

pub unsafe fn set_uniform_value_array_char_q_vector_4d_int( &self, name: *const c_char, values: impl CastInto<Ptr<QVector4D>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(const char* name, const QVector4D* values, int count).

pub unsafe fn set_uniform_value_array_char_q_matrix4_x4_int( &self, name: *const c_char, values: impl CastInto<Ptr<QMatrix4X4>>, count: c_int, )

Calls C++ function: void QOpenGLShaderProgram::setUniformValueArray(const char* name, const QMatrix4x4* values, int count).

pub unsafe fn shaders(&self) -> CppBox<QListOfQOpenglShader>

Calls C++ function: QList<QOpenGLShader*> QOpenGLShaderProgram::shaders() const.

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QOpenGLShaderProgram::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QOpenGLShaderProgram::trUtf8(const char* s, const char* c, int n).

pub unsafe fn uniform_location_char(&self, name: *const c_char) -> c_int

Calls C++ function: int QOpenGLShaderProgram::uniformLocation(const char* name) const.

pub unsafe fn uniform_location_q_byte_array( &self, name: impl CastInto<Ref<QByteArray>>, ) -> c_int

Calls C++ function: int QOpenGLShaderProgram::uniformLocation(const QByteArray& name) const.

pub unsafe fn uniform_location_q_string( &self, name: impl CastInto<Ref<QString>>, ) -> c_int

Calls C++ function: int QOpenGLShaderProgram::uniformLocation(const QString& name) const.

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const i8) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: i32)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: i32) -> i32

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.