pub struct QOpenGLTexture { /* private fields */ }Expand description
C++ class: QOpenGLTexture.
Implementations
Sourceimpl QOpenGLTexture
impl QOpenGLTexture
Sourcepub unsafe fn allocate_storage_0a(&self)
pub unsafe fn allocate_storage_0a(&self)
Calls C++ function: void QOpenGLTexture::allocateStorage().
Sourcepub unsafe fn allocate_storage_2a(
&self,
pixel_format: PixelFormat,
pixel_type: PixelType,
)
pub unsafe fn allocate_storage_2a( &self, pixel_format: PixelFormat, pixel_type: PixelType, )
Calls C++ function: void QOpenGLTexture::allocateStorage(QOpenGLTexture::PixelFormat pixelFormat, QOpenGLTexture::PixelType pixelType).
Sourcepub unsafe fn bind_2a(&self, unit: c_uint, reset: TextureUnitReset)
pub unsafe fn bind_2a(&self, unit: c_uint, reset: TextureUnitReset)
Calls C++ function: void QOpenGLTexture::bind(unsigned int unit, QOpenGLTexture::TextureUnitReset reset = …).
Sourcepub unsafe fn bind_1a(&self, unit: c_uint)
pub unsafe fn bind_1a(&self, unit: c_uint)
Calls C++ function: void QOpenGLTexture::bind(unsigned int unit).
Sourcepub unsafe fn border_color(&self) -> CppBox<QColor>
pub unsafe fn border_color(&self) -> CppBox<QColor>
Calls C++ function: QColor QOpenGLTexture::borderColor() const.
Sourcepub unsafe fn border_color_float(&self, border: *mut c_float)
pub unsafe fn border_color_float(&self, border: *mut c_float)
Calls C++ function: void QOpenGLTexture::borderColor(float* border) const.
Sourcepub unsafe fn border_color_int(&self, border: *mut c_int)
pub unsafe fn border_color_int(&self, border: *mut c_int)
Calls C++ function: void QOpenGLTexture::borderColor(int* border) const.
Sourcepub unsafe fn border_color_uint(&self, border: *mut c_uint)
pub unsafe fn border_color_uint(&self, border: *mut c_uint)
Calls C++ function: void QOpenGLTexture::borderColor(unsigned int* border) const.
Sourcepub unsafe fn bound_texture_id_1a(target: BindingTarget) -> c_uint
pub unsafe fn bound_texture_id_1a(target: BindingTarget) -> c_uint
Calls C++ function: static unsigned int QOpenGLTexture::boundTextureId(QOpenGLTexture::BindingTarget target).
Sourcepub unsafe fn bound_texture_id_2a(unit: c_uint, target: BindingTarget) -> c_uint
pub unsafe fn bound_texture_id_2a(unit: c_uint, target: BindingTarget) -> c_uint
Calls C++ function: static unsigned int QOpenGLTexture::boundTextureId(unsigned int unit, QOpenGLTexture::BindingTarget target).
Sourcepub unsafe fn comparison_function(&self) -> ComparisonFunction
pub unsafe fn comparison_function(&self) -> ComparisonFunction
Calls C++ function: QOpenGLTexture::ComparisonFunction QOpenGLTexture::comparisonFunction() const.
Sourcepub unsafe fn comparison_mode(&self) -> ComparisonMode
pub unsafe fn comparison_mode(&self) -> ComparisonMode
Calls C++ function: QOpenGLTexture::ComparisonMode QOpenGLTexture::comparisonMode() const.
Sourcepub unsafe fn create_texture_view(
&self,
target: Target,
view_format: TextureFormat,
minimum_mipmap_level: c_int,
maximum_mipmap_level: c_int,
minimum_layer: c_int,
maximum_layer: c_int,
) -> Ptr<QOpenGLTexture>
pub unsafe fn create_texture_view( &self, target: Target, view_format: TextureFormat, minimum_mipmap_level: c_int, maximum_mipmap_level: c_int, minimum_layer: c_int, maximum_layer: c_int, ) -> Ptr<QOpenGLTexture>
Calls C++ function: QOpenGLTexture* QOpenGLTexture::createTextureView(QOpenGLTexture::Target target, QOpenGLTexture::TextureFormat viewFormat, int minimumMipmapLevel, int maximumMipmapLevel, int minimumLayer, int maximumLayer) const.
Sourcepub unsafe fn depth_stencil_mode(&self) -> DepthStencilMode
pub unsafe fn depth_stencil_mode(&self) -> DepthStencilMode
Calls C++ function: QOpenGLTexture::DepthStencilMode QOpenGLTexture::depthStencilMode() const.
Sourcepub unsafe fn format(&self) -> TextureFormat
pub unsafe fn format(&self) -> TextureFormat
Calls C++ function: QOpenGLTexture::TextureFormat QOpenGLTexture::format() const.
Sourcepub unsafe fn generate_mip_maps_0a(&self)
pub unsafe fn generate_mip_maps_0a(&self)
Calls C++ function: void QOpenGLTexture::generateMipMaps().
Sourcepub unsafe fn generate_mip_maps_2a(
&self,
base_level: c_int,
reset_base_level: bool,
)
pub unsafe fn generate_mip_maps_2a( &self, base_level: c_int, reset_base_level: bool, )
Calls C++ function: void QOpenGLTexture::generateMipMaps(int baseLevel, bool resetBaseLevel = …).
Sourcepub unsafe fn generate_mip_maps_1a(&self, base_level: c_int)
pub unsafe fn generate_mip_maps_1a(&self, base_level: c_int)
Calls C++ function: void QOpenGLTexture::generateMipMaps(int baseLevel).
Sourcepub unsafe fn has_feature(feature: Feature) -> bool
pub unsafe fn has_feature(feature: Feature) -> bool
Calls C++ function: static bool QOpenGLTexture::hasFeature(QOpenGLTexture::Feature feature).
Sourcepub unsafe fn is_auto_mip_map_generation_enabled(&self) -> bool
pub unsafe fn is_auto_mip_map_generation_enabled(&self) -> bool
Calls C++ function: bool QOpenGLTexture::isAutoMipMapGenerationEnabled() const.
Sourcepub unsafe fn is_bound(&self) -> bool
pub unsafe fn is_bound(&self) -> bool
Calls C++ function: bool QOpenGLTexture::isBound() const.
Sourcepub unsafe fn is_bound_mut(&self, unit: c_uint) -> bool
pub unsafe fn is_bound_mut(&self, unit: c_uint) -> bool
Calls C++ function: bool QOpenGLTexture::isBound(unsigned int unit).
Sourcepub unsafe fn is_created(&self) -> bool
pub unsafe fn is_created(&self) -> bool
Calls C++ function: bool QOpenGLTexture::isCreated() const.
Sourcepub unsafe fn is_fixed_sample_positions(&self) -> bool
pub unsafe fn is_fixed_sample_positions(&self) -> bool
Calls C++ function: bool QOpenGLTexture::isFixedSamplePositions() const.
Sourcepub unsafe fn is_storage_allocated(&self) -> bool
pub unsafe fn is_storage_allocated(&self) -> bool
Calls C++ function: bool QOpenGLTexture::isStorageAllocated() const.
Sourcepub unsafe fn is_texture_view(&self) -> bool
pub unsafe fn is_texture_view(&self) -> bool
Calls C++ function: bool QOpenGLTexture::isTextureView() const.
Sourcepub unsafe fn level_of_detail_range(&self) -> CppBox<QPairOfFloatFloat>
pub unsafe fn level_of_detail_range(&self) -> CppBox<QPairOfFloatFloat>
Calls C++ function: QPair<float, float> QOpenGLTexture::levelOfDetailRange() const.
Sourcepub unsafe fn levelof_detail_bias(&self) -> c_float
pub unsafe fn levelof_detail_bias(&self) -> c_float
Calls C++ function: float QOpenGLTexture::levelofDetailBias() const.
Sourcepub unsafe fn magnification_filter(&self) -> Filter
pub unsafe fn magnification_filter(&self) -> Filter
Calls C++ function: QOpenGLTexture::Filter QOpenGLTexture::magnificationFilter() const.
Sourcepub unsafe fn maximum_anisotropy(&self) -> c_float
pub unsafe fn maximum_anisotropy(&self) -> c_float
Calls C++ function: float QOpenGLTexture::maximumAnisotropy() const.
Sourcepub unsafe fn maximum_level_of_detail(&self) -> c_float
pub unsafe fn maximum_level_of_detail(&self) -> c_float
Calls C++ function: float QOpenGLTexture::maximumLevelOfDetail() const.
Sourcepub unsafe fn maximum_mip_levels(&self) -> c_int
pub unsafe fn maximum_mip_levels(&self) -> c_int
Calls C++ function: int QOpenGLTexture::maximumMipLevels() const.
Sourcepub unsafe fn min_mag_filters(&self) -> CppBox<QPairOfFilterFilter>
pub unsafe fn min_mag_filters(&self) -> CppBox<QPairOfFilterFilter>
Calls C++ function: QPair<QOpenGLTexture::Filter, QOpenGLTexture::Filter> QOpenGLTexture::minMagFilters() const.
Sourcepub unsafe fn minification_filter(&self) -> Filter
pub unsafe fn minification_filter(&self) -> Filter
Calls C++ function: QOpenGLTexture::Filter QOpenGLTexture::minificationFilter() const.
Sourcepub unsafe fn minimum_level_of_detail(&self) -> c_float
pub unsafe fn minimum_level_of_detail(&self) -> c_float
Calls C++ function: float QOpenGLTexture::minimumLevelOfDetail() const.
Sourcepub unsafe fn mip_base_level(&self) -> c_int
pub unsafe fn mip_base_level(&self) -> c_int
Calls C++ function: int QOpenGLTexture::mipBaseLevel() const.
Sourcepub unsafe fn mip_level_range(&self) -> CppBox<QPairOfIntInt>
pub unsafe fn mip_level_range(&self) -> CppBox<QPairOfIntInt>
Calls C++ function: QPair<int, int> QOpenGLTexture::mipLevelRange() const.
Sourcepub unsafe fn mip_levels(&self) -> c_int
pub unsafe fn mip_levels(&self) -> c_int
Calls C++ function: int QOpenGLTexture::mipLevels() const.
Sourcepub unsafe fn mip_max_level(&self) -> c_int
pub unsafe fn mip_max_level(&self) -> c_int
Calls C++ function: int QOpenGLTexture::mipMaxLevel() const.
Sourcepub unsafe fn from_target(target: Target) -> CppBox<QOpenGLTexture>
pub unsafe fn from_target(target: Target) -> CppBox<QOpenGLTexture>
Calls C++ function: [constructor] void QOpenGLTexture::QOpenGLTexture(QOpenGLTexture::Target target).
Sourcepub unsafe fn from_q_image_mip_map_generation(
image: impl CastInto<Ref<QImage>>,
gen_mip_maps: MipMapGeneration,
) -> CppBox<QOpenGLTexture>
pub unsafe fn from_q_image_mip_map_generation( image: impl CastInto<Ref<QImage>>, gen_mip_maps: MipMapGeneration, ) -> CppBox<QOpenGLTexture>
Calls C++ function: [constructor] void QOpenGLTexture::QOpenGLTexture(const QImage& image, QOpenGLTexture::MipMapGeneration genMipMaps = …).
Sourcepub unsafe fn from_q_image(
image: impl CastInto<Ref<QImage>>,
) -> CppBox<QOpenGLTexture>
pub unsafe fn from_q_image( image: impl CastInto<Ref<QImage>>, ) -> CppBox<QOpenGLTexture>
Calls C++ function: [constructor] void QOpenGLTexture::QOpenGLTexture(const QImage& image).
Sourcepub unsafe fn release_0a(&self)
pub unsafe fn release_0a(&self)
Calls C++ function: void QOpenGLTexture::release().
Sourcepub unsafe fn release_2a(&self, unit: c_uint, reset: TextureUnitReset)
pub unsafe fn release_2a(&self, unit: c_uint, reset: TextureUnitReset)
Calls C++ function: void QOpenGLTexture::release(unsigned int unit, QOpenGLTexture::TextureUnitReset reset = …).
Sourcepub unsafe fn release_1a(&self, unit: c_uint)
pub unsafe fn release_1a(&self, unit: c_uint)
Calls C++ function: void QOpenGLTexture::release(unsigned int unit).
Sourcepub unsafe fn set_auto_mip_map_generation_enabled(&self, enabled: bool)
pub unsafe fn set_auto_mip_map_generation_enabled(&self, enabled: bool)
Calls C++ function: void QOpenGLTexture::setAutoMipMapGenerationEnabled(bool enabled).
Sourcepub unsafe fn set_border_color_q_color(&self, color: impl CastInto<Ref<QColor>>)
pub unsafe fn set_border_color_q_color(&self, color: impl CastInto<Ref<QColor>>)
Calls C++ function: void QOpenGLTexture::setBorderColor(QColor color).
Sourcepub unsafe fn set_border_color_4_float(
&self,
r: c_float,
g: c_float,
b: c_float,
a: c_float,
)
pub unsafe fn set_border_color_4_float( &self, r: c_float, g: c_float, b: c_float, a: c_float, )
Calls C++ function: void QOpenGLTexture::setBorderColor(float r, float g, float b, float a).
Sourcepub unsafe fn set_border_color_4_int(
&self,
r: c_int,
g: c_int,
b: c_int,
a: c_int,
)
pub unsafe fn set_border_color_4_int( &self, r: c_int, g: c_int, b: c_int, a: c_int, )
Calls C++ function: void QOpenGLTexture::setBorderColor(int r, int g, int b, int a).
Sourcepub unsafe fn set_border_color_4_uint(
&self,
r: c_uint,
g: c_uint,
b: c_uint,
a: c_uint,
)
pub unsafe fn set_border_color_4_uint( &self, r: c_uint, g: c_uint, b: c_uint, a: c_uint, )
Calls C++ function: void QOpenGLTexture::setBorderColor(unsigned int r, unsigned int g, unsigned int b, unsigned int a).
Sourcepub unsafe fn set_comparison_function(&self, function: ComparisonFunction)
pub unsafe fn set_comparison_function(&self, function: ComparisonFunction)
Calls C++ function: void QOpenGLTexture::setComparisonFunction(QOpenGLTexture::ComparisonFunction function).
Sourcepub unsafe fn set_comparison_mode(&self, mode: ComparisonMode)
pub unsafe fn set_comparison_mode(&self, mode: ComparisonMode)
Calls C++ function: void QOpenGLTexture::setComparisonMode(QOpenGLTexture::ComparisonMode mode).
Sourcepub unsafe fn set_compressed_data_2_int_cube_map_face_int_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
data_size: c_int,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_2_int_cube_map_face_int_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, data_size: c_int, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_3_int_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
layer: c_int,
data_size: c_int,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_3_int_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, layer: c_int, data_size: c_int, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, int dataSize, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_2_int_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
data_size: c_int,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_2_int_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, data_size: c_int, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int dataSize, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_int_void_q_opengl_pixel_transfer_options(
&self,
data_size: c_int,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_int_void_q_opengl_pixel_transfer_options( &self, data_size: c_int, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int dataSize, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_2_int_cube_map_face_int_void_q_opengl_pixel_transfer_options2(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
data_size: c_int,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_2_int_cube_map_face_int_void_q_opengl_pixel_transfer_options2( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, data_size: c_int, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_3_int_cube_map_face_int_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
layer: c_int,
layer_count: c_int,
cube_face: CubeMapFace,
data_size: c_int,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_3_int_cube_map_face_int_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, layer: c_int, layer_count: c_int, cube_face: CubeMapFace, data_size: c_int, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, int layerCount, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_3_int_void_q_opengl_pixel_transfer_options2(
&self,
mip_level: c_int,
layer: c_int,
data_size: c_int,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_3_int_void_q_opengl_pixel_transfer_options2( &self, mip_level: c_int, layer: c_int, data_size: c_int, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, int dataSize, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_2_int_void_q_opengl_pixel_transfer_options2(
&self,
mip_level: c_int,
data_size: c_int,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_2_int_void_q_opengl_pixel_transfer_options2( &self, mip_level: c_int, data_size: c_int, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int dataSize, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_int_void_q_opengl_pixel_transfer_options2(
&self,
data_size: c_int,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_compressed_data_int_void_q_opengl_pixel_transfer_options2( &self, data_size: c_int, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int dataSize, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_compressed_data_2_int_cube_map_face_int_void(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
data_size: c_int,
data: *mut c_void,
)
pub unsafe fn set_compressed_data_2_int_cube_map_face_int_void( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, data_size: c_int, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, void* data).
Sourcepub unsafe fn set_compressed_data_3_int_void(
&self,
mip_level: c_int,
layer: c_int,
data_size: c_int,
data: *mut c_void,
)
pub unsafe fn set_compressed_data_3_int_void( &self, mip_level: c_int, layer: c_int, data_size: c_int, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, int dataSize, void* data).
Sourcepub unsafe fn set_compressed_data_2_int_void(
&self,
mip_level: c_int,
data_size: c_int,
data: *mut c_void,
)
pub unsafe fn set_compressed_data_2_int_void( &self, mip_level: c_int, data_size: c_int, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int dataSize, void* data).
Sourcepub unsafe fn set_compressed_data_int_void(
&self,
data_size: c_int,
data: *mut c_void,
)
pub unsafe fn set_compressed_data_int_void( &self, data_size: c_int, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int dataSize, void* data).
Sourcepub unsafe fn set_compressed_data_2_int_cube_map_face_int_void2(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
data_size: c_int,
data: *const c_void,
)
pub unsafe fn set_compressed_data_2_int_cube_map_face_int_void2( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, data_size: c_int, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, const void* data).
Sourcepub unsafe fn set_compressed_data_3_int_cube_map_face_int_void(
&self,
mip_level: c_int,
layer: c_int,
layer_count: c_int,
cube_face: CubeMapFace,
data_size: c_int,
data: *const c_void,
)
pub unsafe fn set_compressed_data_3_int_cube_map_face_int_void( &self, mip_level: c_int, layer: c_int, layer_count: c_int, cube_face: CubeMapFace, data_size: c_int, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, int layerCount, QOpenGLTexture::CubeMapFace cubeFace, int dataSize, const void* data).
Sourcepub unsafe fn set_compressed_data_3_int_void2(
&self,
mip_level: c_int,
layer: c_int,
data_size: c_int,
data: *const c_void,
)
pub unsafe fn set_compressed_data_3_int_void2( &self, mip_level: c_int, layer: c_int, data_size: c_int, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int layer, int dataSize, const void* data).
Sourcepub unsafe fn set_compressed_data_2_int_void2(
&self,
mip_level: c_int,
data_size: c_int,
data: *const c_void,
)
pub unsafe fn set_compressed_data_2_int_void2( &self, mip_level: c_int, data_size: c_int, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int mipLevel, int dataSize, const void* data).
Sourcepub unsafe fn set_compressed_data_int_void2(
&self,
data_size: c_int,
data: *const c_void,
)
pub unsafe fn set_compressed_data_int_void2( &self, data_size: c_int, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setCompressedData(int dataSize, const void* data).
Sourcepub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_2_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
layer: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_2_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, layer: c_int, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_3_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
mip_level: c_int,
layer: c_int,
layer_count: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_3_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, mip_level: c_int, layer: c_int, layer_count: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, int layerCount, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_2_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2(
&self,
mip_level: c_int,
layer: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_2_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2( &self, mip_level: c_int, layer: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2(
&self,
mip_level: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2( &self, mip_level: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2(
&self,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options2( &self, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_6_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_6_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_7_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_7_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_8_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
layer: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_8_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, layer: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_8_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_8_int_cube_map_face_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_8_int_cube_map_face_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
layer_count: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>,
)
pub unsafe fn set_data_8_int_cube_map_face_int_pixel_format_pixel_type_void_q_opengl_pixel_transfer_options( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, layer_count: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, options: impl CastInto<Ptr<QOpenGLPixelTransferOptions>>, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int layerCount, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data, const QOpenGLPixelTransferOptions* options = …).
Sourcepub unsafe fn set_data_q_image_mip_map_generation(
&self,
image: impl CastInto<Ref<QImage>>,
gen_mip_maps: MipMapGeneration,
)
pub unsafe fn set_data_q_image_mip_map_generation( &self, image: impl CastInto<Ref<QImage>>, gen_mip_maps: MipMapGeneration, )
Calls C++ function: void QOpenGLTexture::setData(const QImage& image, QOpenGLTexture::MipMapGeneration genMipMaps = …).
Sourcepub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
)
pub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data).
Sourcepub unsafe fn set_data_2_int_pixel_format_pixel_type_void(
&self,
mip_level: c_int,
layer: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
)
pub unsafe fn set_data_2_int_pixel_format_pixel_type_void( &self, mip_level: c_int, layer: c_int, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data).
Sourcepub unsafe fn set_data_int_pixel_format_pixel_type_void(
&self,
mip_level: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
)
pub unsafe fn set_data_int_pixel_format_pixel_type_void( &self, mip_level: c_int, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data).
Sourcepub unsafe fn set_data_pixel_format_pixel_type_void(
&self,
source_format: PixelFormat,
source_type: PixelType,
data: *mut c_void,
)
pub unsafe fn set_data_pixel_format_pixel_type_void( &self, source_format: PixelFormat, source_type: PixelType, data: *mut c_void, )
Calls C++ function: void QOpenGLTexture::setData(QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, void* data).
Sourcepub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void2(
&self,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_2_int_cube_map_face_pixel_format_pixel_type_void2( &self, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_3_int_cube_map_face_pixel_format_pixel_type_void(
&self,
mip_level: c_int,
layer: c_int,
layer_count: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_3_int_cube_map_face_pixel_format_pixel_type_void( &self, mip_level: c_int, layer: c_int, layer_count: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, int layerCount, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_2_int_pixel_format_pixel_type_void2(
&self,
mip_level: c_int,
layer: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_2_int_pixel_format_pixel_type_void2( &self, mip_level: c_int, layer: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_int_pixel_format_pixel_type_void2(
&self,
mip_level: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_int_pixel_format_pixel_type_void2( &self, mip_level: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_pixel_format_pixel_type_void2(
&self,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_pixel_format_pixel_type_void2( &self, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_6_int_pixel_format_pixel_type_void(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_6_int_pixel_format_pixel_type_void( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_7_int_pixel_format_pixel_type_void(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_7_int_pixel_format_pixel_type_void( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_8_int_pixel_format_pixel_type_void(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
layer: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_8_int_pixel_format_pixel_type_void( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, layer: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_8_int_cube_map_face_pixel_format_pixel_type_void(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_8_int_cube_map_face_pixel_format_pixel_type_void( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_8_int_cube_map_face_int_pixel_format_pixel_type_void(
&self,
x_offset: c_int,
y_offset: c_int,
z_offset: c_int,
width: c_int,
height: c_int,
depth: c_int,
mip_level: c_int,
layer: c_int,
cube_face: CubeMapFace,
layer_count: c_int,
source_format: PixelFormat,
source_type: PixelType,
data: *const c_void,
)
pub unsafe fn set_data_8_int_cube_map_face_int_pixel_format_pixel_type_void( &self, x_offset: c_int, y_offset: c_int, z_offset: c_int, width: c_int, height: c_int, depth: c_int, mip_level: c_int, layer: c_int, cube_face: CubeMapFace, layer_count: c_int, source_format: PixelFormat, source_type: PixelType, data: *const c_void, )
Calls C++ function: void QOpenGLTexture::setData(int xOffset, int yOffset, int zOffset, int width, int height, int depth, int mipLevel, int layer, QOpenGLTexture::CubeMapFace cubeFace, int layerCount, QOpenGLTexture::PixelFormat sourceFormat, QOpenGLTexture::PixelType sourceType, const void* data).
Sourcepub unsafe fn set_data_q_image(&self, image: impl CastInto<Ref<QImage>>)
pub unsafe fn set_data_q_image(&self, image: impl CastInto<Ref<QImage>>)
Calls C++ function: void QOpenGLTexture::setData(const QImage& image).
Sourcepub unsafe fn set_depth_stencil_mode(&self, mode: DepthStencilMode)
pub unsafe fn set_depth_stencil_mode(&self, mode: DepthStencilMode)
Calls C++ function: void QOpenGLTexture::setDepthStencilMode(QOpenGLTexture::DepthStencilMode mode).
Sourcepub unsafe fn set_fixed_sample_positions(&self, fixed: bool)
pub unsafe fn set_fixed_sample_positions(&self, fixed: bool)
Calls C++ function: void QOpenGLTexture::setFixedSamplePositions(bool fixed).
Sourcepub unsafe fn set_format(&self, format: TextureFormat)
pub unsafe fn set_format(&self, format: TextureFormat)
Calls C++ function: void QOpenGLTexture::setFormat(QOpenGLTexture::TextureFormat format).
Sourcepub unsafe fn set_layers(&self, layers: c_int)
pub unsafe fn set_layers(&self, layers: c_int)
Calls C++ function: void QOpenGLTexture::setLayers(int layers).
Sourcepub unsafe fn set_level_of_detail_range(&self, min: c_float, max: c_float)
pub unsafe fn set_level_of_detail_range(&self, min: c_float, max: c_float)
Calls C++ function: void QOpenGLTexture::setLevelOfDetailRange(float min, float max).
Sourcepub unsafe fn set_levelof_detail_bias(&self, bias: c_float)
pub unsafe fn set_levelof_detail_bias(&self, bias: c_float)
Calls C++ function: void QOpenGLTexture::setLevelofDetailBias(float bias).
Sourcepub unsafe fn set_magnification_filter(&self, filter: Filter)
pub unsafe fn set_magnification_filter(&self, filter: Filter)
Calls C++ function: void QOpenGLTexture::setMagnificationFilter(QOpenGLTexture::Filter filter).
Sourcepub unsafe fn set_maximum_anisotropy(&self, anisotropy: c_float)
pub unsafe fn set_maximum_anisotropy(&self, anisotropy: c_float)
Calls C++ function: void QOpenGLTexture::setMaximumAnisotropy(float anisotropy).
Sourcepub unsafe fn set_maximum_level_of_detail(&self, value: c_float)
pub unsafe fn set_maximum_level_of_detail(&self, value: c_float)
Calls C++ function: void QOpenGLTexture::setMaximumLevelOfDetail(float value).
Sourcepub unsafe fn set_min_mag_filters(
&self,
minification_filter: Filter,
magnification_filter: Filter,
)
pub unsafe fn set_min_mag_filters( &self, minification_filter: Filter, magnification_filter: Filter, )
Calls C++ function: void QOpenGLTexture::setMinMagFilters(QOpenGLTexture::Filter minificationFilter, QOpenGLTexture::Filter magnificationFilter).
Sourcepub unsafe fn set_minification_filter(&self, filter: Filter)
pub unsafe fn set_minification_filter(&self, filter: Filter)
Calls C++ function: void QOpenGLTexture::setMinificationFilter(QOpenGLTexture::Filter filter).
Sourcepub unsafe fn set_minimum_level_of_detail(&self, value: c_float)
pub unsafe fn set_minimum_level_of_detail(&self, value: c_float)
Calls C++ function: void QOpenGLTexture::setMinimumLevelOfDetail(float value).
Sourcepub unsafe fn set_mip_base_level(&self, base_level: c_int)
pub unsafe fn set_mip_base_level(&self, base_level: c_int)
Calls C++ function: void QOpenGLTexture::setMipBaseLevel(int baseLevel).
Sourcepub unsafe fn set_mip_level_range(&self, base_level: c_int, max_level: c_int)
pub unsafe fn set_mip_level_range(&self, base_level: c_int, max_level: c_int)
Calls C++ function: void QOpenGLTexture::setMipLevelRange(int baseLevel, int maxLevel).
Sourcepub unsafe fn set_mip_levels(&self, levels: c_int)
pub unsafe fn set_mip_levels(&self, levels: c_int)
Calls C++ function: void QOpenGLTexture::setMipLevels(int levels).
Sourcepub unsafe fn set_mip_max_level(&self, max_level: c_int)
pub unsafe fn set_mip_max_level(&self, max_level: c_int)
Calls C++ function: void QOpenGLTexture::setMipMaxLevel(int maxLevel).
Sourcepub unsafe fn set_samples(&self, samples: c_int)
pub unsafe fn set_samples(&self, samples: c_int)
Calls C++ function: void QOpenGLTexture::setSamples(int samples).
Sourcepub unsafe fn set_size_3a(&self, width: c_int, height: c_int, depth: c_int)
pub unsafe fn set_size_3a(&self, width: c_int, height: c_int, depth: c_int)
Calls C++ function: void QOpenGLTexture::setSize(int width, int height = …, int depth = …).
Sourcepub unsafe fn set_size_2a(&self, width: c_int, height: c_int)
pub unsafe fn set_size_2a(&self, width: c_int, height: c_int)
Calls C++ function: void QOpenGLTexture::setSize(int width, int height = …).
Sourcepub unsafe fn set_size_1a(&self, width: c_int)
pub unsafe fn set_size_1a(&self, width: c_int)
Calls C++ function: void QOpenGLTexture::setSize(int width).
Sourcepub unsafe fn set_swizzle_mask_2a(
&self,
component: SwizzleComponent,
value: SwizzleValue,
)
pub unsafe fn set_swizzle_mask_2a( &self, component: SwizzleComponent, value: SwizzleValue, )
Calls C++ function: void QOpenGLTexture::setSwizzleMask(QOpenGLTexture::SwizzleComponent component, QOpenGLTexture::SwizzleValue value).
Sourcepub unsafe fn set_swizzle_mask_4a(
&self,
r: SwizzleValue,
g: SwizzleValue,
b: SwizzleValue,
a: SwizzleValue,
)
pub unsafe fn set_swizzle_mask_4a( &self, r: SwizzleValue, g: SwizzleValue, b: SwizzleValue, a: SwizzleValue, )
Calls C++ function: void QOpenGLTexture::setSwizzleMask(QOpenGLTexture::SwizzleValue r, QOpenGLTexture::SwizzleValue g, QOpenGLTexture::SwizzleValue b, QOpenGLTexture::SwizzleValue a).
Sourcepub unsafe fn set_wrap_mode_1a(&self, mode: WrapMode)
pub unsafe fn set_wrap_mode_1a(&self, mode: WrapMode)
Calls C++ function: void QOpenGLTexture::setWrapMode(QOpenGLTexture::WrapMode mode).
Sourcepub unsafe fn set_wrap_mode_2a(
&self,
direction: CoordinateDirection,
mode: WrapMode,
)
pub unsafe fn set_wrap_mode_2a( &self, direction: CoordinateDirection, mode: WrapMode, )
Calls C++ function: void QOpenGLTexture::setWrapMode(QOpenGLTexture::CoordinateDirection direction, QOpenGLTexture::WrapMode mode).
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn swizzle_mask(&self, component: SwizzleComponent) -> SwizzleValue
pub unsafe fn swizzle_mask(&self, component: SwizzleComponent) -> SwizzleValue
Calls C++ function: QOpenGLTexture::SwizzleValue QOpenGLTexture::swizzleMask(QOpenGLTexture::SwizzleComponent component) const.
Sourcepub unsafe fn target(&self) -> Target
pub unsafe fn target(&self) -> Target
Calls C++ function: QOpenGLTexture::Target QOpenGLTexture::target() const.
Sourcepub unsafe fn texture_id(&self) -> c_uint
pub unsafe fn texture_id(&self) -> c_uint
Calls C++ function: unsigned int QOpenGLTexture::textureId() const.
Sourcepub unsafe fn wrap_mode(&self, direction: CoordinateDirection) -> WrapMode
pub unsafe fn wrap_mode(&self, direction: CoordinateDirection) -> WrapMode
Calls C++ function: QOpenGLTexture::WrapMode QOpenGLTexture::wrapMode(QOpenGLTexture::CoordinateDirection direction) const.