pub struct QScreen { /* private fields */ }Expand description
C++ class: QScreen.
Implementations
Sourceimpl QScreen
impl QScreen
Sourcepub fn geometry_changed(&self) -> Signal<(*const QRect,)>
pub fn geometry_changed(&self) -> Signal<(*const QRect,)>
Returns a built-in Qt signal QScreen::geometryChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn available_geometry_changed(&self) -> Signal<(*const QRect,)>
pub fn available_geometry_changed(&self) -> Signal<(*const QRect,)>
Returns a built-in Qt signal QScreen::availableGeometryChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn physical_size_changed(&self) -> Signal<(*const QSizeF,)>
pub fn physical_size_changed(&self) -> Signal<(*const QSizeF,)>
Returns a built-in Qt signal QScreen::physicalSizeChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn physical_dots_per_inch_changed(&self) -> Signal<(c_double,)>
pub fn physical_dots_per_inch_changed(&self) -> Signal<(c_double,)>
Returns a built-in Qt signal QScreen::physicalDotsPerInchChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn logical_dots_per_inch_changed(&self) -> Signal<(c_double,)>
pub fn logical_dots_per_inch_changed(&self) -> Signal<(c_double,)>
Returns a built-in Qt signal QScreen::logicalDotsPerInchChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn virtual_geometry_changed(&self) -> Signal<(*const QRect,)>
pub fn virtual_geometry_changed(&self) -> Signal<(*const QRect,)>
Returns a built-in Qt signal QScreen::virtualGeometryChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn primary_orientation_changed(&self) -> Signal<(ScreenOrientation,)>
pub fn primary_orientation_changed(&self) -> Signal<(ScreenOrientation,)>
Returns a built-in Qt signal QScreen::primaryOrientationChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn orientation_changed(&self) -> Signal<(ScreenOrientation,)>
pub fn orientation_changed(&self) -> Signal<(ScreenOrientation,)>
Returns a built-in Qt signal QScreen::orientationChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn refresh_rate_changed(&self) -> Signal<(c_double,)>
pub fn refresh_rate_changed(&self) -> Signal<(c_double,)>
Returns a built-in Qt signal QScreen::refreshRateChanged that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn angle_between(
&self,
a: ScreenOrientation,
b: ScreenOrientation,
) -> c_int
pub unsafe fn angle_between( &self, a: ScreenOrientation, b: ScreenOrientation, ) -> c_int
Calls C++ function: int QScreen::angleBetween(Qt::ScreenOrientation a, Qt::ScreenOrientation b) const.
Sourcepub unsafe fn available_geometry(&self) -> CppBox<QRect>
pub unsafe fn available_geometry(&self) -> CppBox<QRect>
Calls C++ function: QRect QScreen::availableGeometry() const.
Sourcepub unsafe fn available_size(&self) -> CppBox<QSize>
pub unsafe fn available_size(&self) -> CppBox<QSize>
Calls C++ function: QSize QScreen::availableSize() const.
Sourcepub unsafe fn available_virtual_geometry(&self) -> CppBox<QRect>
pub unsafe fn available_virtual_geometry(&self) -> CppBox<QRect>
Calls C++ function: QRect QScreen::availableVirtualGeometry() const.
Sourcepub unsafe fn available_virtual_size(&self) -> CppBox<QSize>
pub unsafe fn available_virtual_size(&self) -> CppBox<QSize>
Calls C++ function: QSize QScreen::availableVirtualSize() const.
Sourcepub unsafe fn device_pixel_ratio(&self) -> c_double
pub unsafe fn device_pixel_ratio(&self) -> c_double
Calls C++ function: double QScreen::devicePixelRatio() const.
Sourcepub unsafe fn geometry(&self) -> CppBox<QRect>
pub unsafe fn geometry(&self) -> CppBox<QRect>
Calls C++ function: QRect QScreen::geometry() const.
Sourcepub unsafe fn grab_window_5a(
&self,
window: c_ulonglong,
x: c_int,
y: c_int,
w: c_int,
h: c_int,
) -> CppBox<QPixmap>
pub unsafe fn grab_window_5a( &self, window: c_ulonglong, x: c_int, y: c_int, w: c_int, h: c_int, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QScreen::grabWindow(unsigned long long window, int x = …, int y = …, int w = …, int h = …).
Sourcepub unsafe fn grab_window_4a(
&self,
window: c_ulonglong,
x: c_int,
y: c_int,
w: c_int,
) -> CppBox<QPixmap>
pub unsafe fn grab_window_4a( &self, window: c_ulonglong, x: c_int, y: c_int, w: c_int, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QScreen::grabWindow(unsigned long long window, int x = …, int y = …, int w = …).
Sourcepub unsafe fn grab_window_3a(
&self,
window: c_ulonglong,
x: c_int,
y: c_int,
) -> CppBox<QPixmap>
pub unsafe fn grab_window_3a( &self, window: c_ulonglong, x: c_int, y: c_int, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QScreen::grabWindow(unsigned long long window, int x = …, int y = …).
Sourcepub unsafe fn grab_window_2a(
&self,
window: c_ulonglong,
x: c_int,
) -> CppBox<QPixmap>
pub unsafe fn grab_window_2a( &self, window: c_ulonglong, x: c_int, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QScreen::grabWindow(unsigned long long window, int x = …).
Sourcepub unsafe fn grab_window_1a(&self, window: c_ulonglong) -> CppBox<QPixmap>
pub unsafe fn grab_window_1a(&self, window: c_ulonglong) -> CppBox<QPixmap>
Calls C++ function: QPixmap QScreen::grabWindow(unsigned long long window).
Sourcepub unsafe fn is_landscape(&self, orientation: ScreenOrientation) -> bool
pub unsafe fn is_landscape(&self, orientation: ScreenOrientation) -> bool
Calls C++ function: bool QScreen::isLandscape(Qt::ScreenOrientation orientation) const.
Sourcepub unsafe fn is_portrait(&self, orientation: ScreenOrientation) -> bool
pub unsafe fn is_portrait(&self, orientation: ScreenOrientation) -> bool
Calls C++ function: bool QScreen::isPortrait(Qt::ScreenOrientation orientation) const.
Sourcepub unsafe fn logical_dots_per_inch(&self) -> c_double
pub unsafe fn logical_dots_per_inch(&self) -> c_double
Calls C++ function: double QScreen::logicalDotsPerInch() const.
Sourcepub unsafe fn logical_dots_per_inch_x(&self) -> c_double
pub unsafe fn logical_dots_per_inch_x(&self) -> c_double
Calls C++ function: double QScreen::logicalDotsPerInchX() const.
Sourcepub unsafe fn logical_dots_per_inch_y(&self) -> c_double
pub unsafe fn logical_dots_per_inch_y(&self) -> c_double
Calls C++ function: double QScreen::logicalDotsPerInchY() const.
Sourcepub unsafe fn manufacturer(&self) -> CppBox<QString>
pub unsafe fn manufacturer(&self) -> CppBox<QString>
Calls C++ function: QString QScreen::manufacturer() const.
Sourcepub unsafe fn map_between(
&self,
a: ScreenOrientation,
b: ScreenOrientation,
rect: impl CastInto<Ref<QRect>>,
) -> CppBox<QRect>
pub unsafe fn map_between( &self, a: ScreenOrientation, b: ScreenOrientation, rect: impl CastInto<Ref<QRect>>, ) -> CppBox<QRect>
Calls C++ function: QRect QScreen::mapBetween(Qt::ScreenOrientation a, Qt::ScreenOrientation b, const QRect& rect) const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QScreen::metaObject() const.
Sourcepub unsafe fn model(&self) -> CppBox<QString>
pub unsafe fn model(&self) -> CppBox<QString>
Calls C++ function: QString QScreen::model() const.
Sourcepub unsafe fn name(&self) -> CppBox<QString>
pub unsafe fn name(&self) -> CppBox<QString>
Calls C++ function: QString QScreen::name() const.
Sourcepub unsafe fn native_orientation(&self) -> ScreenOrientation
pub unsafe fn native_orientation(&self) -> ScreenOrientation
Calls C++ function: Qt::ScreenOrientation QScreen::nativeOrientation() const.
Sourcepub unsafe fn orientation(&self) -> ScreenOrientation
pub unsafe fn orientation(&self) -> ScreenOrientation
Calls C++ function: Qt::ScreenOrientation QScreen::orientation() const.
Sourcepub unsafe fn orientation_update_mask(&self) -> QFlags<ScreenOrientation>
pub unsafe fn orientation_update_mask(&self) -> QFlags<ScreenOrientation>
Calls C++ function: QFlags<Qt::ScreenOrientation> QScreen::orientationUpdateMask() const.
Sourcepub unsafe fn physical_dots_per_inch(&self) -> c_double
pub unsafe fn physical_dots_per_inch(&self) -> c_double
Calls C++ function: double QScreen::physicalDotsPerInch() const.
Sourcepub unsafe fn physical_dots_per_inch_x(&self) -> c_double
pub unsafe fn physical_dots_per_inch_x(&self) -> c_double
Calls C++ function: double QScreen::physicalDotsPerInchX() const.
Sourcepub unsafe fn physical_dots_per_inch_y(&self) -> c_double
pub unsafe fn physical_dots_per_inch_y(&self) -> c_double
Calls C++ function: double QScreen::physicalDotsPerInchY() const.
Sourcepub unsafe fn physical_size(&self) -> CppBox<QSizeF>
pub unsafe fn physical_size(&self) -> CppBox<QSizeF>
Calls C++ function: QSizeF QScreen::physicalSize() const.
Sourcepub unsafe fn primary_orientation(&self) -> ScreenOrientation
pub unsafe fn primary_orientation(&self) -> ScreenOrientation
Calls C++ function: Qt::ScreenOrientation QScreen::primaryOrientation() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QScreen::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QScreen::qt_metacast(const char* arg1).
Sourcepub unsafe fn refresh_rate(&self) -> c_double
pub unsafe fn refresh_rate(&self) -> c_double
Calls C++ function: double QScreen::refreshRate() const.
Sourcepub unsafe fn serial_number(&self) -> CppBox<QString>
pub unsafe fn serial_number(&self) -> CppBox<QString>
Calls C++ function: QString QScreen::serialNumber() const.
Sourcepub unsafe fn set_orientation_update_mask(
&self,
mask: QFlags<ScreenOrientation>,
)
pub unsafe fn set_orientation_update_mask( &self, mask: QFlags<ScreenOrientation>, )
Calls C++ function: void QScreen::setOrientationUpdateMask(QFlags<Qt::ScreenOrientation> mask).
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn tr(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QScreen::tr(const char* s, const char* c, int n).
Sourcepub unsafe fn tr_utf8(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QScreen::trUtf8(const char* s, const char* c, int n).
Sourcepub unsafe fn transform_between(
&self,
a: ScreenOrientation,
b: ScreenOrientation,
target: impl CastInto<Ref<QRect>>,
) -> CppBox<QTransform>
pub unsafe fn transform_between( &self, a: ScreenOrientation, b: ScreenOrientation, target: impl CastInto<Ref<QRect>>, ) -> CppBox<QTransform>
Calls C++ function: QTransform QScreen::transformBetween(Qt::ScreenOrientation a, Qt::ScreenOrientation b, const QRect& target) const.
Sourcepub unsafe fn virtual_geometry(&self) -> CppBox<QRect>
pub unsafe fn virtual_geometry(&self) -> CppBox<QRect>
Calls C++ function: QRect QScreen::virtualGeometry() const.
Sourcepub unsafe fn virtual_sibling_at(
&self,
point: impl CastInto<Ref<QPoint>>,
) -> QPtr<QScreen>
pub unsafe fn virtual_sibling_at( &self, point: impl CastInto<Ref<QPoint>>, ) -> QPtr<QScreen>
Calls C++ function: QScreen* QScreen::virtualSiblingAt(QPoint point).
Sourcepub unsafe fn virtual_siblings(&self) -> CppBox<QListOfQScreen>
pub unsafe fn virtual_siblings(&self) -> CppBox<QListOfQScreen>
Calls C++ function: QList<QScreen*> QScreen::virtualSiblings() const.
Sourcepub unsafe fn virtual_size(&self) -> CppBox<QSize>
pub unsafe fn virtual_size(&self) -> CppBox<QSize>
Calls C++ function: QSize QScreen::virtualSize() const.
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const i8) -> bool
pub unsafe fn inherits(&self, classname: *const i8) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: i32)
pub unsafe fn kill_timer(&self, id: i32)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: i32,
arg3: *mut *mut c_void,
) -> i32
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const i8,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: i32) -> i32
pub unsafe fn start_timer_1a(&self, interval: i32) -> i32
Calls C++ function: int QObject::startTimer(int interval).