QTextTable

Struct QTextTable 

pub struct QTextTable { /* private fields */ }
C++ class: QTextTable.

Implementations

Source

impl QTextTable

pub unsafe fn append_columns(&self, count: c_int)

Calls C++ function: void QTextTable::appendColumns(int count).

pub unsafe fn append_rows(&self, count: c_int)

Calls C++ function: void QTextTable::appendRows(int count).

pub unsafe fn cell_at_2_int( &self, row: c_int, col: c_int, ) -> CppBox<QTextTableCell>

Calls C++ function: QTextTableCell QTextTable::cellAt(int row, int col) const.

pub unsafe fn cell_at_int(&self, position: c_int) -> CppBox<QTextTableCell>

Calls C++ function: QTextTableCell QTextTable::cellAt(int position) const.

pub unsafe fn cell_at_q_text_cursor( &self, c: impl CastInto<Ref<QTextCursor>>, ) -> CppBox<QTextTableCell>

Calls C++ function: QTextTableCell QTextTable::cellAt(const QTextCursor& c) const.

pub unsafe fn columns(&self) -> c_int

Calls C++ function: int QTextTable::columns() const.

pub unsafe fn format(&self) -> CppBox<QTextTableFormat>

Calls C++ function: QTextTableFormat QTextTable::format() const.

pub unsafe fn insert_columns(&self, pos: c_int, num: c_int)

Calls C++ function: void QTextTable::insertColumns(int pos, int num).

pub unsafe fn insert_rows(&self, pos: c_int, num: c_int)

Calls C++ function: void QTextTable::insertRows(int pos, int num).

pub unsafe fn merge_cells_4a( &self, row: c_int, col: c_int, num_rows: c_int, num_cols: c_int, )

Calls C++ function: void QTextTable::mergeCells(int row, int col, int numRows, int numCols).

pub unsafe fn merge_cells_1a(&self, cursor: impl CastInto<Ref<QTextCursor>>)

Calls C++ function: void QTextTable::mergeCells(const QTextCursor& cursor).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QTextTable::metaObject() const.

pub unsafe fn new(doc: impl CastInto<Ptr<QTextDocument>>) -> QBox<QTextTable>

Calls C++ function: [constructor] void QTextTable::QTextTable(QTextDocument* doc).

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QTextTable::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QTextTable::qt_metacast(const char* arg1).

pub unsafe fn remove_columns(&self, pos: c_int, num: c_int)

Calls C++ function: void QTextTable::removeColumns(int pos, int num).

pub unsafe fn remove_rows(&self, pos: c_int, num: c_int)

Calls C++ function: void QTextTable::removeRows(int pos, int num).

pub unsafe fn resize(&self, rows: c_int, cols: c_int)

Calls C++ function: void QTextTable::resize(int rows, int cols).

pub unsafe fn row_end( &self, c: impl CastInto<Ref<QTextCursor>>, ) -> CppBox<QTextCursor>

Calls C++ function: QTextCursor QTextTable::rowEnd(const QTextCursor& c) const.

pub unsafe fn row_start( &self, c: impl CastInto<Ref<QTextCursor>>, ) -> CppBox<QTextCursor>

Calls C++ function: QTextCursor QTextTable::rowStart(const QTextCursor& c) const.

pub unsafe fn rows(&self) -> c_int

Calls C++ function: int QTextTable::rows() const.

pub unsafe fn set_format(&self, format: impl CastInto<Ref<QTextTableFormat>>)

Calls C++ function: void QTextTable::setFormat(const QTextTableFormat& format).

pub unsafe fn split_cell( &self, row: c_int, col: c_int, num_rows: c_int, num_cols: c_int, )

Calls C++ function: void QTextTable::splitCell(int row, int col, int numRows, int numCols).

pub unsafe fn static_meta_object() -> Ref<QMetaObject>

Returns a reference to the staticMetaObject field.

pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QTextTable::tr(const char* s, const char* c, int n).

pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>

Calls C++ function: static QString QTextTable::trUtf8(const char* s, const char* c, int n).

Methods from Deref<Target = QTextFrame>

pub unsafe fn begin(&self) -> CppBox<Iterator>

Calls C++ function: QTextFrame::iterator QTextFrame::begin() const.

pub unsafe fn child_frames(&self) -> CppBox<QListOfQTextFrame>

Calls C++ function: QList<QTextFrame*> QTextFrame::childFrames() const.

pub unsafe fn end(&self) -> CppBox<Iterator>

Calls C++ function: QTextFrame::iterator QTextFrame::end() const.

pub unsafe fn first_cursor_position(&self) -> CppBox<QTextCursor>

Calls C++ function: QTextCursor QTextFrame::firstCursorPosition() const.

pub unsafe fn first_position(&self) -> c_int

Calls C++ function: int QTextFrame::firstPosition() const.

pub unsafe fn frame_format(&self) -> CppBox<QTextFrameFormat>

Calls C++ function: QTextFrameFormat QTextFrame::frameFormat() const.

pub unsafe fn last_cursor_position(&self) -> CppBox<QTextCursor>

Calls C++ function: QTextCursor QTextFrame::lastCursorPosition() const.

pub unsafe fn last_position(&self) -> c_int

Calls C++ function: int QTextFrame::lastPosition() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QTextFrame::metaObject() const.

pub unsafe fn parent_frame(&self) -> QPtr<QTextFrame>

Calls C++ function: QTextFrame* QTextFrame::parentFrame() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QTextFrame::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QTextFrame::qt_metacast(const char* arg1).

pub unsafe fn set_frame_format( &self, format: impl CastInto<Ref<QTextFrameFormat>>, )

Calls C++ function: void QTextFrame::setFrameFormat(const QTextFrameFormat& format).

Methods from Deref<Target = QTextObject>

pub unsafe fn document(&self) -> QPtr<QTextDocument>

Calls C++ function: QTextDocument* QTextObject::document() const.

pub unsafe fn format(&self) -> CppBox<QTextFormat>

Calls C++ function: QTextFormat QTextObject::format() const.

pub unsafe fn format_index(&self) -> c_int

Calls C++ function: int QTextObject::formatIndex() const.

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QTextObject::metaObject() const.

pub unsafe fn object_index(&self) -> c_int

Calls C++ function: int QTextObject::objectIndex() const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int

Calls C++ function: virtual int QTextObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void

Calls C++ function: virtual void* QTextObject::qt_metacast(const char* arg1).

Methods from Deref<Target = QObject>

pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>

Finds a child of self with the specified object name and casts it to type T.

The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.

Returns an error if there is no child object with object name name or the found object cannot be cast to T.

pub fn destroyed(&self) -> Signal<(*mut QObject,)>

Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.

pub fn object_name_changed(&self) -> Signal<(*const QString,)>

Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.

pub fn slot_delete_later(&self) -> Receiver<()>

Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.

pub unsafe fn block_signals(&self, b: bool) -> bool

Calls C++ function: bool QObject::blockSignals(bool b).

pub unsafe fn children(&self) -> Ref<QListOfQObject>

Calls C++ function: const QList<QObject*>& QObject::children() const.

pub unsafe fn delete_later(&self)

Calls C++ function: [slot] void QObject::deleteLater().

pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.

pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.

pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.

pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool

Calls C++ function: bool QObject::disconnect(const char* signal = …) const.

pub unsafe fn disconnect(&self) -> bool

Calls C++ function: bool QObject::disconnect() const.

pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool

Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.

pub unsafe fn dump_object_info_mut(&self)

Calls C++ function: void QObject::dumpObjectInfo().

pub unsafe fn dump_object_info(&self)

Calls C++ function: void QObject::dumpObjectInfo() const.

pub unsafe fn dump_object_tree_mut(&self)

Calls C++ function: void QObject::dumpObjectTree().

pub unsafe fn dump_object_tree(&self)

Calls C++ function: void QObject::dumpObjectTree() const.

pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>

Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.

pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool

Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).

pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool

Calls C++ function: virtual bool QObject::event(QEvent* event).

pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool

Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).

pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.

pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::findChild<QObject*>() const.

pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.

pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.

pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.

pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.

pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>

Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.

pub unsafe fn inherits(&self, classname: *const i8) -> bool

Calls C++ function: bool QObject::inherits(const char* classname) const.

pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )

Calls C++ function: void QObject::installEventFilter(QObject* filterObj).

pub unsafe fn is_widget_type(&self) -> bool

Calls C++ function: bool QObject::isWidgetType() const.

pub unsafe fn is_window_type(&self) -> bool

Calls C++ function: bool QObject::isWindowType() const.

pub unsafe fn kill_timer(&self, id: i32)

Calls C++ function: void QObject::killTimer(int id).

pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>

Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.

pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)

Calls C++ function: void QObject::moveToThread(QThread* thread).

pub unsafe fn object_name(&self) -> CppBox<QString>

Calls C++ function: QString QObject::objectName() const.

pub unsafe fn parent(&self) -> QPtr<QObject>

Calls C++ function: QObject* QObject::parent() const.

pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>

Calls C++ function: QVariant QObject::property(const char* name) const.

pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32

Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).

pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void

Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).

pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::removeEventFilter(QObject* obj).

pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)

Calls C++ function: void QObject::setObjectName(const QString& name).

pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)

Calls C++ function: void QObject::setParent(QObject* parent).

pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool

Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).

pub unsafe fn signals_blocked(&self) -> bool

Calls C++ function: bool QObject::signalsBlocked() const.

pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32

Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).

pub unsafe fn start_timer_1a(&self, interval: i32) -> i32

Calls C++ function: int QObject::startTimer(int interval).

pub unsafe fn thread(&self) -> QPtr<QThread>

Calls C++ function: QThread* QObject::thread() const.