pub struct QWindow { /* private fields */ }Expand description
C++ class: QWindow.
Implementations
Sourceimpl QWindow
impl QWindow
Sourcepub fn slot_request_activate(&self) -> Receiver<()>
pub fn slot_request_activate(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::requestActivate that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_visible(&self) -> Receiver<(bool,)>
pub fn slot_set_visible(&self) -> Receiver<(bool,)>
Returns a built-in Qt slot QWindow::setVisible that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_show(&self) -> Receiver<()>
pub fn slot_show(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::show that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_hide(&self) -> Receiver<()>
pub fn slot_hide(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::hide that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_show_minimized(&self) -> Receiver<()>
pub fn slot_show_minimized(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::showMinimized that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_show_maximized(&self) -> Receiver<()>
pub fn slot_show_maximized(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::showMaximized that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_show_full_screen(&self) -> Receiver<()>
pub fn slot_show_full_screen(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::showFullScreen that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_show_normal(&self) -> Receiver<()>
pub fn slot_show_normal(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::showNormal that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_close(&self) -> Receiver<()>
pub fn slot_close(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::close that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_raise(&self) -> Receiver<()>
pub fn slot_raise(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::raise that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_lower(&self) -> Receiver<()>
pub fn slot_lower(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::lower that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_start_system_resize(&self) -> Receiver<(c_int,)>
pub fn slot_start_system_resize(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::startSystemResize that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_start_system_move(&self) -> Receiver<()>
pub fn slot_start_system_move(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::startSystemMove that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_title(&self) -> Receiver<(*const QString,)>
pub fn slot_set_title(&self) -> Receiver<(*const QString,)>
Returns a built-in Qt slot QWindow::setTitle that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_x(&self) -> Receiver<(c_int,)>
pub fn slot_set_x(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setX that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_y(&self) -> Receiver<(c_int,)>
pub fn slot_set_y(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setY that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_width(&self) -> Receiver<(c_int,)>
pub fn slot_set_width(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setWidth that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_height(&self) -> Receiver<(c_int,)>
pub fn slot_set_height(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setHeight that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_geometry(&self) -> Receiver<(c_int, c_int, c_int, c_int)>
pub fn slot_set_geometry(&self) -> Receiver<(c_int, c_int, c_int, c_int)>
Returns a built-in Qt slot QWindow::setGeometry that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_geometry2(&self) -> Receiver<(*const QRect,)>
pub fn slot_set_geometry2(&self) -> Receiver<(*const QRect,)>
Returns a built-in Qt slot QWindow::setGeometry that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_minimum_width(&self) -> Receiver<(c_int,)>
pub fn slot_set_minimum_width(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setMinimumWidth that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_minimum_height(&self) -> Receiver<(c_int,)>
pub fn slot_set_minimum_height(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setMinimumHeight that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_maximum_width(&self) -> Receiver<(c_int,)>
pub fn slot_set_maximum_width(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setMaximumWidth that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_maximum_height(&self) -> Receiver<(c_int,)>
pub fn slot_set_maximum_height(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::setMaximumHeight that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_alert(&self) -> Receiver<(c_int,)>
pub fn slot_alert(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QWindow::alert that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_request_update(&self) -> Receiver<()>
pub fn slot_request_update(&self) -> Receiver<()>
Returns a built-in Qt slot QWindow::requestUpdate that can be passed to qt_core::Signal::connect.
Sourcepub fn screen_changed(&self) -> Signal<(*mut QScreen,)>
pub fn screen_changed(&self) -> Signal<(*mut QScreen,)>
Returns a built-in Qt signal QWindow::screenChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn modality_changed(&self) -> Signal<(WindowModality,)>
pub fn modality_changed(&self) -> Signal<(WindowModality,)>
Returns a built-in Qt signal QWindow::modalityChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn window_state_changed(&self) -> Signal<(WindowState,)>
pub fn window_state_changed(&self) -> Signal<(WindowState,)>
Returns a built-in Qt signal QWindow::windowStateChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn window_title_changed(&self) -> Signal<(*const QString,)>
pub fn window_title_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QWindow::windowTitleChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn x_changed(&self) -> Signal<(c_int,)>
pub fn x_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::xChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn y_changed(&self) -> Signal<(c_int,)>
pub fn y_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::yChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn width_changed(&self) -> Signal<(c_int,)>
pub fn width_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::widthChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn height_changed(&self) -> Signal<(c_int,)>
pub fn height_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::heightChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn minimum_width_changed(&self) -> Signal<(c_int,)>
pub fn minimum_width_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::minimumWidthChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn minimum_height_changed(&self) -> Signal<(c_int,)>
pub fn minimum_height_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::minimumHeightChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn maximum_width_changed(&self) -> Signal<(c_int,)>
pub fn maximum_width_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::maximumWidthChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn maximum_height_changed(&self) -> Signal<(c_int,)>
pub fn maximum_height_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QWindow::maximumHeightChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn visible_changed(&self) -> Signal<(bool,)>
pub fn visible_changed(&self) -> Signal<(bool,)>
Returns a built-in Qt signal QWindow::visibleChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn visibility_changed(&self) -> Signal<(Visibility,)>
pub fn visibility_changed(&self) -> Signal<(Visibility,)>
Returns a built-in Qt signal QWindow::visibilityChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn active_changed(&self) -> Signal<()>
pub fn active_changed(&self) -> Signal<()>
Returns a built-in Qt signal QWindow::activeChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn content_orientation_changed(&self) -> Signal<(ScreenOrientation,)>
pub fn content_orientation_changed(&self) -> Signal<(ScreenOrientation,)>
Returns a built-in Qt signal QWindow::contentOrientationChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn focus_object_changed(&self) -> Signal<(*mut QObject,)>
pub fn focus_object_changed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QWindow::focusObjectChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn opacity_changed(&self) -> Signal<(c_double,)>
pub fn opacity_changed(&self) -> Signal<(c_double,)>
Returns a built-in Qt signal QWindow::opacityChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn transient_parent_changed(&self) -> Signal<(*mut QWindow,)>
pub fn transient_parent_changed(&self) -> Signal<(*mut QWindow,)>
Returns a built-in Qt signal QWindow::transientParentChanged that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn accessible_root(&self) -> Ptr<QAccessibleInterface>
pub unsafe fn accessible_root(&self) -> Ptr<QAccessibleInterface>
Calls C++ function: virtual QAccessibleInterface* QWindow::accessibleRoot() const.
Sourcepub unsafe fn alert(&self, msec: c_int)
pub unsafe fn alert(&self, msec: c_int)
Calls C++ function: [slot] void QWindow::alert(int msec).
Sourcepub unsafe fn base_size(&self) -> CppBox<QSize>
pub unsafe fn base_size(&self) -> CppBox<QSize>
Calls C++ function: QSize QWindow::baseSize() const.
Sourcepub unsafe fn content_orientation(&self) -> ScreenOrientation
pub unsafe fn content_orientation(&self) -> ScreenOrientation
Calls C++ function: Qt::ScreenOrientation QWindow::contentOrientation() const.
Sourcepub unsafe fn cursor(&self) -> CppBox<QCursor>
pub unsafe fn cursor(&self) -> CppBox<QCursor>
Calls C++ function: QCursor QWindow::cursor() const.
Sourcepub unsafe fn device_pixel_ratio(&self) -> c_double
pub unsafe fn device_pixel_ratio(&self) -> c_double
Calls C++ function: double QWindow::devicePixelRatio() const.
Sourcepub unsafe fn file_path(&self) -> CppBox<QString>
pub unsafe fn file_path(&self) -> CppBox<QString>
Calls C++ function: QString QWindow::filePath() const.
Sourcepub unsafe fn flags(&self) -> QFlags<WindowType>
pub unsafe fn flags(&self) -> QFlags<WindowType>
Calls C++ function: QFlags<Qt::WindowType> QWindow::flags() const.
Sourcepub unsafe fn focus_object(&self) -> QPtr<QObject>
pub unsafe fn focus_object(&self) -> QPtr<QObject>
Calls C++ function: virtual QObject* QWindow::focusObject() const.
Sourcepub unsafe fn format(&self) -> CppBox<QSurfaceFormat>
pub unsafe fn format(&self) -> CppBox<QSurfaceFormat>
Calls C++ function: virtual QSurfaceFormat QWindow::format() const.
Sourcepub unsafe fn frame_geometry(&self) -> CppBox<QRect>
pub unsafe fn frame_geometry(&self) -> CppBox<QRect>
Calls C++ function: QRect QWindow::frameGeometry() const.
Sourcepub unsafe fn frame_margins(&self) -> CppBox<QMargins>
pub unsafe fn frame_margins(&self) -> CppBox<QMargins>
Calls C++ function: QMargins QWindow::frameMargins() const.
Sourcepub unsafe fn frame_position(&self) -> CppBox<QPoint>
pub unsafe fn frame_position(&self) -> CppBox<QPoint>
Calls C++ function: QPoint QWindow::framePosition() const.
Sourcepub unsafe fn from_win_id(id: c_ulonglong) -> QPtr<QWindow>
pub unsafe fn from_win_id(id: c_ulonglong) -> QPtr<QWindow>
Calls C++ function: static QWindow* QWindow::fromWinId(unsigned long long id).
Sourcepub unsafe fn geometry(&self) -> CppBox<QRect>
pub unsafe fn geometry(&self) -> CppBox<QRect>
Calls C++ function: QRect QWindow::geometry() const.
Sourcepub unsafe fn is_ancestor_of_2a(
&self,
child: impl CastInto<Ptr<QWindow>>,
mode: AncestorMode,
) -> bool
pub unsafe fn is_ancestor_of_2a( &self, child: impl CastInto<Ptr<QWindow>>, mode: AncestorMode, ) -> bool
Calls C++ function: bool QWindow::isAncestorOf(const QWindow* child, QWindow::AncestorMode mode = …) const.
Sourcepub unsafe fn is_ancestor_of_1a(
&self,
child: impl CastInto<Ptr<QWindow>>,
) -> bool
pub unsafe fn is_ancestor_of_1a( &self, child: impl CastInto<Ptr<QWindow>>, ) -> bool
Calls C++ function: bool QWindow::isAncestorOf(const QWindow* child) const.
Sourcepub unsafe fn is_exposed(&self) -> bool
pub unsafe fn is_exposed(&self) -> bool
Calls C++ function: bool QWindow::isExposed() const.
Sourcepub unsafe fn is_top_level(&self) -> bool
pub unsafe fn is_top_level(&self) -> bool
Calls C++ function: bool QWindow::isTopLevel() const.
Sourcepub unsafe fn is_visible(&self) -> bool
pub unsafe fn is_visible(&self) -> bool
Calls C++ function: bool QWindow::isVisible() const.
Sourcepub unsafe fn map_from_global(
&self,
pos: impl CastInto<Ref<QPoint>>,
) -> CppBox<QPoint>
pub unsafe fn map_from_global( &self, pos: impl CastInto<Ref<QPoint>>, ) -> CppBox<QPoint>
Calls C++ function: QPoint QWindow::mapFromGlobal(const QPoint& pos) const.
Sourcepub unsafe fn map_to_global(
&self,
pos: impl CastInto<Ref<QPoint>>,
) -> CppBox<QPoint>
pub unsafe fn map_to_global( &self, pos: impl CastInto<Ref<QPoint>>, ) -> CppBox<QPoint>
Calls C++ function: QPoint QWindow::mapToGlobal(const QPoint& pos) const.
Sourcepub unsafe fn mask(&self) -> CppBox<QRegion>
pub unsafe fn mask(&self) -> CppBox<QRegion>
Calls C++ function: QRegion QWindow::mask() const.
Sourcepub unsafe fn maximum_height(&self) -> c_int
pub unsafe fn maximum_height(&self) -> c_int
Calls C++ function: int QWindow::maximumHeight() const.
Sourcepub unsafe fn maximum_size(&self) -> CppBox<QSize>
pub unsafe fn maximum_size(&self) -> CppBox<QSize>
Calls C++ function: QSize QWindow::maximumSize() const.
Sourcepub unsafe fn maximum_width(&self) -> c_int
pub unsafe fn maximum_width(&self) -> c_int
Calls C++ function: int QWindow::maximumWidth() const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QWindow::metaObject() const.
Sourcepub unsafe fn minimum_height(&self) -> c_int
pub unsafe fn minimum_height(&self) -> c_int
Calls C++ function: int QWindow::minimumHeight() const.
Sourcepub unsafe fn minimum_size(&self) -> CppBox<QSize>
pub unsafe fn minimum_size(&self) -> CppBox<QSize>
Calls C++ function: QSize QWindow::minimumSize() const.
Sourcepub unsafe fn minimum_width(&self) -> c_int
pub unsafe fn minimum_width(&self) -> c_int
Calls C++ function: int QWindow::minimumWidth() const.
Sourcepub unsafe fn modality(&self) -> WindowModality
pub unsafe fn modality(&self) -> WindowModality
Calls C++ function: Qt::WindowModality QWindow::modality() const.
Sourcepub unsafe fn from_q_screen(
screen: impl CastInto<Ptr<QScreen>>,
) -> QBox<QWindow>
pub unsafe fn from_q_screen( screen: impl CastInto<Ptr<QScreen>>, ) -> QBox<QWindow>
Calls C++ function: [constructor] void QWindow::QWindow(QScreen* screen = …).
Sourcepub unsafe fn from_q_window(
parent: impl CastInto<Ptr<QWindow>>,
) -> QBox<QWindow>
pub unsafe fn from_q_window( parent: impl CastInto<Ptr<QWindow>>, ) -> QBox<QWindow>
Calls C++ function: [constructor] void QWindow::QWindow(QWindow* parent).
Sourcepub unsafe fn new() -> QBox<QWindow>
pub unsafe fn new() -> QBox<QWindow>
Calls C++ function: [constructor] void QWindow::QWindow().
Sourcepub unsafe fn parent_1a(&self, mode: AncestorMode) -> QPtr<QWindow>
pub unsafe fn parent_1a(&self, mode: AncestorMode) -> QPtr<QWindow>
Calls C++ function: QWindow* QWindow::parent(QWindow::AncestorMode mode) const.
Sourcepub unsafe fn parent_0a(&self) -> QPtr<QWindow>
pub unsafe fn parent_0a(&self) -> QPtr<QWindow>
Calls C++ function: QWindow* QWindow::parent() const.
Sourcepub unsafe fn position(&self) -> CppBox<QPoint>
pub unsafe fn position(&self) -> CppBox<QPoint>
Calls C++ function: QPoint QWindow::position() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QWindow::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QWindow::qt_metacast(const char* arg1).
Sourcepub unsafe fn report_content_orientation_change(
&self,
orientation: ScreenOrientation,
)
pub unsafe fn report_content_orientation_change( &self, orientation: ScreenOrientation, )
Calls C++ function: void QWindow::reportContentOrientationChange(Qt::ScreenOrientation orientation).
Sourcepub unsafe fn request_activate(&self)
pub unsafe fn request_activate(&self)
Calls C++ function: [slot] void QWindow::requestActivate().
Sourcepub unsafe fn request_update(&self)
pub unsafe fn request_update(&self)
Calls C++ function: [slot] void QWindow::requestUpdate().
Sourcepub unsafe fn requested_format(&self) -> CppBox<QSurfaceFormat>
pub unsafe fn requested_format(&self) -> CppBox<QSurfaceFormat>
Calls C++ function: QSurfaceFormat QWindow::requestedFormat() const.
Sourcepub unsafe fn resize_1a(&self, new_size: impl CastInto<Ref<QSize>>)
pub unsafe fn resize_1a(&self, new_size: impl CastInto<Ref<QSize>>)
Calls C++ function: void QWindow::resize(const QSize& newSize).
Sourcepub unsafe fn resize_2a(&self, w: c_int, h: c_int)
pub unsafe fn resize_2a(&self, w: c_int, h: c_int)
Calls C++ function: void QWindow::resize(int w, int h).
Sourcepub unsafe fn screen(&self) -> QPtr<QScreen>
pub unsafe fn screen(&self) -> QPtr<QScreen>
Calls C++ function: QScreen* QWindow::screen() const.
Sourcepub unsafe fn set_base_size(&self, size: impl CastInto<Ref<QSize>>)
pub unsafe fn set_base_size(&self, size: impl CastInto<Ref<QSize>>)
Calls C++ function: void QWindow::setBaseSize(const QSize& size).
Sourcepub unsafe fn set_cursor(&self, arg1: impl CastInto<Ref<QCursor>>)
pub unsafe fn set_cursor(&self, arg1: impl CastInto<Ref<QCursor>>)
Calls C++ function: void QWindow::setCursor(const QCursor& arg1).
Sourcepub unsafe fn set_file_path(&self, file_path: impl CastInto<Ref<QString>>)
pub unsafe fn set_file_path(&self, file_path: impl CastInto<Ref<QString>>)
Calls C++ function: void QWindow::setFilePath(const QString& filePath).
Sourcepub unsafe fn set_flag_2a(&self, arg1: WindowType, on: bool)
pub unsafe fn set_flag_2a(&self, arg1: WindowType, on: bool)
Calls C++ function: void QWindow::setFlag(Qt::WindowType arg1, bool on = …).
Sourcepub unsafe fn set_flag_1a(&self, arg1: WindowType)
pub unsafe fn set_flag_1a(&self, arg1: WindowType)
Calls C++ function: void QWindow::setFlag(Qt::WindowType arg1).
Sourcepub unsafe fn set_flags(&self, flags: QFlags<WindowType>)
pub unsafe fn set_flags(&self, flags: QFlags<WindowType>)
Calls C++ function: void QWindow::setFlags(QFlags<Qt::WindowType> flags).
Sourcepub unsafe fn set_format(&self, format: impl CastInto<Ref<QSurfaceFormat>>)
pub unsafe fn set_format(&self, format: impl CastInto<Ref<QSurfaceFormat>>)
Calls C++ function: void QWindow::setFormat(const QSurfaceFormat& format).
Sourcepub unsafe fn set_frame_position(&self, point: impl CastInto<Ref<QPoint>>)
pub unsafe fn set_frame_position(&self, point: impl CastInto<Ref<QPoint>>)
Calls C++ function: void QWindow::setFramePosition(const QPoint& point).
Sourcepub unsafe fn set_geometry_4a(
&self,
posx: c_int,
posy: c_int,
w: c_int,
h: c_int,
)
pub unsafe fn set_geometry_4a( &self, posx: c_int, posy: c_int, w: c_int, h: c_int, )
Calls C++ function: [slot] void QWindow::setGeometry(int posx, int posy, int w, int h).
Sourcepub unsafe fn set_geometry_1a(&self, rect: impl CastInto<Ref<QRect>>)
pub unsafe fn set_geometry_1a(&self, rect: impl CastInto<Ref<QRect>>)
Calls C++ function: [slot] void QWindow::setGeometry(const QRect& rect).
Sourcepub unsafe fn set_height(&self, arg: c_int)
pub unsafe fn set_height(&self, arg: c_int)
Calls C++ function: [slot] void QWindow::setHeight(int arg).
Sourcepub unsafe fn set_icon(&self, icon: impl CastInto<Ref<QIcon>>)
pub unsafe fn set_icon(&self, icon: impl CastInto<Ref<QIcon>>)
Calls C++ function: void QWindow::setIcon(const QIcon& icon).
Sourcepub unsafe fn set_keyboard_grab_enabled(&self, grab: bool) -> bool
pub unsafe fn set_keyboard_grab_enabled(&self, grab: bool) -> bool
Calls C++ function: bool QWindow::setKeyboardGrabEnabled(bool grab).
Sourcepub unsafe fn set_mask(&self, region: impl CastInto<Ref<QRegion>>)
pub unsafe fn set_mask(&self, region: impl CastInto<Ref<QRegion>>)
Calls C++ function: void QWindow::setMask(const QRegion& region).
Sourcepub unsafe fn set_maximum_height(&self, h: c_int)
pub unsafe fn set_maximum_height(&self, h: c_int)
Calls C++ function: [slot] void QWindow::setMaximumHeight(int h).
Sourcepub unsafe fn set_maximum_size(&self, size: impl CastInto<Ref<QSize>>)
pub unsafe fn set_maximum_size(&self, size: impl CastInto<Ref<QSize>>)
Calls C++ function: void QWindow::setMaximumSize(const QSize& size).
Sourcepub unsafe fn set_maximum_width(&self, w: c_int)
pub unsafe fn set_maximum_width(&self, w: c_int)
Calls C++ function: [slot] void QWindow::setMaximumWidth(int w).
Sourcepub unsafe fn set_minimum_height(&self, h: c_int)
pub unsafe fn set_minimum_height(&self, h: c_int)
Calls C++ function: [slot] void QWindow::setMinimumHeight(int h).
Sourcepub unsafe fn set_minimum_size(&self, size: impl CastInto<Ref<QSize>>)
pub unsafe fn set_minimum_size(&self, size: impl CastInto<Ref<QSize>>)
Calls C++ function: void QWindow::setMinimumSize(const QSize& size).
Sourcepub unsafe fn set_minimum_width(&self, w: c_int)
pub unsafe fn set_minimum_width(&self, w: c_int)
Calls C++ function: [slot] void QWindow::setMinimumWidth(int w).
Sourcepub unsafe fn set_modality(&self, modality: WindowModality)
pub unsafe fn set_modality(&self, modality: WindowModality)
Calls C++ function: void QWindow::setModality(Qt::WindowModality modality).
Sourcepub unsafe fn set_mouse_grab_enabled(&self, grab: bool) -> bool
pub unsafe fn set_mouse_grab_enabled(&self, grab: bool) -> bool
Calls C++ function: bool QWindow::setMouseGrabEnabled(bool grab).
Sourcepub unsafe fn set_opacity(&self, level: c_double)
pub unsafe fn set_opacity(&self, level: c_double)
Calls C++ function: void QWindow::setOpacity(double level).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QWindow>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QWindow>>)
Calls C++ function: void QWindow::setParent(QWindow* parent).
Sourcepub unsafe fn set_position_1a(&self, pt: impl CastInto<Ref<QPoint>>)
pub unsafe fn set_position_1a(&self, pt: impl CastInto<Ref<QPoint>>)
Calls C++ function: void QWindow::setPosition(const QPoint& pt).
Sourcepub unsafe fn set_position_2a(&self, posx: c_int, posy: c_int)
pub unsafe fn set_position_2a(&self, posx: c_int, posy: c_int)
Calls C++ function: void QWindow::setPosition(int posx, int posy).
Sourcepub unsafe fn set_screen(&self, screen: impl CastInto<Ptr<QScreen>>)
pub unsafe fn set_screen(&self, screen: impl CastInto<Ptr<QScreen>>)
Calls C++ function: void QWindow::setScreen(QScreen* screen).
Sourcepub unsafe fn set_size_increment(&self, size: impl CastInto<Ref<QSize>>)
pub unsafe fn set_size_increment(&self, size: impl CastInto<Ref<QSize>>)
Calls C++ function: void QWindow::setSizeIncrement(const QSize& size).
Sourcepub unsafe fn set_surface_type(&self, surface_type: SurfaceType)
pub unsafe fn set_surface_type(&self, surface_type: SurfaceType)
Calls C++ function: void QWindow::setSurfaceType(QSurface::SurfaceType surfaceType).
Sourcepub unsafe fn set_title(&self, arg1: impl CastInto<Ref<QString>>)
pub unsafe fn set_title(&self, arg1: impl CastInto<Ref<QString>>)
Calls C++ function: [slot] void QWindow::setTitle(const QString& arg1).
Sourcepub unsafe fn set_transient_parent(&self, parent: impl CastInto<Ptr<QWindow>>)
pub unsafe fn set_transient_parent(&self, parent: impl CastInto<Ptr<QWindow>>)
Calls C++ function: void QWindow::setTransientParent(QWindow* parent).
Sourcepub unsafe fn set_visibility(&self, v: Visibility)
pub unsafe fn set_visibility(&self, v: Visibility)
Calls C++ function: void QWindow::setVisibility(QWindow::Visibility v).
Sourcepub unsafe fn set_visible(&self, visible: bool)
pub unsafe fn set_visible(&self, visible: bool)
Calls C++ function: [slot] void QWindow::setVisible(bool visible).
Sourcepub unsafe fn set_width(&self, arg: c_int)
pub unsafe fn set_width(&self, arg: c_int)
Calls C++ function: [slot] void QWindow::setWidth(int arg).
Sourcepub unsafe fn set_window_state(&self, state: WindowState)
pub unsafe fn set_window_state(&self, state: WindowState)
Calls C++ function: void QWindow::setWindowState(Qt::WindowState state).
Sourcepub unsafe fn set_window_states(&self, states: QFlags<WindowState>)
pub unsafe fn set_window_states(&self, states: QFlags<WindowState>)
Calls C++ function: void QWindow::setWindowStates(QFlags<Qt::WindowState> states).
Sourcepub unsafe fn show_full_screen(&self)
pub unsafe fn show_full_screen(&self)
Calls C++ function: [slot] void QWindow::showFullScreen().
Sourcepub unsafe fn show_maximized(&self)
pub unsafe fn show_maximized(&self)
Calls C++ function: [slot] void QWindow::showMaximized().
Sourcepub unsafe fn show_minimized(&self)
pub unsafe fn show_minimized(&self)
Calls C++ function: [slot] void QWindow::showMinimized().
Sourcepub unsafe fn show_normal(&self)
pub unsafe fn show_normal(&self)
Calls C++ function: [slot] void QWindow::showNormal().
Sourcepub unsafe fn size(&self) -> CppBox<QSize>
pub unsafe fn size(&self) -> CppBox<QSize>
Calls C++ function: virtual QSize QWindow::size() const.
Sourcepub unsafe fn size_increment(&self) -> CppBox<QSize>
pub unsafe fn size_increment(&self) -> CppBox<QSize>
Calls C++ function: QSize QWindow::sizeIncrement() const.
Sourcepub unsafe fn start_system_move(&self) -> bool
pub unsafe fn start_system_move(&self) -> bool
Calls C++ function: [slot] bool QWindow::startSystemMove().
Sourcepub unsafe fn start_system_resize(&self, edges: QFlags<Edge>) -> bool
pub unsafe fn start_system_resize(&self, edges: QFlags<Edge>) -> bool
Calls C++ function: [slot] bool QWindow::startSystemResize(QFlags<Qt::Edge> edges).
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn surface_type(&self) -> SurfaceType
pub unsafe fn surface_type(&self) -> SurfaceType
Calls C++ function: virtual QSurface::SurfaceType QWindow::surfaceType() const.
Sourcepub unsafe fn title(&self) -> CppBox<QString>
pub unsafe fn title(&self) -> CppBox<QString>
Calls C++ function: QString QWindow::title() const.
Sourcepub unsafe fn tr(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QWindow::tr(const char* s, const char* c, int n).
Sourcepub unsafe fn tr_utf8(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QWindow::trUtf8(const char* s, const char* c, int n).
Sourcepub unsafe fn transient_parent(&self) -> QPtr<QWindow>
pub unsafe fn transient_parent(&self) -> QPtr<QWindow>
Calls C++ function: QWindow* QWindow::transientParent() const.
Sourcepub unsafe fn type_(&self) -> WindowType
pub unsafe fn type_(&self) -> WindowType
Calls C++ function: Qt::WindowType QWindow::type() const.
Sourcepub unsafe fn unset_cursor(&self)
pub unsafe fn unset_cursor(&self)
Calls C++ function: void QWindow::unsetCursor().
Sourcepub unsafe fn visibility(&self) -> Visibility
pub unsafe fn visibility(&self) -> Visibility
Calls C++ function: QWindow::Visibility QWindow::visibility() const.
Sourcepub unsafe fn win_id(&self) -> c_ulonglong
pub unsafe fn win_id(&self) -> c_ulonglong
Calls C++ function: unsigned long long QWindow::winId() const.
Sourcepub unsafe fn window_state(&self) -> WindowState
pub unsafe fn window_state(&self) -> WindowState
Calls C++ function: Qt::WindowState QWindow::windowState() const.
Sourcepub unsafe fn window_states(&self) -> QFlags<WindowState>
pub unsafe fn window_states(&self) -> QFlags<WindowState>
Calls C++ function: QFlags<Qt::WindowState> QWindow::windowStates() const.
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const i8) -> bool
pub unsafe fn inherits(&self, classname: *const i8) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: i32)
pub unsafe fn kill_timer(&self, id: i32)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: i32,
arg3: *mut *mut c_void,
) -> i32
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const i8,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: i32) -> i32
pub unsafe fn start_timer_1a(&self, interval: i32) -> i32
Calls C++ function: int QObject::startTimer(int interval).