pub struct QBitmap { /* private fields */ }Expand description
C++ class: QBitmap.
Implementations
Sourceimpl QBitmap
impl QBitmap
Sourcepub unsafe fn copy_from_q_bitmap(
&self,
other: impl CastInto<Ref<QBitmap>>,
) -> Ref<QBitmap>
pub unsafe fn copy_from_q_bitmap( &self, other: impl CastInto<Ref<QBitmap>>, ) -> Ref<QBitmap>
Calls C++ function: QBitmap& QBitmap::operator=(const QBitmap& other).
Sourcepub unsafe fn copy_from_q_pixmap(
&self,
arg1: impl CastInto<Ref<QPixmap>>,
) -> Ref<QBitmap>
pub unsafe fn copy_from_q_pixmap( &self, arg1: impl CastInto<Ref<QPixmap>>, ) -> Ref<QBitmap>
Calls C++ function: QBitmap& QBitmap::operator=(const QPixmap& arg1).
Sourcepub unsafe fn from_data_3a(
size: impl CastInto<Ref<QSize>>,
bits: *const c_uchar,
mono_format: Format,
) -> CppBox<QBitmap>
pub unsafe fn from_data_3a( size: impl CastInto<Ref<QSize>>, bits: *const c_uchar, mono_format: Format, ) -> CppBox<QBitmap>
Calls C++ function: static QBitmap QBitmap::fromData(const QSize& size, const unsigned char* bits, QImage::Format monoFormat = …).
Sourcepub unsafe fn from_data_2a(
size: impl CastInto<Ref<QSize>>,
bits: *const c_uchar,
) -> CppBox<QBitmap>
pub unsafe fn from_data_2a( size: impl CastInto<Ref<QSize>>, bits: *const c_uchar, ) -> CppBox<QBitmap>
Calls C++ function: static QBitmap QBitmap::fromData(const QSize& size, const unsigned char* bits).
Sourcepub unsafe fn from_image_2a(
image: impl CastInto<Ref<QImage>>,
flags: QFlags<ImageConversionFlag>,
) -> CppBox<QBitmap>
pub unsafe fn from_image_2a( image: impl CastInto<Ref<QImage>>, flags: QFlags<ImageConversionFlag>, ) -> CppBox<QBitmap>
Calls C++ function: static QBitmap QBitmap::fromImage(const QImage& image, QFlags<Qt::ImageConversionFlag> flags = …).
Sourcepub unsafe fn from_image_1a(
image: impl CastInto<Ref<QImage>>,
) -> CppBox<QBitmap>
pub unsafe fn from_image_1a( image: impl CastInto<Ref<QImage>>, ) -> CppBox<QBitmap>
Calls C++ function: static QBitmap QBitmap::fromImage(const QImage& image).
Sourcepub unsafe fn new() -> CppBox<QBitmap>
pub unsafe fn new() -> CppBox<QBitmap>
Calls C++ function: [constructor] void QBitmap::QBitmap().
Sourcepub unsafe fn from_q_pixmap(
arg1: impl CastInto<Ref<QPixmap>>,
) -> CppBox<QBitmap>
pub unsafe fn from_q_pixmap( arg1: impl CastInto<Ref<QPixmap>>, ) -> CppBox<QBitmap>
Calls C++ function: [constructor] void QBitmap::QBitmap(const QPixmap& arg1).
Sourcepub unsafe fn from_2_int(w: c_int, h: c_int) -> CppBox<QBitmap>
pub unsafe fn from_2_int(w: c_int, h: c_int) -> CppBox<QBitmap>
Calls C++ function: [constructor] void QBitmap::QBitmap(int w, int h).
Sourcepub unsafe fn from_q_size(arg1: impl CastInto<Ref<QSize>>) -> CppBox<QBitmap>
pub unsafe fn from_q_size(arg1: impl CastInto<Ref<QSize>>) -> CppBox<QBitmap>
Calls C++ function: [constructor] void QBitmap::QBitmap(const QSize& arg1).
Sourcepub unsafe fn from_q_string_char(
file_name: impl CastInto<Ref<QString>>,
format: *const c_char,
) -> CppBox<QBitmap>
pub unsafe fn from_q_string_char( file_name: impl CastInto<Ref<QString>>, format: *const c_char, ) -> CppBox<QBitmap>
Calls C++ function: [constructor] void QBitmap::QBitmap(const QString& fileName, const char* format = …).
Sourcepub unsafe fn from_q_string(
file_name: impl CastInto<Ref<QString>>,
) -> CppBox<QBitmap>
pub unsafe fn from_q_string( file_name: impl CastInto<Ref<QString>>, ) -> CppBox<QBitmap>
Calls C++ function: [constructor] void QBitmap::QBitmap(const QString& fileName).
Sourcepub unsafe fn new_copy(other: impl CastInto<Ref<QBitmap>>) -> CppBox<QBitmap>
pub unsafe fn new_copy(other: impl CastInto<Ref<QBitmap>>) -> CppBox<QBitmap>
Calls C++ function: [constructor] void QBitmap::QBitmap(const QBitmap& other).
Sourcepub unsafe fn swap(&self, other: impl CastInto<Ref<QBitmap>>)
pub unsafe fn swap(&self, other: impl CastInto<Ref<QBitmap>>)
Calls C++ function: void QBitmap::swap(QBitmap& other).
Sourcepub unsafe fn to_q_variant(&self) -> CppBox<QVariant>
pub unsafe fn to_q_variant(&self) -> CppBox<QVariant>
Calls C++ function: QVariant QBitmap::operator QVariant() const.
Sourcepub unsafe fn transformed_q_matrix(
&self,
arg1: impl CastInto<Ref<QMatrix>>,
) -> CppBox<QBitmap>
pub unsafe fn transformed_q_matrix( &self, arg1: impl CastInto<Ref<QMatrix>>, ) -> CppBox<QBitmap>
Calls C++ function: QBitmap QBitmap::transformed(const QMatrix& arg1) const.
Sourcepub unsafe fn transformed_q_transform(
&self,
matrix: impl CastInto<Ref<QTransform>>,
) -> CppBox<QBitmap>
pub unsafe fn transformed_q_transform( &self, matrix: impl CastInto<Ref<QTransform>>, ) -> CppBox<QBitmap>
Calls C++ function: QBitmap QBitmap::transformed(const QTransform& matrix) const.
Methods from Deref<Target = QPixmap>
Sourcepub unsafe fn cache_key(&self) -> c_longlong
pub unsafe fn cache_key(&self) -> c_longlong
Calls C++ function: long long QPixmap::cacheKey() const.
Sourcepub unsafe fn convert_from_image_2a(
&self,
img: impl CastInto<Ref<QImage>>,
flags: QFlags<ImageConversionFlag>,
) -> bool
pub unsafe fn convert_from_image_2a( &self, img: impl CastInto<Ref<QImage>>, flags: QFlags<ImageConversionFlag>, ) -> bool
Calls C++ function: bool QPixmap::convertFromImage(const QImage& img, QFlags<Qt::ImageConversionFlag> flags = …).
Sourcepub unsafe fn convert_from_image_1a(
&self,
img: impl CastInto<Ref<QImage>>,
) -> bool
pub unsafe fn convert_from_image_1a( &self, img: impl CastInto<Ref<QImage>>, ) -> bool
Calls C++ function: bool QPixmap::convertFromImage(const QImage& img).
Sourcepub unsafe fn copy_4a(
&self,
x: c_int,
y: c_int,
width: c_int,
height: c_int,
) -> CppBox<QPixmap>
pub unsafe fn copy_4a( &self, x: c_int, y: c_int, width: c_int, height: c_int, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::copy(int x, int y, int width, int height) const.
Sourcepub unsafe fn copy_1a(&self, rect: impl CastInto<Ref<QRect>>) -> CppBox<QPixmap>
pub unsafe fn copy_1a(&self, rect: impl CastInto<Ref<QRect>>) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::copy(const QRect& rect = …) const.
Sourcepub unsafe fn copy_0a(&self) -> CppBox<QPixmap>
pub unsafe fn copy_0a(&self) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::copy() const.
Sourcepub unsafe fn copy_from(
&self,
arg1: impl CastInto<Ref<QPixmap>>,
) -> Ref<QPixmap>
pub unsafe fn copy_from( &self, arg1: impl CastInto<Ref<QPixmap>>, ) -> Ref<QPixmap>
Calls C++ function: QPixmap& QPixmap::operator=(const QPixmap& arg1).
Sourcepub unsafe fn create_heuristic_mask_1a(
&self,
clip_tight: bool,
) -> CppBox<QBitmap>
pub unsafe fn create_heuristic_mask_1a( &self, clip_tight: bool, ) -> CppBox<QBitmap>
Calls C++ function: QBitmap QPixmap::createHeuristicMask(bool clipTight = …) const.
Sourcepub unsafe fn create_heuristic_mask_0a(&self) -> CppBox<QBitmap>
pub unsafe fn create_heuristic_mask_0a(&self) -> CppBox<QBitmap>
Calls C++ function: QBitmap QPixmap::createHeuristicMask() const.
Sourcepub unsafe fn create_mask_from_color_2a(
&self,
mask_color: impl CastInto<Ref<QColor>>,
mode: MaskMode,
) -> CppBox<QBitmap>
pub unsafe fn create_mask_from_color_2a( &self, mask_color: impl CastInto<Ref<QColor>>, mode: MaskMode, ) -> CppBox<QBitmap>
Calls C++ function: QBitmap QPixmap::createMaskFromColor(const QColor& maskColor, Qt::MaskMode mode = …) const.
Sourcepub unsafe fn create_mask_from_color_1a(
&self,
mask_color: impl CastInto<Ref<QColor>>,
) -> CppBox<QBitmap>
pub unsafe fn create_mask_from_color_1a( &self, mask_color: impl CastInto<Ref<QColor>>, ) -> CppBox<QBitmap>
Calls C++ function: QBitmap QPixmap::createMaskFromColor(const QColor& maskColor) const.
Sourcepub unsafe fn dev_type(&self) -> c_int
pub unsafe fn dev_type(&self) -> c_int
Calls C++ function: virtual int QPixmap::devType() const.
Sourcepub unsafe fn device_pixel_ratio(&self) -> c_double
pub unsafe fn device_pixel_ratio(&self) -> c_double
Calls C++ function: double QPixmap::devicePixelRatio() const.
Sourcepub unsafe fn fill_1a(&self, fill_color: impl CastInto<Ref<QColor>>)
pub unsafe fn fill_1a(&self, fill_color: impl CastInto<Ref<QColor>>)
Calls C++ function: void QPixmap::fill(const QColor& fillColor = …).
Sourcepub unsafe fn fill_2a(
&self,
device: impl CastInto<Ptr<QPaintDevice>>,
ofs: impl CastInto<Ref<QPoint>>,
)
pub unsafe fn fill_2a( &self, device: impl CastInto<Ptr<QPaintDevice>>, ofs: impl CastInto<Ref<QPoint>>, )
Calls C++ function: void QPixmap::fill(const QPaintDevice* device, const QPoint& ofs).
Sourcepub unsafe fn fill_3a(
&self,
device: impl CastInto<Ptr<QPaintDevice>>,
xofs: c_int,
yofs: c_int,
)
pub unsafe fn fill_3a( &self, device: impl CastInto<Ptr<QPaintDevice>>, xofs: c_int, yofs: c_int, )
Calls C++ function: void QPixmap::fill(const QPaintDevice* device, int xofs, int yofs).
Sourcepub unsafe fn has_alpha_channel(&self) -> bool
pub unsafe fn has_alpha_channel(&self) -> bool
Calls C++ function: bool QPixmap::hasAlphaChannel() const.
Sourcepub unsafe fn is_detached(&self) -> bool
pub unsafe fn is_detached(&self) -> bool
Calls C++ function: bool QPixmap::isDetached() const.
Sourcepub unsafe fn is_q_bitmap(&self) -> bool
pub unsafe fn is_q_bitmap(&self) -> bool
Calls C++ function: bool QPixmap::isQBitmap() const.
Sourcepub unsafe fn load_3a(
&self,
file_name: impl CastInto<Ref<QString>>,
format: *const c_char,
flags: QFlags<ImageConversionFlag>,
) -> bool
pub unsafe fn load_3a( &self, file_name: impl CastInto<Ref<QString>>, format: *const c_char, flags: QFlags<ImageConversionFlag>, ) -> bool
Calls C++ function: bool QPixmap::load(const QString& fileName, const char* format = …, QFlags<Qt::ImageConversionFlag> flags = …).
Sourcepub unsafe fn load_2a(
&self,
file_name: impl CastInto<Ref<QString>>,
format: *const c_char,
) -> bool
pub unsafe fn load_2a( &self, file_name: impl CastInto<Ref<QString>>, format: *const c_char, ) -> bool
Calls C++ function: bool QPixmap::load(const QString& fileName, const char* format = …).
Sourcepub unsafe fn load_1a(&self, file_name: impl CastInto<Ref<QString>>) -> bool
pub unsafe fn load_1a(&self, file_name: impl CastInto<Ref<QString>>) -> bool
Calls C++ function: bool QPixmap::load(const QString& fileName).
Sourcepub unsafe fn load_from_data_uchar_uint_char_q_flags_image_conversion_flag(
&self,
buf: *const c_uchar,
len: c_uint,
format: *const c_char,
flags: QFlags<ImageConversionFlag>,
) -> bool
pub unsafe fn load_from_data_uchar_uint_char_q_flags_image_conversion_flag( &self, buf: *const c_uchar, len: c_uint, format: *const c_char, flags: QFlags<ImageConversionFlag>, ) -> bool
Calls C++ function: bool QPixmap::loadFromData(const unsigned char* buf, unsigned int len, const char* format = …, QFlags<Qt::ImageConversionFlag> flags = …).
Sourcepub unsafe fn load_from_data_q_byte_array_char_q_flags_image_conversion_flag(
&self,
data: impl CastInto<Ref<QByteArray>>,
format: *const c_char,
flags: QFlags<ImageConversionFlag>,
) -> bool
pub unsafe fn load_from_data_q_byte_array_char_q_flags_image_conversion_flag( &self, data: impl CastInto<Ref<QByteArray>>, format: *const c_char, flags: QFlags<ImageConversionFlag>, ) -> bool
Calls C++ function: bool QPixmap::loadFromData(const QByteArray& data, const char* format = …, QFlags<Qt::ImageConversionFlag> flags = …).
Sourcepub unsafe fn load_from_data_uchar_uint_char(
&self,
buf: *const c_uchar,
len: c_uint,
format: *const c_char,
) -> bool
pub unsafe fn load_from_data_uchar_uint_char( &self, buf: *const c_uchar, len: c_uint, format: *const c_char, ) -> bool
Calls C++ function: bool QPixmap::loadFromData(const unsigned char* buf, unsigned int len, const char* format = …).
Sourcepub unsafe fn load_from_data_uchar_uint(
&self,
buf: *const c_uchar,
len: c_uint,
) -> bool
pub unsafe fn load_from_data_uchar_uint( &self, buf: *const c_uchar, len: c_uint, ) -> bool
Calls C++ function: bool QPixmap::loadFromData(const unsigned char* buf, unsigned int len).
Sourcepub unsafe fn load_from_data_q_byte_array_char(
&self,
data: impl CastInto<Ref<QByteArray>>,
format: *const c_char,
) -> bool
pub unsafe fn load_from_data_q_byte_array_char( &self, data: impl CastInto<Ref<QByteArray>>, format: *const c_char, ) -> bool
Calls C++ function: bool QPixmap::loadFromData(const QByteArray& data, const char* format = …).
Sourcepub unsafe fn load_from_data_q_byte_array(
&self,
data: impl CastInto<Ref<QByteArray>>,
) -> bool
pub unsafe fn load_from_data_q_byte_array( &self, data: impl CastInto<Ref<QByteArray>>, ) -> bool
Calls C++ function: bool QPixmap::loadFromData(const QByteArray& data).
Sourcepub unsafe fn mask(&self) -> CppBox<QBitmap>
pub unsafe fn mask(&self) -> CppBox<QBitmap>
Calls C++ function: QBitmap QPixmap::mask() const.
Sourcepub unsafe fn paint_engine(&self) -> Ptr<QPaintEngine>
pub unsafe fn paint_engine(&self) -> Ptr<QPaintEngine>
Calls C++ function: virtual QPaintEngine* QPixmap::paintEngine() const.
Sourcepub unsafe fn save_q_string_char_int(
&self,
file_name: impl CastInto<Ref<QString>>,
format: *const c_char,
quality: c_int,
) -> bool
pub unsafe fn save_q_string_char_int( &self, file_name: impl CastInto<Ref<QString>>, format: *const c_char, quality: c_int, ) -> bool
Calls C++ function: bool QPixmap::save(const QString& fileName, const char* format = …, int quality = …) const.
Sourcepub unsafe fn save_q_io_device_char_int(
&self,
device: impl CastInto<Ptr<QIODevice>>,
format: *const c_char,
quality: c_int,
) -> bool
pub unsafe fn save_q_io_device_char_int( &self, device: impl CastInto<Ptr<QIODevice>>, format: *const c_char, quality: c_int, ) -> bool
Calls C++ function: bool QPixmap::save(QIODevice* device, const char* format = …, int quality = …) const.
Sourcepub unsafe fn save_q_string_char(
&self,
file_name: impl CastInto<Ref<QString>>,
format: *const c_char,
) -> bool
pub unsafe fn save_q_string_char( &self, file_name: impl CastInto<Ref<QString>>, format: *const c_char, ) -> bool
Calls C++ function: bool QPixmap::save(const QString& fileName, const char* format = …) const.
Sourcepub unsafe fn save_q_string(
&self,
file_name: impl CastInto<Ref<QString>>,
) -> bool
pub unsafe fn save_q_string( &self, file_name: impl CastInto<Ref<QString>>, ) -> bool
Calls C++ function: bool QPixmap::save(const QString& fileName) const.
Sourcepub unsafe fn save_q_io_device_char(
&self,
device: impl CastInto<Ptr<QIODevice>>,
format: *const c_char,
) -> bool
pub unsafe fn save_q_io_device_char( &self, device: impl CastInto<Ptr<QIODevice>>, format: *const c_char, ) -> bool
Calls C++ function: bool QPixmap::save(QIODevice* device, const char* format = …) const.
Sourcepub unsafe fn save_q_io_device(
&self,
device: impl CastInto<Ptr<QIODevice>>,
) -> bool
pub unsafe fn save_q_io_device( &self, device: impl CastInto<Ptr<QIODevice>>, ) -> bool
Calls C++ function: bool QPixmap::save(QIODevice* device) const.
Sourcepub unsafe fn scaled_2_int_aspect_ratio_mode_transformation_mode(
&self,
w: c_int,
h: c_int,
aspect_mode: AspectRatioMode,
mode: TransformationMode,
) -> CppBox<QPixmap>
pub unsafe fn scaled_2_int_aspect_ratio_mode_transformation_mode( &self, w: c_int, h: c_int, aspect_mode: AspectRatioMode, mode: TransformationMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaled(int w, int h, Qt::AspectRatioMode aspectMode = …, Qt::TransformationMode mode = …) const.
Sourcepub unsafe fn scaled_q_size_aspect_ratio_mode_transformation_mode(
&self,
s: impl CastInto<Ref<QSize>>,
aspect_mode: AspectRatioMode,
mode: TransformationMode,
) -> CppBox<QPixmap>
pub unsafe fn scaled_q_size_aspect_ratio_mode_transformation_mode( &self, s: impl CastInto<Ref<QSize>>, aspect_mode: AspectRatioMode, mode: TransformationMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaled(const QSize& s, Qt::AspectRatioMode aspectMode = …, Qt::TransformationMode mode = …) const.
Sourcepub unsafe fn scaled_2_int_aspect_ratio_mode(
&self,
w: c_int,
h: c_int,
aspect_mode: AspectRatioMode,
) -> CppBox<QPixmap>
pub unsafe fn scaled_2_int_aspect_ratio_mode( &self, w: c_int, h: c_int, aspect_mode: AspectRatioMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaled(int w, int h, Qt::AspectRatioMode aspectMode = …) const.
Sourcepub unsafe fn scaled_2_int(&self, w: c_int, h: c_int) -> CppBox<QPixmap>
pub unsafe fn scaled_2_int(&self, w: c_int, h: c_int) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaled(int w, int h) const.
Sourcepub unsafe fn scaled_q_size_aspect_ratio_mode(
&self,
s: impl CastInto<Ref<QSize>>,
aspect_mode: AspectRatioMode,
) -> CppBox<QPixmap>
pub unsafe fn scaled_q_size_aspect_ratio_mode( &self, s: impl CastInto<Ref<QSize>>, aspect_mode: AspectRatioMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaled(const QSize& s, Qt::AspectRatioMode aspectMode = …) const.
Sourcepub unsafe fn scaled_q_size(
&self,
s: impl CastInto<Ref<QSize>>,
) -> CppBox<QPixmap>
pub unsafe fn scaled_q_size( &self, s: impl CastInto<Ref<QSize>>, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaled(const QSize& s) const.
Sourcepub unsafe fn scaled_to_height_2a(
&self,
h: c_int,
mode: TransformationMode,
) -> CppBox<QPixmap>
pub unsafe fn scaled_to_height_2a( &self, h: c_int, mode: TransformationMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaledToHeight(int h, Qt::TransformationMode mode = …) const.
Sourcepub unsafe fn scaled_to_height_1a(&self, h: c_int) -> CppBox<QPixmap>
pub unsafe fn scaled_to_height_1a(&self, h: c_int) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaledToHeight(int h) const.
Sourcepub unsafe fn scaled_to_width_2a(
&self,
w: c_int,
mode: TransformationMode,
) -> CppBox<QPixmap>
pub unsafe fn scaled_to_width_2a( &self, w: c_int, mode: TransformationMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaledToWidth(int w, Qt::TransformationMode mode = …) const.
Sourcepub unsafe fn scaled_to_width_1a(&self, w: c_int) -> CppBox<QPixmap>
pub unsafe fn scaled_to_width_1a(&self, w: c_int) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::scaledToWidth(int w) const.
Sourcepub unsafe fn scroll_7a(
&self,
dx: c_int,
dy: c_int,
x: c_int,
y: c_int,
width: c_int,
height: c_int,
exposed: impl CastInto<Ptr<QRegion>>,
)
pub unsafe fn scroll_7a( &self, dx: c_int, dy: c_int, x: c_int, y: c_int, width: c_int, height: c_int, exposed: impl CastInto<Ptr<QRegion>>, )
Calls C++ function: void QPixmap::scroll(int dx, int dy, int x, int y, int width, int height, QRegion* exposed = …).
Sourcepub unsafe fn scroll_4a(
&self,
dx: c_int,
dy: c_int,
rect: impl CastInto<Ref<QRect>>,
exposed: impl CastInto<Ptr<QRegion>>,
)
pub unsafe fn scroll_4a( &self, dx: c_int, dy: c_int, rect: impl CastInto<Ref<QRect>>, exposed: impl CastInto<Ptr<QRegion>>, )
Calls C++ function: void QPixmap::scroll(int dx, int dy, const QRect& rect, QRegion* exposed = …).
Sourcepub unsafe fn scroll_6a(
&self,
dx: c_int,
dy: c_int,
x: c_int,
y: c_int,
width: c_int,
height: c_int,
)
pub unsafe fn scroll_6a( &self, dx: c_int, dy: c_int, x: c_int, y: c_int, width: c_int, height: c_int, )
Calls C++ function: void QPixmap::scroll(int dx, int dy, int x, int y, int width, int height).
Sourcepub unsafe fn scroll_3a(
&self,
dx: c_int,
dy: c_int,
rect: impl CastInto<Ref<QRect>>,
)
pub unsafe fn scroll_3a( &self, dx: c_int, dy: c_int, rect: impl CastInto<Ref<QRect>>, )
Calls C++ function: void QPixmap::scroll(int dx, int dy, const QRect& rect).
Sourcepub unsafe fn set_device_pixel_ratio(&self, scale_factor: c_double)
pub unsafe fn set_device_pixel_ratio(&self, scale_factor: c_double)
Calls C++ function: void QPixmap::setDevicePixelRatio(double scaleFactor).
Sourcepub unsafe fn set_mask(&self, arg1: impl CastInto<Ref<QBitmap>>)
pub unsafe fn set_mask(&self, arg1: impl CastInto<Ref<QBitmap>>)
Calls C++ function: void QPixmap::setMask(const QBitmap& arg1).
Sourcepub unsafe fn swap(&self, other: impl CastInto<Ref<QPixmap>>)
pub unsafe fn swap(&self, other: impl CastInto<Ref<QPixmap>>)
Calls C++ function: void QPixmap::swap(QPixmap& other).
Sourcepub unsafe fn to_image(&self) -> CppBox<QImage>
pub unsafe fn to_image(&self) -> CppBox<QImage>
Calls C++ function: QImage QPixmap::toImage() const.
Sourcepub unsafe fn to_q_variant(&self) -> CppBox<QVariant>
pub unsafe fn to_q_variant(&self) -> CppBox<QVariant>
Calls C++ function: QVariant QPixmap::operator QVariant() const.
Sourcepub unsafe fn transformed_q_matrix_transformation_mode(
&self,
arg1: impl CastInto<Ref<QMatrix>>,
mode: TransformationMode,
) -> CppBox<QPixmap>
pub unsafe fn transformed_q_matrix_transformation_mode( &self, arg1: impl CastInto<Ref<QMatrix>>, mode: TransformationMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::transformed(const QMatrix& arg1, Qt::TransformationMode mode = …) const.
Sourcepub unsafe fn transformed_q_transform_transformation_mode(
&self,
arg1: impl CastInto<Ref<QTransform>>,
mode: TransformationMode,
) -> CppBox<QPixmap>
pub unsafe fn transformed_q_transform_transformation_mode( &self, arg1: impl CastInto<Ref<QTransform>>, mode: TransformationMode, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::transformed(const QTransform& arg1, Qt::TransformationMode mode = …) const.
Sourcepub unsafe fn transformed_q_matrix(
&self,
arg1: impl CastInto<Ref<QMatrix>>,
) -> CppBox<QPixmap>
pub unsafe fn transformed_q_matrix( &self, arg1: impl CastInto<Ref<QMatrix>>, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::transformed(const QMatrix& arg1) const.
Sourcepub unsafe fn transformed_q_transform(
&self,
arg1: impl CastInto<Ref<QTransform>>,
) -> CppBox<QPixmap>
pub unsafe fn transformed_q_transform( &self, arg1: impl CastInto<Ref<QTransform>>, ) -> CppBox<QPixmap>
Calls C++ function: QPixmap QPixmap::transformed(const QTransform& arg1) const.
Methods from Deref<Target = QPaintDevice>
Sourcepub unsafe fn color_count(&self) -> c_int
pub unsafe fn color_count(&self) -> c_int
Calls C++ function: int QPaintDevice::colorCount() const.
Sourcepub unsafe fn dev_type(&self) -> c_int
pub unsafe fn dev_type(&self) -> c_int
Calls C++ function: virtual int QPaintDevice::devType() const.
Sourcepub unsafe fn device_pixel_ratio(&self) -> c_int
pub unsafe fn device_pixel_ratio(&self) -> c_int
Calls C++ function: int QPaintDevice::devicePixelRatio() const.
Sourcepub unsafe fn device_pixel_ratio_f(&self) -> c_double
pub unsafe fn device_pixel_ratio_f(&self) -> c_double
Calls C++ function: double QPaintDevice::devicePixelRatioF() const.
Sourcepub unsafe fn height_m_m(&self) -> c_int
pub unsafe fn height_m_m(&self) -> c_int
Calls C++ function: int QPaintDevice::heightMM() const.
Sourcepub unsafe fn logical_dpi_x(&self) -> c_int
pub unsafe fn logical_dpi_x(&self) -> c_int
Calls C++ function: int QPaintDevice::logicalDpiX() const.
Sourcepub unsafe fn logical_dpi_y(&self) -> c_int
pub unsafe fn logical_dpi_y(&self) -> c_int
Calls C++ function: int QPaintDevice::logicalDpiY() const.
Sourcepub unsafe fn paint_engine(&self) -> Ptr<QPaintEngine>
pub unsafe fn paint_engine(&self) -> Ptr<QPaintEngine>
Calls C++ function: pure virtual QPaintEngine* QPaintDevice::paintEngine() const.
Sourcepub unsafe fn painting_active(&self) -> bool
pub unsafe fn painting_active(&self) -> bool
Calls C++ function: bool QPaintDevice::paintingActive() const.
Sourcepub unsafe fn physical_dpi_x(&self) -> c_int
pub unsafe fn physical_dpi_x(&self) -> c_int
Calls C++ function: int QPaintDevice::physicalDpiX() const.
Sourcepub unsafe fn physical_dpi_y(&self) -> c_int
pub unsafe fn physical_dpi_y(&self) -> c_int
Calls C++ function: int QPaintDevice::physicalDpiY() const.