pub struct QColor { /* private fields */ }Expand description
C++ class: QColor.
Implementations
Sourceimpl QColor
impl QColor
Sourcepub unsafe fn color_names() -> CppBox<QStringList>
pub unsafe fn color_names() -> CppBox<QStringList>
Calls C++ function: static QStringList QColor::colorNames().
Sourcepub unsafe fn convert_to(&self, color_spec: Spec) -> CppBox<QColor>
pub unsafe fn convert_to(&self, color_spec: Spec) -> CppBox<QColor>
Calls C++ function: QColor QColor::convertTo(QColor::Spec colorSpec) const.
Sourcepub unsafe fn copy_from_q_color(
&self,
arg1: impl CastInto<Ref<QColor>>,
) -> Ref<QColor>
pub unsafe fn copy_from_q_color( &self, arg1: impl CastInto<Ref<QColor>>, ) -> Ref<QColor>
Calls C++ function: QColor& QColor::operator=(const QColor& arg1).
Sourcepub unsafe fn copy_from_global_color(&self, color: GlobalColor) -> Ref<QColor>
pub unsafe fn copy_from_global_color(&self, color: GlobalColor) -> Ref<QColor>
Calls C++ function: QColor& QColor::operator=(Qt::GlobalColor color).
Sourcepub unsafe fn dark_1a(&self, f: c_int) -> CppBox<QColor>
pub unsafe fn dark_1a(&self, f: c_int) -> CppBox<QColor>
Calls C++ function: QColor QColor::dark(int f = …) const.
Sourcepub unsafe fn dark_0a(&self) -> CppBox<QColor>
pub unsafe fn dark_0a(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::dark() const.
Sourcepub unsafe fn darker_1a(&self, f: c_int) -> CppBox<QColor>
pub unsafe fn darker_1a(&self, f: c_int) -> CppBox<QColor>
Calls C++ function: QColor QColor::darker(int f = …) const.
Sourcepub unsafe fn darker_0a(&self) -> CppBox<QColor>
pub unsafe fn darker_0a(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::darker() const.
Sourcepub unsafe fn from_cmyk_5a(
c: c_int,
m: c_int,
y: c_int,
k: c_int,
a: c_int,
) -> CppBox<QColor>
pub unsafe fn from_cmyk_5a( c: c_int, m: c_int, y: c_int, k: c_int, a: c_int, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromCmyk(int c, int m, int y, int k, int a = …).
Sourcepub unsafe fn from_cmyk_4a(
c: c_int,
m: c_int,
y: c_int,
k: c_int,
) -> CppBox<QColor>
pub unsafe fn from_cmyk_4a( c: c_int, m: c_int, y: c_int, k: c_int, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromCmyk(int c, int m, int y, int k).
Sourcepub unsafe fn from_cmyk_f_5a(
c: c_double,
m: c_double,
y: c_double,
k: c_double,
a: c_double,
) -> CppBox<QColor>
pub unsafe fn from_cmyk_f_5a( c: c_double, m: c_double, y: c_double, k: c_double, a: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromCmykF(double c, double m, double y, double k, double a = …).
Sourcepub unsafe fn from_cmyk_f_4a(
c: c_double,
m: c_double,
y: c_double,
k: c_double,
) -> CppBox<QColor>
pub unsafe fn from_cmyk_f_4a( c: c_double, m: c_double, y: c_double, k: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromCmykF(double c, double m, double y, double k).
Sourcepub unsafe fn from_hsl_4a(
h: c_int,
s: c_int,
l: c_int,
a: c_int,
) -> CppBox<QColor>
pub unsafe fn from_hsl_4a( h: c_int, s: c_int, l: c_int, a: c_int, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHsl(int h, int s, int l, int a = …).
Sourcepub unsafe fn from_hsl_3a(h: c_int, s: c_int, l: c_int) -> CppBox<QColor>
pub unsafe fn from_hsl_3a(h: c_int, s: c_int, l: c_int) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHsl(int h, int s, int l).
Sourcepub unsafe fn from_hsl_f_4a(
h: c_double,
s: c_double,
l: c_double,
a: c_double,
) -> CppBox<QColor>
pub unsafe fn from_hsl_f_4a( h: c_double, s: c_double, l: c_double, a: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHslF(double h, double s, double l, double a = …).
Sourcepub unsafe fn from_hsl_f_3a(
h: c_double,
s: c_double,
l: c_double,
) -> CppBox<QColor>
pub unsafe fn from_hsl_f_3a( h: c_double, s: c_double, l: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHslF(double h, double s, double l).
Sourcepub unsafe fn from_hsv_4a(
h: c_int,
s: c_int,
v: c_int,
a: c_int,
) -> CppBox<QColor>
pub unsafe fn from_hsv_4a( h: c_int, s: c_int, v: c_int, a: c_int, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHsv(int h, int s, int v, int a = …).
Sourcepub unsafe fn from_hsv_3a(h: c_int, s: c_int, v: c_int) -> CppBox<QColor>
pub unsafe fn from_hsv_3a(h: c_int, s: c_int, v: c_int) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHsv(int h, int s, int v).
Sourcepub unsafe fn from_hsv_f_4a(
h: c_double,
s: c_double,
v: c_double,
a: c_double,
) -> CppBox<QColor>
pub unsafe fn from_hsv_f_4a( h: c_double, s: c_double, v: c_double, a: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHsvF(double h, double s, double v, double a = …).
Sourcepub unsafe fn from_hsv_f_3a(
h: c_double,
s: c_double,
v: c_double,
) -> CppBox<QColor>
pub unsafe fn from_hsv_f_3a( h: c_double, s: c_double, v: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromHsvF(double h, double s, double v).
Sourcepub unsafe fn from_rgb_1a(rgb: c_uint) -> CppBox<QColor>
pub unsafe fn from_rgb_1a(rgb: c_uint) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgb(unsigned int rgb).
Sourcepub unsafe fn from_rgb_4a(
r: c_int,
g: c_int,
b: c_int,
a: c_int,
) -> CppBox<QColor>
pub unsafe fn from_rgb_4a( r: c_int, g: c_int, b: c_int, a: c_int, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgb(int r, int g, int b, int a = …).
Sourcepub unsafe fn from_rgb_3a(r: c_int, g: c_int, b: c_int) -> CppBox<QColor>
pub unsafe fn from_rgb_3a(r: c_int, g: c_int, b: c_int) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgb(int r, int g, int b).
Sourcepub unsafe fn from_rgb_f_4a(
r: c_double,
g: c_double,
b: c_double,
a: c_double,
) -> CppBox<QColor>
pub unsafe fn from_rgb_f_4a( r: c_double, g: c_double, b: c_double, a: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgbF(double r, double g, double b, double a = …).
Sourcepub unsafe fn from_rgb_f_3a(
r: c_double,
g: c_double,
b: c_double,
) -> CppBox<QColor>
pub unsafe fn from_rgb_f_3a( r: c_double, g: c_double, b: c_double, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgbF(double r, double g, double b).
Sourcepub unsafe fn from_rgba(rgba: c_uint) -> CppBox<QColor>
pub unsafe fn from_rgba(rgba: c_uint) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgba(unsigned int rgba).
Sourcepub unsafe fn from_rgba64_4a(
r: c_ushort,
g: c_ushort,
b: c_ushort,
a: c_ushort,
) -> CppBox<QColor>
pub unsafe fn from_rgba64_4a( r: c_ushort, g: c_ushort, b: c_ushort, a: c_ushort, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgba64(unsigned short r, unsigned short g, unsigned short b, unsigned short a = …).
Sourcepub unsafe fn from_rgba64_1a(
rgba: impl CastInto<Ref<QRgba64>>,
) -> CppBox<QColor>
pub unsafe fn from_rgba64_1a( rgba: impl CastInto<Ref<QRgba64>>, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgba64(QRgba64 rgba).
Sourcepub unsafe fn from_rgba64_3a(
r: c_ushort,
g: c_ushort,
b: c_ushort,
) -> CppBox<QColor>
pub unsafe fn from_rgba64_3a( r: c_ushort, g: c_ushort, b: c_ushort, ) -> CppBox<QColor>
Calls C++ function: static QColor QColor::fromRgba64(unsigned short r, unsigned short g, unsigned short b).
Sourcepub unsafe fn get_cmyk_5a_mut(
&self,
c: *mut c_int,
m: *mut c_int,
y: *mut c_int,
k: *mut c_int,
a: *mut c_int,
)
pub unsafe fn get_cmyk_5a_mut( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, a: *mut c_int, )
Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k, int* a = …).
Sourcepub unsafe fn get_cmyk_5a(
&self,
c: *mut c_int,
m: *mut c_int,
y: *mut c_int,
k: *mut c_int,
a: *mut c_int,
)
pub unsafe fn get_cmyk_5a( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, a: *mut c_int, )
Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k, int* a = …) const.
Sourcepub unsafe fn get_cmyk_4a_mut(
&self,
c: *mut c_int,
m: *mut c_int,
y: *mut c_int,
k: *mut c_int,
)
pub unsafe fn get_cmyk_4a_mut( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, )
Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k).
Sourcepub unsafe fn get_cmyk_4a(
&self,
c: *mut c_int,
m: *mut c_int,
y: *mut c_int,
k: *mut c_int,
)
pub unsafe fn get_cmyk_4a( &self, c: *mut c_int, m: *mut c_int, y: *mut c_int, k: *mut c_int, )
Calls C++ function: void QColor::getCmyk(int* c, int* m, int* y, int* k) const.
Sourcepub unsafe fn get_cmyk_f_5a_mut(
&self,
c: *mut c_double,
m: *mut c_double,
y: *mut c_double,
k: *mut c_double,
a: *mut c_double,
)
pub unsafe fn get_cmyk_f_5a_mut( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, a: *mut c_double, )
Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k, double* a = …).
Sourcepub unsafe fn get_cmyk_f_5a(
&self,
c: *mut c_double,
m: *mut c_double,
y: *mut c_double,
k: *mut c_double,
a: *mut c_double,
)
pub unsafe fn get_cmyk_f_5a( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, a: *mut c_double, )
Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k, double* a = …) const.
Sourcepub unsafe fn get_cmyk_f_4a_mut(
&self,
c: *mut c_double,
m: *mut c_double,
y: *mut c_double,
k: *mut c_double,
)
pub unsafe fn get_cmyk_f_4a_mut( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, )
Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k).
Sourcepub unsafe fn get_cmyk_f_4a(
&self,
c: *mut c_double,
m: *mut c_double,
y: *mut c_double,
k: *mut c_double,
)
pub unsafe fn get_cmyk_f_4a( &self, c: *mut c_double, m: *mut c_double, y: *mut c_double, k: *mut c_double, )
Calls C++ function: void QColor::getCmykF(double* c, double* m, double* y, double* k) const.
Sourcepub unsafe fn get_hsl_4a(
&self,
h: *mut c_int,
s: *mut c_int,
l: *mut c_int,
a: *mut c_int,
)
pub unsafe fn get_hsl_4a( &self, h: *mut c_int, s: *mut c_int, l: *mut c_int, a: *mut c_int, )
Calls C++ function: void QColor::getHsl(int* h, int* s, int* l, int* a = …) const.
Sourcepub unsafe fn get_hsl_3a(&self, h: *mut c_int, s: *mut c_int, l: *mut c_int)
pub unsafe fn get_hsl_3a(&self, h: *mut c_int, s: *mut c_int, l: *mut c_int)
Calls C++ function: void QColor::getHsl(int* h, int* s, int* l) const.
Sourcepub unsafe fn get_hsl_f_4a(
&self,
h: *mut c_double,
s: *mut c_double,
l: *mut c_double,
a: *mut c_double,
)
pub unsafe fn get_hsl_f_4a( &self, h: *mut c_double, s: *mut c_double, l: *mut c_double, a: *mut c_double, )
Calls C++ function: void QColor::getHslF(double* h, double* s, double* l, double* a = …) const.
Sourcepub unsafe fn get_hsl_f_3a(
&self,
h: *mut c_double,
s: *mut c_double,
l: *mut c_double,
)
pub unsafe fn get_hsl_f_3a( &self, h: *mut c_double, s: *mut c_double, l: *mut c_double, )
Calls C++ function: void QColor::getHslF(double* h, double* s, double* l) const.
Sourcepub unsafe fn get_hsv_4a(
&self,
h: *mut c_int,
s: *mut c_int,
v: *mut c_int,
a: *mut c_int,
)
pub unsafe fn get_hsv_4a( &self, h: *mut c_int, s: *mut c_int, v: *mut c_int, a: *mut c_int, )
Calls C++ function: void QColor::getHsv(int* h, int* s, int* v, int* a = …) const.
Sourcepub unsafe fn get_hsv_3a(&self, h: *mut c_int, s: *mut c_int, v: *mut c_int)
pub unsafe fn get_hsv_3a(&self, h: *mut c_int, s: *mut c_int, v: *mut c_int)
Calls C++ function: void QColor::getHsv(int* h, int* s, int* v) const.
Sourcepub unsafe fn get_hsv_f_4a(
&self,
h: *mut c_double,
s: *mut c_double,
v: *mut c_double,
a: *mut c_double,
)
pub unsafe fn get_hsv_f_4a( &self, h: *mut c_double, s: *mut c_double, v: *mut c_double, a: *mut c_double, )
Calls C++ function: void QColor::getHsvF(double* h, double* s, double* v, double* a = …) const.
Sourcepub unsafe fn get_hsv_f_3a(
&self,
h: *mut c_double,
s: *mut c_double,
v: *mut c_double,
)
pub unsafe fn get_hsv_f_3a( &self, h: *mut c_double, s: *mut c_double, v: *mut c_double, )
Calls C++ function: void QColor::getHsvF(double* h, double* s, double* v) const.
Sourcepub unsafe fn get_rgb_4a(
&self,
r: *mut c_int,
g: *mut c_int,
b: *mut c_int,
a: *mut c_int,
)
pub unsafe fn get_rgb_4a( &self, r: *mut c_int, g: *mut c_int, b: *mut c_int, a: *mut c_int, )
Calls C++ function: void QColor::getRgb(int* r, int* g, int* b, int* a = …) const.
Sourcepub unsafe fn get_rgb_3a(&self, r: *mut c_int, g: *mut c_int, b: *mut c_int)
pub unsafe fn get_rgb_3a(&self, r: *mut c_int, g: *mut c_int, b: *mut c_int)
Calls C++ function: void QColor::getRgb(int* r, int* g, int* b) const.
Sourcepub unsafe fn get_rgb_f_4a(
&self,
r: *mut c_double,
g: *mut c_double,
b: *mut c_double,
a: *mut c_double,
)
pub unsafe fn get_rgb_f_4a( &self, r: *mut c_double, g: *mut c_double, b: *mut c_double, a: *mut c_double, )
Calls C++ function: void QColor::getRgbF(double* r, double* g, double* b, double* a = …) const.
Sourcepub unsafe fn get_rgb_f_3a(
&self,
r: *mut c_double,
g: *mut c_double,
b: *mut c_double,
)
pub unsafe fn get_rgb_f_3a( &self, r: *mut c_double, g: *mut c_double, b: *mut c_double, )
Calls C++ function: void QColor::getRgbF(double* r, double* g, double* b) const.
Sourcepub unsafe fn hsl_saturation(&self) -> c_int
pub unsafe fn hsl_saturation(&self) -> c_int
Calls C++ function: int QColor::hslSaturation() const.
Sourcepub unsafe fn hsl_saturation_f(&self) -> c_double
pub unsafe fn hsl_saturation_f(&self) -> c_double
Calls C++ function: double QColor::hslSaturationF() const.
Sourcepub unsafe fn hsv_saturation(&self) -> c_int
pub unsafe fn hsv_saturation(&self) -> c_int
Calls C++ function: int QColor::hsvSaturation() const.
Sourcepub unsafe fn hsv_saturation_f(&self) -> c_double
pub unsafe fn hsv_saturation_f(&self) -> c_double
Calls C++ function: double QColor::hsvSaturationF() const.
Sourcepub unsafe fn is_valid_color_q_string(name: impl CastInto<Ref<QString>>) -> bool
pub unsafe fn is_valid_color_q_string(name: impl CastInto<Ref<QString>>) -> bool
Calls C++ function: static bool QColor::isValidColor(const QString& name).
Sourcepub unsafe fn is_valid_color_q_string_view(
arg1: impl CastInto<Ref<QStringView>>,
) -> bool
pub unsafe fn is_valid_color_q_string_view( arg1: impl CastInto<Ref<QStringView>>, ) -> bool
Calls C++ function: static bool QColor::isValidColor(QStringView arg1).
Sourcepub unsafe fn is_valid_color_q_latin1_string(
arg1: impl CastInto<Ref<QLatin1String>>,
) -> bool
pub unsafe fn is_valid_color_q_latin1_string( arg1: impl CastInto<Ref<QLatin1String>>, ) -> bool
Calls C++ function: static bool QColor::isValidColor(QLatin1String arg1).
Sourcepub unsafe fn light_1a(&self, f: c_int) -> CppBox<QColor>
pub unsafe fn light_1a(&self, f: c_int) -> CppBox<QColor>
Calls C++ function: QColor QColor::light(int f = …) const.
Sourcepub unsafe fn light_0a(&self) -> CppBox<QColor>
pub unsafe fn light_0a(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::light() const.
Sourcepub unsafe fn lighter_1a(&self, f: c_int) -> CppBox<QColor>
pub unsafe fn lighter_1a(&self, f: c_int) -> CppBox<QColor>
Calls C++ function: QColor QColor::lighter(int f = …) const.
Sourcepub unsafe fn lighter_0a(&self) -> CppBox<QColor>
pub unsafe fn lighter_0a(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::lighter() const.
Sourcepub unsafe fn lightness_f(&self) -> c_double
pub unsafe fn lightness_f(&self) -> c_double
Calls C++ function: double QColor::lightnessF() const.
Sourcepub unsafe fn magenta_f(&self) -> c_double
pub unsafe fn magenta_f(&self) -> c_double
Calls C++ function: double QColor::magentaF() const.
Sourcepub unsafe fn name_0a(&self) -> CppBox<QString>
pub unsafe fn name_0a(&self) -> CppBox<QString>
Calls C++ function: QString QColor::name() const.
Sourcepub unsafe fn name_1a(&self, format: NameFormat) -> CppBox<QString>
pub unsafe fn name_1a(&self, format: NameFormat) -> CppBox<QString>
Calls C++ function: QString QColor::name(QColor::NameFormat format) const.
Sourcepub unsafe fn from_global_color(color: GlobalColor) -> CppBox<QColor>
pub unsafe fn from_global_color(color: GlobalColor) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(Qt::GlobalColor color).
Sourcepub unsafe fn from_4_int(
r: c_int,
g: c_int,
b: c_int,
a: c_int,
) -> CppBox<QColor>
pub unsafe fn from_4_int( r: c_int, g: c_int, b: c_int, a: c_int, ) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(int r, int g, int b, int a = …).
Sourcepub unsafe fn from_uint(rgb: c_uint) -> CppBox<QColor>
pub unsafe fn from_uint(rgb: c_uint) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(unsigned int rgb).
Sourcepub unsafe fn from_q_rgba64(
rgba64: impl CastInto<Ref<QRgba64>>,
) -> CppBox<QColor>
pub unsafe fn from_q_rgba64( rgba64: impl CastInto<Ref<QRgba64>>, ) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(QRgba64 rgba64).
Sourcepub unsafe fn from_q_string(name: impl CastInto<Ref<QString>>) -> CppBox<QColor>
pub unsafe fn from_q_string(name: impl CastInto<Ref<QString>>) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(const QString& name).
Sourcepub unsafe fn from_q_string_view(
name: impl CastInto<Ref<QStringView>>,
) -> CppBox<QColor>
pub unsafe fn from_q_string_view( name: impl CastInto<Ref<QStringView>>, ) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(QStringView name).
Sourcepub unsafe fn from_char(aname: *const c_char) -> CppBox<QColor>
pub unsafe fn from_char(aname: *const c_char) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(const char* aname).
Sourcepub unsafe fn from_q_latin1_string(
name: impl CastInto<Ref<QLatin1String>>,
) -> CppBox<QColor>
pub unsafe fn from_q_latin1_string( name: impl CastInto<Ref<QLatin1String>>, ) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(QLatin1String name).
Sourcepub unsafe fn from_spec(spec: Spec) -> CppBox<QColor>
pub unsafe fn from_spec(spec: Spec) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(QColor::Spec spec).
Sourcepub unsafe fn from_spec5_ushort(
spec: Spec,
a1: c_ushort,
a2: c_ushort,
a3: c_ushort,
a4: c_ushort,
a5: c_ushort,
) -> CppBox<QColor>
pub unsafe fn from_spec5_ushort( spec: Spec, a1: c_ushort, a2: c_ushort, a3: c_ushort, a4: c_ushort, a5: c_ushort, ) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(QColor::Spec spec, unsigned short a1, unsigned short a2, unsigned short a3, unsigned short a4, unsigned short a5 = …).
Sourcepub unsafe fn from_3_int(r: c_int, g: c_int, b: c_int) -> CppBox<QColor>
pub unsafe fn from_3_int(r: c_int, g: c_int, b: c_int) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(int r, int g, int b).
Sourcepub unsafe fn from_spec4_ushort(
spec: Spec,
a1: c_ushort,
a2: c_ushort,
a3: c_ushort,
a4: c_ushort,
) -> CppBox<QColor>
pub unsafe fn from_spec4_ushort( spec: Spec, a1: c_ushort, a2: c_ushort, a3: c_ushort, a4: c_ushort, ) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(QColor::Spec spec, unsigned short a1, unsigned short a2, unsigned short a3, unsigned short a4).
Sourcepub unsafe fn new_copy(color: impl CastInto<Ref<QColor>>) -> CppBox<QColor>
pub unsafe fn new_copy(color: impl CastInto<Ref<QColor>>) -> CppBox<QColor>
Calls C++ function: [constructor] void QColor::QColor(const QColor& color).
Sourcepub unsafe fn rgba64(&self) -> CppBox<QRgba64>
pub unsafe fn rgba64(&self) -> CppBox<QRgba64>
Calls C++ function: QRgba64 QColor::rgba64() const.
Sourcepub unsafe fn saturation(&self) -> c_int
pub unsafe fn saturation(&self) -> c_int
Calls C++ function: int QColor::saturation() const.
Sourcepub unsafe fn saturation_f(&self) -> c_double
pub unsafe fn saturation_f(&self) -> c_double
Calls C++ function: double QColor::saturationF() const.
Sourcepub unsafe fn set_alpha(&self, alpha: c_int)
pub unsafe fn set_alpha(&self, alpha: c_int)
Calls C++ function: void QColor::setAlpha(int alpha).
Sourcepub unsafe fn set_alpha_f(&self, alpha: c_double)
pub unsafe fn set_alpha_f(&self, alpha: c_double)
Calls C++ function: void QColor::setAlphaF(double alpha).
Sourcepub unsafe fn set_blue_f(&self, blue: c_double)
pub unsafe fn set_blue_f(&self, blue: c_double)
Calls C++ function: void QColor::setBlueF(double blue).
Sourcepub unsafe fn set_cmyk_5a(
&self,
c: c_int,
m: c_int,
y: c_int,
k: c_int,
a: c_int,
)
pub unsafe fn set_cmyk_5a( &self, c: c_int, m: c_int, y: c_int, k: c_int, a: c_int, )
Calls C++ function: void QColor::setCmyk(int c, int m, int y, int k, int a = …).
Sourcepub unsafe fn set_cmyk_4a(&self, c: c_int, m: c_int, y: c_int, k: c_int)
pub unsafe fn set_cmyk_4a(&self, c: c_int, m: c_int, y: c_int, k: c_int)
Calls C++ function: void QColor::setCmyk(int c, int m, int y, int k).
Sourcepub unsafe fn set_cmyk_f_5a(
&self,
c: c_double,
m: c_double,
y: c_double,
k: c_double,
a: c_double,
)
pub unsafe fn set_cmyk_f_5a( &self, c: c_double, m: c_double, y: c_double, k: c_double, a: c_double, )
Calls C++ function: void QColor::setCmykF(double c, double m, double y, double k, double a = …).
Sourcepub unsafe fn set_cmyk_f_4a(
&self,
c: c_double,
m: c_double,
y: c_double,
k: c_double,
)
pub unsafe fn set_cmyk_f_4a( &self, c: c_double, m: c_double, y: c_double, k: c_double, )
Calls C++ function: void QColor::setCmykF(double c, double m, double y, double k).
Sourcepub unsafe fn set_green(&self, green: c_int)
pub unsafe fn set_green(&self, green: c_int)
Calls C++ function: void QColor::setGreen(int green).
Sourcepub unsafe fn set_green_f(&self, green: c_double)
pub unsafe fn set_green_f(&self, green: c_double)
Calls C++ function: void QColor::setGreenF(double green).
Sourcepub unsafe fn set_hsl_4a(&self, h: c_int, s: c_int, l: c_int, a: c_int)
pub unsafe fn set_hsl_4a(&self, h: c_int, s: c_int, l: c_int, a: c_int)
Calls C++ function: void QColor::setHsl(int h, int s, int l, int a = …).
Sourcepub unsafe fn set_hsl_3a(&self, h: c_int, s: c_int, l: c_int)
pub unsafe fn set_hsl_3a(&self, h: c_int, s: c_int, l: c_int)
Calls C++ function: void QColor::setHsl(int h, int s, int l).
Sourcepub unsafe fn set_hsl_f_4a(
&self,
h: c_double,
s: c_double,
l: c_double,
a: c_double,
)
pub unsafe fn set_hsl_f_4a( &self, h: c_double, s: c_double, l: c_double, a: c_double, )
Calls C++ function: void QColor::setHslF(double h, double s, double l, double a = …).
Sourcepub unsafe fn set_hsl_f_3a(&self, h: c_double, s: c_double, l: c_double)
pub unsafe fn set_hsl_f_3a(&self, h: c_double, s: c_double, l: c_double)
Calls C++ function: void QColor::setHslF(double h, double s, double l).
Sourcepub unsafe fn set_hsv_4a(&self, h: c_int, s: c_int, v: c_int, a: c_int)
pub unsafe fn set_hsv_4a(&self, h: c_int, s: c_int, v: c_int, a: c_int)
Calls C++ function: void QColor::setHsv(int h, int s, int v, int a = …).
Sourcepub unsafe fn set_hsv_3a(&self, h: c_int, s: c_int, v: c_int)
pub unsafe fn set_hsv_3a(&self, h: c_int, s: c_int, v: c_int)
Calls C++ function: void QColor::setHsv(int h, int s, int v).
Sourcepub unsafe fn set_hsv_f_4a(
&self,
h: c_double,
s: c_double,
v: c_double,
a: c_double,
)
pub unsafe fn set_hsv_f_4a( &self, h: c_double, s: c_double, v: c_double, a: c_double, )
Calls C++ function: void QColor::setHsvF(double h, double s, double v, double a = …).
Sourcepub unsafe fn set_hsv_f_3a(&self, h: c_double, s: c_double, v: c_double)
pub unsafe fn set_hsv_f_3a(&self, h: c_double, s: c_double, v: c_double)
Calls C++ function: void QColor::setHsvF(double h, double s, double v).
Sourcepub unsafe fn set_named_color_q_string(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_named_color_q_string(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QColor::setNamedColor(const QString& name).
Sourcepub unsafe fn set_named_color_q_string_view(
&self,
name: impl CastInto<Ref<QStringView>>,
)
pub unsafe fn set_named_color_q_string_view( &self, name: impl CastInto<Ref<QStringView>>, )
Calls C++ function: void QColor::setNamedColor(QStringView name).
Sourcepub unsafe fn set_named_color_q_latin1_string(
&self,
name: impl CastInto<Ref<QLatin1String>>,
)
pub unsafe fn set_named_color_q_latin1_string( &self, name: impl CastInto<Ref<QLatin1String>>, )
Calls C++ function: void QColor::setNamedColor(QLatin1String name).
Sourcepub unsafe fn set_red_f(&self, red: c_double)
pub unsafe fn set_red_f(&self, red: c_double)
Calls C++ function: void QColor::setRedF(double red).
Sourcepub unsafe fn set_rgb_4a(&self, r: c_int, g: c_int, b: c_int, a: c_int)
pub unsafe fn set_rgb_4a(&self, r: c_int, g: c_int, b: c_int, a: c_int)
Calls C++ function: void QColor::setRgb(int r, int g, int b, int a = …).
Sourcepub unsafe fn set_rgb_1a(&self, rgb: c_uint)
pub unsafe fn set_rgb_1a(&self, rgb: c_uint)
Calls C++ function: void QColor::setRgb(unsigned int rgb).
Sourcepub unsafe fn set_rgb_3a(&self, r: c_int, g: c_int, b: c_int)
pub unsafe fn set_rgb_3a(&self, r: c_int, g: c_int, b: c_int)
Calls C++ function: void QColor::setRgb(int r, int g, int b).
Sourcepub unsafe fn set_rgb_f_4a(
&self,
r: c_double,
g: c_double,
b: c_double,
a: c_double,
)
pub unsafe fn set_rgb_f_4a( &self, r: c_double, g: c_double, b: c_double, a: c_double, )
Calls C++ function: void QColor::setRgbF(double r, double g, double b, double a = …).
Sourcepub unsafe fn set_rgb_f_3a(&self, r: c_double, g: c_double, b: c_double)
pub unsafe fn set_rgb_f_3a(&self, r: c_double, g: c_double, b: c_double)
Calls C++ function: void QColor::setRgbF(double r, double g, double b).
Sourcepub unsafe fn set_rgba(&self, rgba: c_uint)
pub unsafe fn set_rgba(&self, rgba: c_uint)
Calls C++ function: void QColor::setRgba(unsigned int rgba).
Sourcepub unsafe fn set_rgba64(&self, rgba: impl CastInto<Ref<QRgba64>>)
pub unsafe fn set_rgba64(&self, rgba: impl CastInto<Ref<QRgba64>>)
Calls C++ function: void QColor::setRgba64(QRgba64 rgba).
Sourcepub unsafe fn to_cmyk(&self) -> CppBox<QColor>
pub unsafe fn to_cmyk(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::toCmyk() const.
Sourcepub unsafe fn to_extended_rgb(&self) -> CppBox<QColor>
pub unsafe fn to_extended_rgb(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::toExtendedRgb() const.
Sourcepub unsafe fn to_hsl(&self) -> CppBox<QColor>
pub unsafe fn to_hsl(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::toHsl() const.
Sourcepub unsafe fn to_hsv(&self) -> CppBox<QColor>
pub unsafe fn to_hsv(&self) -> CppBox<QColor>
Calls C++ function: QColor QColor::toHsv() const.
Sourcepub unsafe fn to_q_variant(&self) -> CppBox<QVariant>
pub unsafe fn to_q_variant(&self) -> CppBox<QVariant>
Calls C++ function: QVariant QColor::operator QVariant() const.