pub struct QMovie { /* private fields */ }Expand description
C++ class: QMovie.
Implementations
Sourceimpl QMovie
impl QMovie
Sourcepub fn started(&self) -> Signal<()>
pub fn started(&self) -> Signal<()>
Returns a built-in Qt signal QMovie::started that can be passed to qt_core::Signal::connect.
Sourcepub fn resized(&self) -> Signal<(*const QSize,)>
pub fn resized(&self) -> Signal<(*const QSize,)>
Returns a built-in Qt signal QMovie::resized that can be passed to qt_core::Signal::connect.
Sourcepub fn updated(&self) -> Signal<(*const QRect,)>
pub fn updated(&self) -> Signal<(*const QRect,)>
Returns a built-in Qt signal QMovie::updated that can be passed to qt_core::Signal::connect.
Sourcepub fn state_changed(&self) -> Signal<(MovieState,)>
pub fn state_changed(&self) -> Signal<(MovieState,)>
Returns a built-in Qt signal QMovie::stateChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn error(&self) -> Signal<(ImageReaderError,)>
pub fn error(&self) -> Signal<(ImageReaderError,)>
Returns a built-in Qt signal QMovie::error that can be passed to qt_core::Signal::connect.
Sourcepub fn finished(&self) -> Signal<()>
pub fn finished(&self) -> Signal<()>
Returns a built-in Qt signal QMovie::finished that can be passed to qt_core::Signal::connect.
Sourcepub fn frame_changed(&self) -> Signal<(c_int,)>
pub fn frame_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QMovie::frameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_start(&self) -> Receiver<()>
pub fn slot_start(&self) -> Receiver<()>
Returns a built-in Qt slot QMovie::start that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_jump_to_next_frame(&self) -> Receiver<()>
pub fn slot_jump_to_next_frame(&self) -> Receiver<()>
Returns a built-in Qt slot QMovie::jumpToNextFrame that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_paused(&self) -> Receiver<(bool,)>
pub fn slot_set_paused(&self) -> Receiver<(bool,)>
Returns a built-in Qt slot QMovie::setPaused that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_stop(&self) -> Receiver<()>
pub fn slot_stop(&self) -> Receiver<()>
Returns a built-in Qt slot QMovie::stop that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_set_speed(&self) -> Receiver<(c_int,)>
pub fn slot_set_speed(&self) -> Receiver<(c_int,)>
Returns a built-in Qt slot QMovie::setSpeed that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn background_color(&self) -> CppBox<QColor>
pub unsafe fn background_color(&self) -> CppBox<QColor>
Calls C++ function: QColor QMovie::backgroundColor() const.
Sourcepub unsafe fn cache_mode(&self) -> CacheMode
pub unsafe fn cache_mode(&self) -> CacheMode
Calls C++ function: QMovie::CacheMode QMovie::cacheMode() const.
Sourcepub unsafe fn current_frame_number(&self) -> c_int
pub unsafe fn current_frame_number(&self) -> c_int
Calls C++ function: int QMovie::currentFrameNumber() const.
Sourcepub unsafe fn current_image(&self) -> CppBox<QImage>
pub unsafe fn current_image(&self) -> CppBox<QImage>
Calls C++ function: QImage QMovie::currentImage() const.
Sourcepub unsafe fn current_pixmap(&self) -> CppBox<QPixmap>
pub unsafe fn current_pixmap(&self) -> CppBox<QPixmap>
Calls C++ function: QPixmap QMovie::currentPixmap() const.
Sourcepub unsafe fn device(&self) -> QPtr<QIODevice>
pub unsafe fn device(&self) -> QPtr<QIODevice>
Calls C++ function: QIODevice* QMovie::device() const.
Sourcepub unsafe fn file_name(&self) -> CppBox<QString>
pub unsafe fn file_name(&self) -> CppBox<QString>
Calls C++ function: QString QMovie::fileName() const.
Sourcepub unsafe fn format(&self) -> CppBox<QByteArray>
pub unsafe fn format(&self) -> CppBox<QByteArray>
Calls C++ function: QByteArray QMovie::format() const.
Sourcepub unsafe fn frame_count(&self) -> c_int
pub unsafe fn frame_count(&self) -> c_int
Calls C++ function: int QMovie::frameCount() const.
Sourcepub unsafe fn frame_rect(&self) -> CppBox<QRect>
pub unsafe fn frame_rect(&self) -> CppBox<QRect>
Calls C++ function: QRect QMovie::frameRect() const.
Sourcepub unsafe fn jump_to_frame(&self, frame_number: c_int) -> bool
pub unsafe fn jump_to_frame(&self, frame_number: c_int) -> bool
Calls C++ function: bool QMovie::jumpToFrame(int frameNumber).
Sourcepub unsafe fn jump_to_next_frame(&self) -> bool
pub unsafe fn jump_to_next_frame(&self) -> bool
Calls C++ function: [slot] bool QMovie::jumpToNextFrame().
Sourcepub unsafe fn last_error(&self) -> ImageReaderError
pub unsafe fn last_error(&self) -> ImageReaderError
Calls C++ function: QImageReader::ImageReaderError QMovie::lastError() const.
Sourcepub unsafe fn last_error_string(&self) -> CppBox<QString>
pub unsafe fn last_error_string(&self) -> CppBox<QString>
Calls C++ function: QString QMovie::lastErrorString() const.
Sourcepub unsafe fn loop_count(&self) -> c_int
pub unsafe fn loop_count(&self) -> c_int
Calls C++ function: int QMovie::loopCount() const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QMovie::metaObject() const.
Sourcepub unsafe fn from_q_object(parent: impl CastInto<Ptr<QObject>>) -> QBox<QMovie>
pub unsafe fn from_q_object(parent: impl CastInto<Ptr<QObject>>) -> QBox<QMovie>
Calls C++ function: [constructor] void QMovie::QMovie(QObject* parent = …).
Sourcepub unsafe fn from_q_io_device_q_byte_array_q_object(
device: impl CastInto<Ptr<QIODevice>>,
format: impl CastInto<Ref<QByteArray>>,
parent: impl CastInto<Ptr<QObject>>,
) -> QBox<QMovie>
pub unsafe fn from_q_io_device_q_byte_array_q_object( device: impl CastInto<Ptr<QIODevice>>, format: impl CastInto<Ref<QByteArray>>, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QMovie>
Calls C++ function: [constructor] void QMovie::QMovie(QIODevice* device, const QByteArray& format = …, QObject* parent = …).
Sourcepub unsafe fn from_q_string_q_byte_array_q_object(
file_name: impl CastInto<Ref<QString>>,
format: impl CastInto<Ref<QByteArray>>,
parent: impl CastInto<Ptr<QObject>>,
) -> QBox<QMovie>
pub unsafe fn from_q_string_q_byte_array_q_object( file_name: impl CastInto<Ref<QString>>, format: impl CastInto<Ref<QByteArray>>, parent: impl CastInto<Ptr<QObject>>, ) -> QBox<QMovie>
Calls C++ function: [constructor] void QMovie::QMovie(const QString& fileName, const QByteArray& format = …, QObject* parent = …).
Sourcepub unsafe fn from_q_io_device_q_byte_array(
device: impl CastInto<Ptr<QIODevice>>,
format: impl CastInto<Ref<QByteArray>>,
) -> QBox<QMovie>
pub unsafe fn from_q_io_device_q_byte_array( device: impl CastInto<Ptr<QIODevice>>, format: impl CastInto<Ref<QByteArray>>, ) -> QBox<QMovie>
Calls C++ function: [constructor] void QMovie::QMovie(QIODevice* device, const QByteArray& format = …).
Sourcepub unsafe fn from_q_io_device(
device: impl CastInto<Ptr<QIODevice>>,
) -> QBox<QMovie>
pub unsafe fn from_q_io_device( device: impl CastInto<Ptr<QIODevice>>, ) -> QBox<QMovie>
Calls C++ function: [constructor] void QMovie::QMovie(QIODevice* device).
Sourcepub unsafe fn from_q_string_q_byte_array(
file_name: impl CastInto<Ref<QString>>,
format: impl CastInto<Ref<QByteArray>>,
) -> QBox<QMovie>
pub unsafe fn from_q_string_q_byte_array( file_name: impl CastInto<Ref<QString>>, format: impl CastInto<Ref<QByteArray>>, ) -> QBox<QMovie>
Calls C++ function: [constructor] void QMovie::QMovie(const QString& fileName, const QByteArray& format = …).
Sourcepub unsafe fn from_q_string(
file_name: impl CastInto<Ref<QString>>,
) -> QBox<QMovie>
pub unsafe fn from_q_string( file_name: impl CastInto<Ref<QString>>, ) -> QBox<QMovie>
Calls C++ function: [constructor] void QMovie::QMovie(const QString& fileName).
Sourcepub unsafe fn next_frame_delay(&self) -> c_int
pub unsafe fn next_frame_delay(&self) -> c_int
Calls C++ function: int QMovie::nextFrameDelay() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QMovie::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QMovie::qt_metacast(const char* arg1).
Sourcepub unsafe fn scaled_size(&self) -> CppBox<QSize>
pub unsafe fn scaled_size(&self) -> CppBox<QSize>
Calls C++ function: QSize QMovie::scaledSize().
Sourcepub unsafe fn set_background_color(&self, color: impl CastInto<Ref<QColor>>)
pub unsafe fn set_background_color(&self, color: impl CastInto<Ref<QColor>>)
Calls C++ function: void QMovie::setBackgroundColor(const QColor& color).
Sourcepub unsafe fn set_cache_mode(&self, mode: CacheMode)
pub unsafe fn set_cache_mode(&self, mode: CacheMode)
Calls C++ function: void QMovie::setCacheMode(QMovie::CacheMode mode).
Sourcepub unsafe fn set_device(&self, device: impl CastInto<Ptr<QIODevice>>)
pub unsafe fn set_device(&self, device: impl CastInto<Ptr<QIODevice>>)
Calls C++ function: void QMovie::setDevice(QIODevice* device).
Sourcepub unsafe fn set_file_name(&self, file_name: impl CastInto<Ref<QString>>)
pub unsafe fn set_file_name(&self, file_name: impl CastInto<Ref<QString>>)
Calls C++ function: void QMovie::setFileName(const QString& fileName).
Sourcepub unsafe fn set_format(&self, format: impl CastInto<Ref<QByteArray>>)
pub unsafe fn set_format(&self, format: impl CastInto<Ref<QByteArray>>)
Calls C++ function: void QMovie::setFormat(const QByteArray& format).
Sourcepub unsafe fn set_paused(&self, paused: bool)
pub unsafe fn set_paused(&self, paused: bool)
Calls C++ function: [slot] void QMovie::setPaused(bool paused).
Sourcepub unsafe fn set_scaled_size(&self, size: impl CastInto<Ref<QSize>>)
pub unsafe fn set_scaled_size(&self, size: impl CastInto<Ref<QSize>>)
Calls C++ function: void QMovie::setScaledSize(const QSize& size).
Sourcepub unsafe fn set_speed(&self, percent_speed: c_int)
pub unsafe fn set_speed(&self, percent_speed: c_int)
Calls C++ function: [slot] void QMovie::setSpeed(int percentSpeed).
Sourcepub unsafe fn state(&self) -> MovieState
pub unsafe fn state(&self) -> MovieState
Calls C++ function: QMovie::MovieState QMovie::state() const.
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn supported_formats() -> CppBox<QListOfQByteArray>
pub unsafe fn supported_formats() -> CppBox<QListOfQByteArray>
Calls C++ function: static QList<QByteArray> QMovie::supportedFormats().
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const i8) -> bool
pub unsafe fn inherits(&self, classname: *const i8) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: i32)
pub unsafe fn kill_timer(&self, id: i32)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: i32,
arg3: *mut *mut c_void,
) -> i32
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const i8,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: i32) -> i32
pub unsafe fn start_timer_1a(&self, interval: i32) -> i32
Calls C++ function: int QObject::startTimer(int interval).