QOpenGLFramebufferObject

Struct QOpenGLFramebufferObject 

pub struct QOpenGLFramebufferObject { /* private fields */ }
C++ class: QOpenGLFramebufferObject.

Implementations

Source

impl QOpenGLFramebufferObject

pub unsafe fn add_color_attachment_q_size_uint( &self, size: impl CastInto<Ref<QSize>>, internal_format: c_uint, )

Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(const QSize& size, unsigned int internalFormat = …).

pub unsafe fn add_color_attachment_2_int_uint( &self, width: c_int, height: c_int, internal_format: c_uint, )

Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(int width, int height, unsigned int internalFormat = …).

pub unsafe fn add_color_attachment_q_size( &self, size: impl CastInto<Ref<QSize>>, )

Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(const QSize& size).

pub unsafe fn add_color_attachment_2_int(&self, width: c_int, height: c_int)

Calls C++ function: void QOpenGLFramebufferObject::addColorAttachment(int width, int height).

pub unsafe fn attachment(&self) -> Attachment

Calls C++ function: QOpenGLFramebufferObject::Attachment QOpenGLFramebufferObject::attachment() const.

pub unsafe fn bind(&self) -> bool

Calls C++ function: bool QOpenGLFramebufferObject::bind().

pub unsafe fn bind_default() -> bool

Calls C++ function: static bool QOpenGLFramebufferObject::bindDefault().

pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint2_int_framebuffer_restore_policy( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, filter: c_uint, read_color_attachment_index: c_int, draw_color_attachment_index: c_int, restore_policy: FramebufferRestorePolicy, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers, unsigned int filter, int readColorAttachmentIndex, int drawColorAttachmentIndex, QOpenGLFramebufferObject::FramebufferRestorePolicy restorePolicy).

pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint2_int( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, filter: c_uint, read_color_attachment_index: c_int, draw_color_attachment_index: c_int, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers, unsigned int filter, int readColorAttachmentIndex, int drawColorAttachmentIndex).

pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect2_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, filter: c_uint, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers = …, unsigned int filter = …).

pub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object2_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, buffers: c_uint, filter: c_uint, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, QOpenGLFramebufferObject* source, unsigned int buffers = …, unsigned int filter = …).

pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, buffers: c_uint, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect, unsigned int buffers = …).

pub unsafe fn blit_framebuffer_q_opengl_framebuffer_object_q_rect_q_opengl_framebuffer_object_q_rect( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, target_rect: impl CastInto<Ref<QRect>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source_rect: impl CastInto<Ref<QRect>>, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, const QRect& targetRect, QOpenGLFramebufferObject* source, const QRect& sourceRect).

pub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object_uint( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, buffers: c_uint, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, QOpenGLFramebufferObject* source, unsigned int buffers = …).

pub unsafe fn blit_framebuffer_2_q_opengl_framebuffer_object( target: impl CastInto<Ptr<QOpenGLFramebufferObject>>, source: impl CastInto<Ptr<QOpenGLFramebufferObject>>, )

Calls C++ function: static void QOpenGLFramebufferObject::blitFramebuffer(QOpenGLFramebufferObject* target, QOpenGLFramebufferObject* source).

pub unsafe fn format(&self) -> CppBox<QOpenGLFramebufferObjectFormat>

Calls C++ function: QOpenGLFramebufferObjectFormat QOpenGLFramebufferObject::format() const.

pub unsafe fn handle(&self) -> c_uint

Calls C++ function: unsigned int QOpenGLFramebufferObject::handle() const.

pub unsafe fn has_opengl_framebuffer_blit() -> bool

Calls C++ function: static bool QOpenGLFramebufferObject::hasOpenGLFramebufferBlit().

pub unsafe fn has_opengl_framebuffer_objects() -> bool

Calls C++ function: static bool QOpenGLFramebufferObject::hasOpenGLFramebufferObjects().

pub unsafe fn height(&self) -> c_int

Calls C++ function: int QOpenGLFramebufferObject::height() const.

pub unsafe fn is_bound(&self) -> bool

Calls C++ function: bool QOpenGLFramebufferObject::isBound() const.

pub unsafe fn is_valid(&self) -> bool

Calls C++ function: bool QOpenGLFramebufferObject::isValid() const.

pub unsafe fn from_q_size_uint( size: impl CastInto<Ref<QSize>>, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, unsigned int target = …).

pub unsafe fn from_2_int_uint( width: c_int, height: c_int, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, unsigned int target = …).

pub unsafe fn from_q_size_attachment2_uint( size: impl CastInto<Ref<QSize>>, attachment: Attachment, target: c_uint, internal_format: c_uint, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …, unsigned int internalFormat = …).

pub unsafe fn from_2_int_attachment2_uint( width: c_int, height: c_int, attachment: Attachment, target: c_uint, internal_format: c_uint, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …, unsigned int internalFormat = …).

pub unsafe fn from_q_size_q_opengl_framebuffer_object_format( size: impl CastInto<Ref<QSize>>, format: impl CastInto<Ref<QOpenGLFramebufferObjectFormat>>, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, const QOpenGLFramebufferObjectFormat& format).

pub unsafe fn from_2_int_q_opengl_framebuffer_object_format( width: c_int, height: c_int, format: impl CastInto<Ref<QOpenGLFramebufferObjectFormat>>, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, const QOpenGLFramebufferObjectFormat& format).

pub unsafe fn from_q_size( size: impl CastInto<Ref<QSize>>, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size).

pub unsafe fn from_2_int( width: c_int, height: c_int, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height).

pub unsafe fn from_q_size_attachment_uint( size: impl CastInto<Ref<QSize>>, attachment: Attachment, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …).

pub unsafe fn from_q_size_attachment( size: impl CastInto<Ref<QSize>>, attachment: Attachment, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(const QSize& size, QOpenGLFramebufferObject::Attachment attachment).

pub unsafe fn from_2_int_attachment_uint( width: c_int, height: c_int, attachment: Attachment, target: c_uint, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, QOpenGLFramebufferObject::Attachment attachment, unsigned int target = …).

pub unsafe fn from_2_int_attachment( width: c_int, height: c_int, attachment: Attachment, ) -> CppBox<QOpenGLFramebufferObject>

Calls C++ function: [constructor] void QOpenGLFramebufferObject::QOpenGLFramebufferObject(int width, int height, QOpenGLFramebufferObject::Attachment attachment).

pub unsafe fn release(&self) -> bool

Calls C++ function: bool QOpenGLFramebufferObject::release().

pub unsafe fn set_attachment(&self, attachment: Attachment)

Calls C++ function: void QOpenGLFramebufferObject::setAttachment(QOpenGLFramebufferObject::Attachment attachment).

pub unsafe fn size(&self) -> CppBox<QSize>

Calls C++ function: QSize QOpenGLFramebufferObject::size() const.

pub unsafe fn sizes(&self) -> CppBox<QVectorOfQSize>

Calls C++ function: QVector<QSize> QOpenGLFramebufferObject::sizes() const.

pub unsafe fn take_texture_0a(&self) -> c_uint

Calls C++ function: unsigned int QOpenGLFramebufferObject::takeTexture().

pub unsafe fn take_texture_1a(&self, color_attachment_index: c_int) -> c_uint

Calls C++ function: unsigned int QOpenGLFramebufferObject::takeTexture(int colorAttachmentIndex).

pub unsafe fn texture(&self) -> c_uint

Calls C++ function: unsigned int QOpenGLFramebufferObject::texture() const.

pub unsafe fn textures(&self) -> CppBox<QVectorOfUint>

Calls C++ function: QVector<unsigned int> QOpenGLFramebufferObject::textures() const.

pub unsafe fn to_image_0a(&self) -> CppBox<QImage>

Calls C++ function: QImage QOpenGLFramebufferObject::toImage() const.

pub unsafe fn to_image_1a(&self, flipped: bool) -> CppBox<QImage>

Calls C++ function: QImage QOpenGLFramebufferObject::toImage(bool flipped) const.

pub unsafe fn to_image_2a( &self, flipped: bool, color_attachment_index: c_int, ) -> CppBox<QImage>

Calls C++ function: QImage QOpenGLFramebufferObject::toImage(bool flipped, int colorAttachmentIndex) const.

pub unsafe fn width(&self) -> c_int

Calls C++ function: int QOpenGLFramebufferObject::width() const.