pub struct QPainterPath { /* private fields */ }Expand description
C++ class: QPainterPath.
Implementations
Sourceimpl QPainterPath
impl QPainterPath
Sourcepub unsafe fn add_assign(
&self,
other: impl CastInto<Ref<QPainterPath>>,
) -> Ref<QPainterPath>
pub unsafe fn add_assign( &self, other: impl CastInto<Ref<QPainterPath>>, ) -> Ref<QPainterPath>
Calls C++ function: QPainterPath& QPainterPath::operator+=(const QPainterPath& other).
Sourcepub unsafe fn add_ellipse_1a(&self, rect: impl CastInto<Ref<QRectF>>)
pub unsafe fn add_ellipse_1a(&self, rect: impl CastInto<Ref<QRectF>>)
Calls C++ function: void QPainterPath::addEllipse(const QRectF& rect).
Sourcepub unsafe fn add_ellipse_4a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
)
pub unsafe fn add_ellipse_4a( &self, x: c_double, y: c_double, w: c_double, h: c_double, )
Calls C++ function: void QPainterPath::addEllipse(double x, double y, double w, double h).
Sourcepub unsafe fn add_ellipse_3a(
&self,
center: impl CastInto<Ref<QPointF>>,
rx: c_double,
ry: c_double,
)
pub unsafe fn add_ellipse_3a( &self, center: impl CastInto<Ref<QPointF>>, rx: c_double, ry: c_double, )
Calls C++ function: void QPainterPath::addEllipse(const QPointF& center, double rx, double ry).
Sourcepub unsafe fn add_path(&self, path: impl CastInto<Ref<QPainterPath>>)
pub unsafe fn add_path(&self, path: impl CastInto<Ref<QPainterPath>>)
Calls C++ function: void QPainterPath::addPath(const QPainterPath& path).
Sourcepub unsafe fn add_polygon(&self, polygon: impl CastInto<Ref<QPolygonF>>)
pub unsafe fn add_polygon(&self, polygon: impl CastInto<Ref<QPolygonF>>)
Calls C++ function: void QPainterPath::addPolygon(const QPolygonF& polygon).
Sourcepub unsafe fn add_rect_1a(&self, rect: impl CastInto<Ref<QRectF>>)
pub unsafe fn add_rect_1a(&self, rect: impl CastInto<Ref<QRectF>>)
Calls C++ function: void QPainterPath::addRect(const QRectF& rect).
Sourcepub unsafe fn add_rect_4a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
)
pub unsafe fn add_rect_4a( &self, x: c_double, y: c_double, w: c_double, h: c_double, )
Calls C++ function: void QPainterPath::addRect(double x, double y, double w, double h).
Sourcepub unsafe fn add_region(&self, region: impl CastInto<Ref<QRegion>>)
pub unsafe fn add_region(&self, region: impl CastInto<Ref<QRegion>>)
Calls C++ function: void QPainterPath::addRegion(const QRegion& region).
Sourcepub unsafe fn add_round_rect_3a(
&self,
rect: impl CastInto<Ref<QRectF>>,
x_rnd: c_int,
y_rnd: c_int,
)
pub unsafe fn add_round_rect_3a( &self, rect: impl CastInto<Ref<QRectF>>, x_rnd: c_int, y_rnd: c_int, )
Calls C++ function: void QPainterPath::addRoundRect(const QRectF& rect, int xRnd, int yRnd).
Sourcepub unsafe fn add_round_rect_6a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
x_rnd: c_int,
y_rnd: c_int,
)
pub unsafe fn add_round_rect_6a( &self, x: c_double, y: c_double, w: c_double, h: c_double, x_rnd: c_int, y_rnd: c_int, )
Calls C++ function: void QPainterPath::addRoundRect(double x, double y, double w, double h, int xRnd, int yRnd).
Sourcepub unsafe fn add_round_rect_2a(
&self,
rect: impl CastInto<Ref<QRectF>>,
roundness: c_int,
)
pub unsafe fn add_round_rect_2a( &self, rect: impl CastInto<Ref<QRectF>>, roundness: c_int, )
Calls C++ function: void QPainterPath::addRoundRect(const QRectF& rect, int roundness).
Sourcepub unsafe fn add_round_rect_5a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
roundness: c_int,
)
pub unsafe fn add_round_rect_5a( &self, x: c_double, y: c_double, w: c_double, h: c_double, roundness: c_int, )
Calls C++ function: void QPainterPath::addRoundRect(double x, double y, double w, double h, int roundness).
Sourcepub unsafe fn add_rounded_rect_4a(
&self,
rect: impl CastInto<Ref<QRectF>>,
x_radius: c_double,
y_radius: c_double,
mode: SizeMode,
)
pub unsafe fn add_rounded_rect_4a( &self, rect: impl CastInto<Ref<QRectF>>, x_radius: c_double, y_radius: c_double, mode: SizeMode, )
Calls C++ function: void QPainterPath::addRoundedRect(const QRectF& rect, double xRadius, double yRadius, Qt::SizeMode mode = …).
Sourcepub unsafe fn add_rounded_rect_7a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
x_radius: c_double,
y_radius: c_double,
mode: SizeMode,
)
pub unsafe fn add_rounded_rect_7a( &self, x: c_double, y: c_double, w: c_double, h: c_double, x_radius: c_double, y_radius: c_double, mode: SizeMode, )
Calls C++ function: void QPainterPath::addRoundedRect(double x, double y, double w, double h, double xRadius, double yRadius, Qt::SizeMode mode = …).
Sourcepub unsafe fn add_rounded_rect_3a(
&self,
rect: impl CastInto<Ref<QRectF>>,
x_radius: c_double,
y_radius: c_double,
)
pub unsafe fn add_rounded_rect_3a( &self, rect: impl CastInto<Ref<QRectF>>, x_radius: c_double, y_radius: c_double, )
Calls C++ function: void QPainterPath::addRoundedRect(const QRectF& rect, double xRadius, double yRadius).
Sourcepub unsafe fn add_rounded_rect_6a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
x_radius: c_double,
y_radius: c_double,
)
pub unsafe fn add_rounded_rect_6a( &self, x: c_double, y: c_double, w: c_double, h: c_double, x_radius: c_double, y_radius: c_double, )
Calls C++ function: void QPainterPath::addRoundedRect(double x, double y, double w, double h, double xRadius, double yRadius).
Sourcepub unsafe fn add_text_3a(
&self,
point: impl CastInto<Ref<QPointF>>,
f: impl CastInto<Ref<QFont>>,
text: impl CastInto<Ref<QString>>,
)
pub unsafe fn add_text_3a( &self, point: impl CastInto<Ref<QPointF>>, f: impl CastInto<Ref<QFont>>, text: impl CastInto<Ref<QString>>, )
Calls C++ function: void QPainterPath::addText(const QPointF& point, const QFont& f, const QString& text).
Sourcepub unsafe fn add_text_4a(
&self,
x: c_double,
y: c_double,
f: impl CastInto<Ref<QFont>>,
text: impl CastInto<Ref<QString>>,
)
pub unsafe fn add_text_4a( &self, x: c_double, y: c_double, f: impl CastInto<Ref<QFont>>, text: impl CastInto<Ref<QString>>, )
Calls C++ function: void QPainterPath::addText(double x, double y, const QFont& f, const QString& text).
Sourcepub unsafe fn angle_at_percent(&self, t: c_double) -> c_double
pub unsafe fn angle_at_percent(&self, t: c_double) -> c_double
Calls C++ function: double QPainterPath::angleAtPercent(double t) const.
Sourcepub unsafe fn arc_move_to_2a(
&self,
rect: impl CastInto<Ref<QRectF>>,
angle: c_double,
)
pub unsafe fn arc_move_to_2a( &self, rect: impl CastInto<Ref<QRectF>>, angle: c_double, )
Calls C++ function: void QPainterPath::arcMoveTo(const QRectF& rect, double angle).
Sourcepub unsafe fn arc_move_to_5a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
angle: c_double,
)
pub unsafe fn arc_move_to_5a( &self, x: c_double, y: c_double, w: c_double, h: c_double, angle: c_double, )
Calls C++ function: void QPainterPath::arcMoveTo(double x, double y, double w, double h, double angle).
Sourcepub unsafe fn arc_to_3a(
&self,
rect: impl CastInto<Ref<QRectF>>,
start_angle: c_double,
arc_length: c_double,
)
pub unsafe fn arc_to_3a( &self, rect: impl CastInto<Ref<QRectF>>, start_angle: c_double, arc_length: c_double, )
Calls C++ function: void QPainterPath::arcTo(const QRectF& rect, double startAngle, double arcLength).
Sourcepub unsafe fn arc_to_6a(
&self,
x: c_double,
y: c_double,
w: c_double,
h: c_double,
start_angle: c_double,
arc_length: c_double,
)
pub unsafe fn arc_to_6a( &self, x: c_double, y: c_double, w: c_double, h: c_double, start_angle: c_double, arc_length: c_double, )
Calls C++ function: void QPainterPath::arcTo(double x, double y, double w, double h, double startAngle, double arcLength).
Sourcepub unsafe fn bit_and_assign(
&self,
other: impl CastInto<Ref<QPainterPath>>,
) -> Ref<QPainterPath>
pub unsafe fn bit_and_assign( &self, other: impl CastInto<Ref<QPainterPath>>, ) -> Ref<QPainterPath>
Calls C++ function: QPainterPath& QPainterPath::operator&=(const QPainterPath& other).
Sourcepub unsafe fn bit_or_assign(
&self,
other: impl CastInto<Ref<QPainterPath>>,
) -> Ref<QPainterPath>
pub unsafe fn bit_or_assign( &self, other: impl CastInto<Ref<QPainterPath>>, ) -> Ref<QPainterPath>
Calls C++ function: QPainterPath& QPainterPath::operator|=(const QPainterPath& other).
Sourcepub unsafe fn bounding_rect(&self) -> CppBox<QRectF>
pub unsafe fn bounding_rect(&self) -> CppBox<QRectF>
Calls C++ function: QRectF QPainterPath::boundingRect() const.
Sourcepub unsafe fn close_subpath(&self)
pub unsafe fn close_subpath(&self)
Calls C++ function: void QPainterPath::closeSubpath().
Sourcepub unsafe fn connect_path(&self, path: impl CastInto<Ref<QPainterPath>>)
pub unsafe fn connect_path(&self, path: impl CastInto<Ref<QPainterPath>>)
Calls C++ function: void QPainterPath::connectPath(const QPainterPath& path).
Sourcepub unsafe fn contains_q_point_f(&self, pt: impl CastInto<Ref<QPointF>>) -> bool
pub unsafe fn contains_q_point_f(&self, pt: impl CastInto<Ref<QPointF>>) -> bool
Calls C++ function: bool QPainterPath::contains(const QPointF& pt) const.
Sourcepub unsafe fn contains_q_rect_f(&self, rect: impl CastInto<Ref<QRectF>>) -> bool
pub unsafe fn contains_q_rect_f(&self, rect: impl CastInto<Ref<QRectF>>) -> bool
Calls C++ function: bool QPainterPath::contains(const QRectF& rect) const.
Sourcepub unsafe fn contains_q_painter_path(
&self,
p: impl CastInto<Ref<QPainterPath>>,
) -> bool
pub unsafe fn contains_q_painter_path( &self, p: impl CastInto<Ref<QPainterPath>>, ) -> bool
Calls C++ function: bool QPainterPath::contains(const QPainterPath& p) const.
Sourcepub unsafe fn control_point_rect(&self) -> CppBox<QRectF>
pub unsafe fn control_point_rect(&self) -> CppBox<QRectF>
Calls C++ function: QRectF QPainterPath::controlPointRect() const.
Sourcepub unsafe fn copy_from(
&self,
other: impl CastInto<Ref<QPainterPath>>,
) -> Ref<QPainterPath>
pub unsafe fn copy_from( &self, other: impl CastInto<Ref<QPainterPath>>, ) -> Ref<QPainterPath>
Calls C++ function: QPainterPath& QPainterPath::operator=(const QPainterPath& other).
Sourcepub unsafe fn cubic_to_3a(
&self,
ctrl_pt1: impl CastInto<Ref<QPointF>>,
ctrl_pt2: impl CastInto<Ref<QPointF>>,
end_pt: impl CastInto<Ref<QPointF>>,
)
pub unsafe fn cubic_to_3a( &self, ctrl_pt1: impl CastInto<Ref<QPointF>>, ctrl_pt2: impl CastInto<Ref<QPointF>>, end_pt: impl CastInto<Ref<QPointF>>, )
Calls C++ function: void QPainterPath::cubicTo(const QPointF& ctrlPt1, const QPointF& ctrlPt2, const QPointF& endPt).
Sourcepub unsafe fn cubic_to_6a(
&self,
ctrl_pt_1x: c_double,
ctrl_pt_1y: c_double,
ctrl_pt_2x: c_double,
ctrl_pt_2y: c_double,
end_ptx: c_double,
end_pty: c_double,
)
pub unsafe fn cubic_to_6a( &self, ctrl_pt_1x: c_double, ctrl_pt_1y: c_double, ctrl_pt_2x: c_double, ctrl_pt_2y: c_double, end_ptx: c_double, end_pty: c_double, )
Calls C++ function: void QPainterPath::cubicTo(double ctrlPt1x, double ctrlPt1y, double ctrlPt2x, double ctrlPt2y, double endPtx, double endPty).
Sourcepub unsafe fn current_position(&self) -> CppBox<QPointF>
pub unsafe fn current_position(&self) -> CppBox<QPointF>
Calls C++ function: QPointF QPainterPath::currentPosition() const.
Sourcepub unsafe fn element_at(&self, i: c_int) -> CppBox<Element>
pub unsafe fn element_at(&self, i: c_int) -> CppBox<Element>
Calls C++ function: QPainterPath::Element QPainterPath::elementAt(int i) const.
Sourcepub unsafe fn element_count(&self) -> c_int
pub unsafe fn element_count(&self) -> c_int
Calls C++ function: int QPainterPath::elementCount() const.
Sourcepub unsafe fn fill_rule(&self) -> FillRule
pub unsafe fn fill_rule(&self) -> FillRule
Calls C++ function: Qt::FillRule QPainterPath::fillRule() const.
Sourcepub unsafe fn intersected(
&self,
r: impl CastInto<Ref<QPainterPath>>,
) -> CppBox<QPainterPath>
pub unsafe fn intersected( &self, r: impl CastInto<Ref<QPainterPath>>, ) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::intersected(const QPainterPath& r) const.
Sourcepub unsafe fn intersects_q_rect_f(
&self,
rect: impl CastInto<Ref<QRectF>>,
) -> bool
pub unsafe fn intersects_q_rect_f( &self, rect: impl CastInto<Ref<QRectF>>, ) -> bool
Calls C++ function: bool QPainterPath::intersects(const QRectF& rect) const.
Sourcepub unsafe fn intersects_q_painter_path(
&self,
p: impl CastInto<Ref<QPainterPath>>,
) -> bool
pub unsafe fn intersects_q_painter_path( &self, p: impl CastInto<Ref<QPainterPath>>, ) -> bool
Calls C++ function: bool QPainterPath::intersects(const QPainterPath& p) const.
Sourcepub unsafe fn length(&self) -> c_double
pub unsafe fn length(&self) -> c_double
Calls C++ function: double QPainterPath::length() const.
Sourcepub unsafe fn line_to_1a(&self, p: impl CastInto<Ref<QPointF>>)
pub unsafe fn line_to_1a(&self, p: impl CastInto<Ref<QPointF>>)
Calls C++ function: void QPainterPath::lineTo(const QPointF& p).
Sourcepub unsafe fn line_to_2a(&self, x: c_double, y: c_double)
pub unsafe fn line_to_2a(&self, x: c_double, y: c_double)
Calls C++ function: void QPainterPath::lineTo(double x, double y).
Sourcepub unsafe fn move_to_1a(&self, p: impl CastInto<Ref<QPointF>>)
pub unsafe fn move_to_1a(&self, p: impl CastInto<Ref<QPointF>>)
Calls C++ function: void QPainterPath::moveTo(const QPointF& p).
Sourcepub unsafe fn move_to_2a(&self, x: c_double, y: c_double)
pub unsafe fn move_to_2a(&self, x: c_double, y: c_double)
Calls C++ function: void QPainterPath::moveTo(double x, double y).
Sourcepub unsafe fn new_0a() -> CppBox<QPainterPath>
pub unsafe fn new_0a() -> CppBox<QPainterPath>
Calls C++ function: [constructor] void QPainterPath::QPainterPath().
Sourcepub unsafe fn new_1a(
start_point: impl CastInto<Ref<QPointF>>,
) -> CppBox<QPainterPath>
pub unsafe fn new_1a( start_point: impl CastInto<Ref<QPointF>>, ) -> CppBox<QPainterPath>
Calls C++ function: [constructor] void QPainterPath::QPainterPath(const QPointF& startPoint).
Sourcepub unsafe fn new_copy(
other: impl CastInto<Ref<QPainterPath>>,
) -> CppBox<QPainterPath>
pub unsafe fn new_copy( other: impl CastInto<Ref<QPainterPath>>, ) -> CppBox<QPainterPath>
Calls C++ function: [constructor] void QPainterPath::QPainterPath(const QPainterPath& other).
Sourcepub unsafe fn percent_at_length(&self, t: c_double) -> c_double
pub unsafe fn percent_at_length(&self, t: c_double) -> c_double
Calls C++ function: double QPainterPath::percentAtLength(double t) const.
Sourcepub unsafe fn point_at_percent(&self, t: c_double) -> CppBox<QPointF>
pub unsafe fn point_at_percent(&self, t: c_double) -> CppBox<QPointF>
Calls C++ function: QPointF QPainterPath::pointAtPercent(double t) const.
Sourcepub unsafe fn quad_to_2a(
&self,
ctrl_pt: impl CastInto<Ref<QPointF>>,
end_pt: impl CastInto<Ref<QPointF>>,
)
pub unsafe fn quad_to_2a( &self, ctrl_pt: impl CastInto<Ref<QPointF>>, end_pt: impl CastInto<Ref<QPointF>>, )
Calls C++ function: void QPainterPath::quadTo(const QPointF& ctrlPt, const QPointF& endPt).
Sourcepub unsafe fn quad_to_4a(
&self,
ctrl_ptx: c_double,
ctrl_pty: c_double,
end_ptx: c_double,
end_pty: c_double,
)
pub unsafe fn quad_to_4a( &self, ctrl_ptx: c_double, ctrl_pty: c_double, end_ptx: c_double, end_pty: c_double, )
Calls C++ function: void QPainterPath::quadTo(double ctrlPtx, double ctrlPty, double endPtx, double endPty).
Sourcepub unsafe fn reserve(&self, size: c_int)
pub unsafe fn reserve(&self, size: c_int)
Calls C++ function: void QPainterPath::reserve(int size).
Sourcepub unsafe fn set_element_position_at(&self, i: c_int, x: c_double, y: c_double)
pub unsafe fn set_element_position_at(&self, i: c_int, x: c_double, y: c_double)
Calls C++ function: void QPainterPath::setElementPositionAt(int i, double x, double y).
Sourcepub unsafe fn set_fill_rule(&self, fill_rule: FillRule)
pub unsafe fn set_fill_rule(&self, fill_rule: FillRule)
Calls C++ function: void QPainterPath::setFillRule(Qt::FillRule fillRule).
Sourcepub unsafe fn simplified(&self) -> CppBox<QPainterPath>
pub unsafe fn simplified(&self) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::simplified() const.
Sourcepub unsafe fn slope_at_percent(&self, t: c_double) -> c_double
pub unsafe fn slope_at_percent(&self, t: c_double) -> c_double
Calls C++ function: double QPainterPath::slopeAtPercent(double t) const.
Sourcepub unsafe fn sub_assign(
&self,
other: impl CastInto<Ref<QPainterPath>>,
) -> Ref<QPainterPath>
pub unsafe fn sub_assign( &self, other: impl CastInto<Ref<QPainterPath>>, ) -> Ref<QPainterPath>
Calls C++ function: QPainterPath& QPainterPath::operator-=(const QPainterPath& other).
Sourcepub unsafe fn subtracted(
&self,
r: impl CastInto<Ref<QPainterPath>>,
) -> CppBox<QPainterPath>
pub unsafe fn subtracted( &self, r: impl CastInto<Ref<QPainterPath>>, ) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::subtracted(const QPainterPath& r) const.
Sourcepub unsafe fn subtracted_inverted(
&self,
r: impl CastInto<Ref<QPainterPath>>,
) -> CppBox<QPainterPath>
pub unsafe fn subtracted_inverted( &self, r: impl CastInto<Ref<QPainterPath>>, ) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::subtractedInverted(const QPainterPath& r) const.
Sourcepub unsafe fn swap(&self, other: impl CastInto<Ref<QPainterPath>>)
pub unsafe fn swap(&self, other: impl CastInto<Ref<QPainterPath>>)
Calls C++ function: void QPainterPath::swap(QPainterPath& other).
Sourcepub unsafe fn to_fill_polygon_q_matrix(
&self,
matrix: impl CastInto<Ref<QMatrix>>,
) -> CppBox<QPolygonF>
pub unsafe fn to_fill_polygon_q_matrix( &self, matrix: impl CastInto<Ref<QMatrix>>, ) -> CppBox<QPolygonF>
Calls C++ function: QPolygonF QPainterPath::toFillPolygon(const QMatrix& matrix) const.
Sourcepub unsafe fn to_fill_polygon_q_transform(
&self,
matrix: impl CastInto<Ref<QTransform>>,
) -> CppBox<QPolygonF>
pub unsafe fn to_fill_polygon_q_transform( &self, matrix: impl CastInto<Ref<QTransform>>, ) -> CppBox<QPolygonF>
Calls C++ function: QPolygonF QPainterPath::toFillPolygon(const QTransform& matrix = …) const.
Sourcepub unsafe fn to_fill_polygon(&self) -> CppBox<QPolygonF>
pub unsafe fn to_fill_polygon(&self) -> CppBox<QPolygonF>
Calls C++ function: QPolygonF QPainterPath::toFillPolygon() const.
Sourcepub unsafe fn to_fill_polygons_q_matrix(
&self,
matrix: impl CastInto<Ref<QMatrix>>,
) -> CppBox<QListOfQPolygonF>
pub unsafe fn to_fill_polygons_q_matrix( &self, matrix: impl CastInto<Ref<QMatrix>>, ) -> CppBox<QListOfQPolygonF>
Calls C++ function: QList<QPolygonF> QPainterPath::toFillPolygons(const QMatrix& matrix) const.
Sourcepub unsafe fn to_fill_polygons_q_transform(
&self,
matrix: impl CastInto<Ref<QTransform>>,
) -> CppBox<QListOfQPolygonF>
pub unsafe fn to_fill_polygons_q_transform( &self, matrix: impl CastInto<Ref<QTransform>>, ) -> CppBox<QListOfQPolygonF>
Calls C++ function: QList<QPolygonF> QPainterPath::toFillPolygons(const QTransform& matrix = …) const.
Sourcepub unsafe fn to_fill_polygons(&self) -> CppBox<QListOfQPolygonF>
pub unsafe fn to_fill_polygons(&self) -> CppBox<QListOfQPolygonF>
Calls C++ function: QList<QPolygonF> QPainterPath::toFillPolygons() const.
Sourcepub unsafe fn to_reversed(&self) -> CppBox<QPainterPath>
pub unsafe fn to_reversed(&self) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::toReversed() const.
Sourcepub unsafe fn to_subpath_polygons_q_matrix(
&self,
matrix: impl CastInto<Ref<QMatrix>>,
) -> CppBox<QListOfQPolygonF>
pub unsafe fn to_subpath_polygons_q_matrix( &self, matrix: impl CastInto<Ref<QMatrix>>, ) -> CppBox<QListOfQPolygonF>
Calls C++ function: QList<QPolygonF> QPainterPath::toSubpathPolygons(const QMatrix& matrix) const.
Sourcepub unsafe fn to_subpath_polygons_q_transform(
&self,
matrix: impl CastInto<Ref<QTransform>>,
) -> CppBox<QListOfQPolygonF>
pub unsafe fn to_subpath_polygons_q_transform( &self, matrix: impl CastInto<Ref<QTransform>>, ) -> CppBox<QListOfQPolygonF>
Calls C++ function: QList<QPolygonF> QPainterPath::toSubpathPolygons(const QTransform& matrix = …) const.
Sourcepub unsafe fn to_subpath_polygons(&self) -> CppBox<QListOfQPolygonF>
pub unsafe fn to_subpath_polygons(&self) -> CppBox<QListOfQPolygonF>
Calls C++ function: QList<QPolygonF> QPainterPath::toSubpathPolygons() const.
Sourcepub unsafe fn translate_2a(&self, dx: c_double, dy: c_double)
pub unsafe fn translate_2a(&self, dx: c_double, dy: c_double)
Calls C++ function: void QPainterPath::translate(double dx, double dy).
Sourcepub unsafe fn translate_1a(&self, offset: impl CastInto<Ref<QPointF>>)
pub unsafe fn translate_1a(&self, offset: impl CastInto<Ref<QPointF>>)
Calls C++ function: void QPainterPath::translate(const QPointF& offset).
Sourcepub unsafe fn translated_2a(
&self,
dx: c_double,
dy: c_double,
) -> CppBox<QPainterPath>
pub unsafe fn translated_2a( &self, dx: c_double, dy: c_double, ) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::translated(double dx, double dy) const.
Sourcepub unsafe fn translated_1a(
&self,
offset: impl CastInto<Ref<QPointF>>,
) -> CppBox<QPainterPath>
pub unsafe fn translated_1a( &self, offset: impl CastInto<Ref<QPointF>>, ) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::translated(const QPointF& offset) const.
Sourcepub unsafe fn united(
&self,
r: impl CastInto<Ref<QPainterPath>>,
) -> CppBox<QPainterPath>
pub unsafe fn united( &self, r: impl CastInto<Ref<QPainterPath>>, ) -> CppBox<QPainterPath>
Calls C++ function: QPainterPath QPainterPath::united(const QPainterPath& r) const.