pub struct QStyleHints { /* private fields */ }Expand description
C++ class: QStyleHints.
Implementations
Sourceimpl QStyleHints
impl QStyleHints
Sourcepub fn cursor_flash_time_changed(&self) -> Signal<(c_int,)>
pub fn cursor_flash_time_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::cursorFlashTimeChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn keyboard_input_interval_changed(&self) -> Signal<(c_int,)>
pub fn keyboard_input_interval_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::keyboardInputIntervalChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn mouse_double_click_interval_changed(&self) -> Signal<(c_int,)>
pub fn mouse_double_click_interval_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::mouseDoubleClickIntervalChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn mouse_press_and_hold_interval_changed(&self) -> Signal<(c_int,)>
pub fn mouse_press_and_hold_interval_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::mousePressAndHoldIntervalChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn start_drag_distance_changed(&self) -> Signal<(c_int,)>
pub fn start_drag_distance_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::startDragDistanceChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn start_drag_time_changed(&self) -> Signal<(c_int,)>
pub fn start_drag_time_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::startDragTimeChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn tab_focus_behavior_changed(&self) -> Signal<(TabFocusBehavior,)>
pub fn tab_focus_behavior_changed(&self) -> Signal<(TabFocusBehavior,)>
Returns a built-in Qt signal QStyleHints::tabFocusBehaviorChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn use_hover_effects_changed(&self) -> Signal<(bool,)>
pub fn use_hover_effects_changed(&self) -> Signal<(bool,)>
Returns a built-in Qt signal QStyleHints::useHoverEffectsChanged that can be passed to qt_core::Signal::connect.
Returns a built-in Qt signal QStyleHints::showShortcutsInContextMenusChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn wheel_scroll_lines_changed(&self) -> Signal<(c_int,)>
pub fn wheel_scroll_lines_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::wheelScrollLinesChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn mouse_quick_selection_threshold_changed(&self) -> Signal<(c_int,)>
pub fn mouse_quick_selection_threshold_changed(&self) -> Signal<(c_int,)>
Returns a built-in Qt signal QStyleHints::mouseQuickSelectionThresholdChanged that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn cursor_flash_time(&self) -> c_int
pub unsafe fn cursor_flash_time(&self) -> c_int
Calls C++ function: int QStyleHints::cursorFlashTime() const.
Sourcepub unsafe fn font_smoothing_gamma(&self) -> c_double
pub unsafe fn font_smoothing_gamma(&self) -> c_double
Calls C++ function: double QStyleHints::fontSmoothingGamma() const.
Sourcepub unsafe fn keyboard_auto_repeat_rate(&self) -> c_int
pub unsafe fn keyboard_auto_repeat_rate(&self) -> c_int
Calls C++ function: int QStyleHints::keyboardAutoRepeatRate() const.
Sourcepub unsafe fn keyboard_input_interval(&self) -> c_int
pub unsafe fn keyboard_input_interval(&self) -> c_int
Calls C++ function: int QStyleHints::keyboardInputInterval() const.
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QStyleHints::metaObject() const.
Sourcepub unsafe fn mouse_double_click_distance(&self) -> c_int
pub unsafe fn mouse_double_click_distance(&self) -> c_int
Calls C++ function: int QStyleHints::mouseDoubleClickDistance() const.
Sourcepub unsafe fn mouse_double_click_interval(&self) -> c_int
pub unsafe fn mouse_double_click_interval(&self) -> c_int
Calls C++ function: int QStyleHints::mouseDoubleClickInterval() const.
Sourcepub unsafe fn mouse_press_and_hold_interval(&self) -> c_int
pub unsafe fn mouse_press_and_hold_interval(&self) -> c_int
Calls C++ function: int QStyleHints::mousePressAndHoldInterval() const.
Sourcepub unsafe fn mouse_quick_selection_threshold(&self) -> c_int
pub unsafe fn mouse_quick_selection_threshold(&self) -> c_int
Calls C++ function: int QStyleHints::mouseQuickSelectionThreshold() const.
Sourcepub unsafe fn password_mask_character(&self) -> CppBox<QChar>
pub unsafe fn password_mask_character(&self) -> CppBox<QChar>
Calls C++ function: QChar QStyleHints::passwordMaskCharacter() const.
Sourcepub unsafe fn password_mask_delay(&self) -> c_int
pub unsafe fn password_mask_delay(&self) -> c_int
Calls C++ function: int QStyleHints::passwordMaskDelay() const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: c_int,
arg3: *mut *mut c_void,
) -> c_int
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: c_int, arg3: *mut *mut c_void, ) -> c_int
Calls C++ function: virtual int QStyleHints::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const c_char) -> *mut c_void
Calls C++ function: virtual void* QStyleHints::qt_metacast(const char* arg1).
Sourcepub unsafe fn set_cursor_flash_time(&self, cursor_flash_time: c_int)
pub unsafe fn set_cursor_flash_time(&self, cursor_flash_time: c_int)
Calls C++ function: void QStyleHints::setCursorFlashTime(int cursorFlashTime).
Sourcepub unsafe fn set_focus_on_touch_release(&self) -> bool
pub unsafe fn set_focus_on_touch_release(&self) -> bool
Calls C++ function: bool QStyleHints::setFocusOnTouchRelease() const.
Sourcepub unsafe fn set_keyboard_input_interval(&self, keyboard_input_interval: c_int)
pub unsafe fn set_keyboard_input_interval(&self, keyboard_input_interval: c_int)
Calls C++ function: void QStyleHints::setKeyboardInputInterval(int keyboardInputInterval).
Sourcepub unsafe fn set_mouse_double_click_interval(
&self,
mouse_double_click_interval: c_int,
)
pub unsafe fn set_mouse_double_click_interval( &self, mouse_double_click_interval: c_int, )
Calls C++ function: void QStyleHints::setMouseDoubleClickInterval(int mouseDoubleClickInterval).
Sourcepub unsafe fn set_mouse_press_and_hold_interval(
&self,
mouse_press_and_hold_interval: c_int,
)
pub unsafe fn set_mouse_press_and_hold_interval( &self, mouse_press_and_hold_interval: c_int, )
Calls C++ function: void QStyleHints::setMousePressAndHoldInterval(int mousePressAndHoldInterval).
Sourcepub unsafe fn set_mouse_quick_selection_threshold(&self, threshold: c_int)
pub unsafe fn set_mouse_quick_selection_threshold(&self, threshold: c_int)
Calls C++ function: void QStyleHints::setMouseQuickSelectionThreshold(int threshold).
Calls C++ function: void QStyleHints::setShowShortcutsInContextMenus(bool showShortcutsInContextMenus).
Sourcepub unsafe fn set_start_drag_distance(&self, start_drag_distance: c_int)
pub unsafe fn set_start_drag_distance(&self, start_drag_distance: c_int)
Calls C++ function: void QStyleHints::setStartDragDistance(int startDragDistance).
Sourcepub unsafe fn set_start_drag_time(&self, start_drag_time: c_int)
pub unsafe fn set_start_drag_time(&self, start_drag_time: c_int)
Calls C++ function: void QStyleHints::setStartDragTime(int startDragTime).
Sourcepub unsafe fn set_tab_focus_behavior(
&self,
tab_focus_behavior: TabFocusBehavior,
)
pub unsafe fn set_tab_focus_behavior( &self, tab_focus_behavior: TabFocusBehavior, )
Calls C++ function: void QStyleHints::setTabFocusBehavior(Qt::TabFocusBehavior tabFocusBehavior).
Sourcepub unsafe fn set_use_hover_effects(&self, use_hover_effects: bool)
pub unsafe fn set_use_hover_effects(&self, use_hover_effects: bool)
Calls C++ function: void QStyleHints::setUseHoverEffects(bool useHoverEffects).
Sourcepub unsafe fn set_wheel_scroll_lines(&self, scroll_lines: c_int)
pub unsafe fn set_wheel_scroll_lines(&self, scroll_lines: c_int)
Calls C++ function: void QStyleHints::setWheelScrollLines(int scrollLines).
Sourcepub unsafe fn show_is_full_screen(&self) -> bool
pub unsafe fn show_is_full_screen(&self) -> bool
Calls C++ function: bool QStyleHints::showIsFullScreen() const.
Sourcepub unsafe fn show_is_maximized(&self) -> bool
pub unsafe fn show_is_maximized(&self) -> bool
Calls C++ function: bool QStyleHints::showIsMaximized() const.
Calls C++ function: bool QStyleHints::showShortcutsInContextMenus() const.
Sourcepub unsafe fn single_click_activation(&self) -> bool
pub unsafe fn single_click_activation(&self) -> bool
Calls C++ function: bool QStyleHints::singleClickActivation() const.
Sourcepub unsafe fn start_drag_distance(&self) -> c_int
pub unsafe fn start_drag_distance(&self) -> c_int
Calls C++ function: int QStyleHints::startDragDistance() const.
Sourcepub unsafe fn start_drag_time(&self) -> c_int
pub unsafe fn start_drag_time(&self) -> c_int
Calls C++ function: int QStyleHints::startDragTime() const.
Sourcepub unsafe fn start_drag_velocity(&self) -> c_int
pub unsafe fn start_drag_velocity(&self) -> c_int
Calls C++ function: int QStyleHints::startDragVelocity() const.
Sourcepub unsafe fn static_meta_object() -> Ref<QMetaObject>
pub unsafe fn static_meta_object() -> Ref<QMetaObject>
Returns a reference to the staticMetaObject field.
Sourcepub unsafe fn tab_focus_behavior(&self) -> TabFocusBehavior
pub unsafe fn tab_focus_behavior(&self) -> TabFocusBehavior
Calls C++ function: Qt::TabFocusBehavior QStyleHints::tabFocusBehavior() const.
Sourcepub unsafe fn touch_double_tap_distance(&self) -> c_int
pub unsafe fn touch_double_tap_distance(&self) -> c_int
Calls C++ function: int QStyleHints::touchDoubleTapDistance() const.
Sourcepub unsafe fn tr(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QStyleHints::tr(const char* s, const char* c, int n).
Sourcepub unsafe fn tr_utf8(
s: *const c_char,
c: *const c_char,
n: c_int,
) -> CppBox<QString>
pub unsafe fn tr_utf8( s: *const c_char, c: *const c_char, n: c_int, ) -> CppBox<QString>
Calls C++ function: static QString QStyleHints::trUtf8(const char* s, const char* c, int n).
Sourcepub unsafe fn use_hover_effects(&self) -> bool
pub unsafe fn use_hover_effects(&self) -> bool
Calls C++ function: bool QStyleHints::useHoverEffects() const.
Sourcepub unsafe fn use_rtl_extensions(&self) -> bool
pub unsafe fn use_rtl_extensions(&self) -> bool
Calls C++ function: bool QStyleHints::useRtlExtensions() const.
Sourcepub unsafe fn wheel_scroll_lines(&self) -> c_int
pub unsafe fn wheel_scroll_lines(&self) -> c_int
Calls C++ function: int QStyleHints::wheelScrollLines() const.
Methods from Deref<Target = QObject>
Sourcepub unsafe fn find_child<T>(
&self,
name: &str,
) -> Result<QPtr<T>, FindChildError>
pub unsafe fn find_child<T>( &self, name: &str, ) -> Result<QPtr<T>, FindChildError>
Finds a child of self with the specified object name
and casts it to type T.
The search is performed recursively. If there is more than one child matching the search, the most direct ancestor is returned. If there are several direct ancestors, it is undefined which one will be returned.
Returns an error if there is no child object with object name name or
the found object cannot be cast to T.
Sourcepub fn destroyed(&self) -> Signal<(*mut QObject,)>
pub fn destroyed(&self) -> Signal<(*mut QObject,)>
Returns a built-in Qt signal QObject::destroyed that can be passed to qt_core::Signal::connect.
Sourcepub fn object_name_changed(&self) -> Signal<(*const QString,)>
pub fn object_name_changed(&self) -> Signal<(*const QString,)>
Returns a built-in Qt signal QObject::objectNameChanged that can be passed to qt_core::Signal::connect.
Sourcepub fn slot_delete_later(&self) -> Receiver<()>
pub fn slot_delete_later(&self) -> Receiver<()>
Returns a built-in Qt slot QObject::deleteLater that can be passed to qt_core::Signal::connect.
Sourcepub unsafe fn block_signals(&self, b: bool) -> bool
pub unsafe fn block_signals(&self, b: bool) -> bool
Calls C++ function: bool QObject::blockSignals(bool b).
Sourcepub unsafe fn children(&self) -> Ref<QListOfQObject>
pub unsafe fn children(&self) -> Ref<QListOfQObject>
Calls C++ function: const QList<QObject*>& QObject::children() const.
Sourcepub unsafe fn delete_later(&self)
pub unsafe fn delete_later(&self)
Calls C++ function: [slot] void QObject::deleteLater().
Sourcepub unsafe fn disconnect_char_q_object_char(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_char_q_object_char( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …, const char* member = …) const.
Sourcepub unsafe fn disconnect_q_object_char(
&self,
receiver: impl CastInto<Ptr<QObject>>,
member: *const i8,
) -> bool
pub unsafe fn disconnect_q_object_char( &self, receiver: impl CastInto<Ptr<QObject>>, member: *const i8, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver, const char* member = …) const.
Sourcepub unsafe fn disconnect_char_q_object(
&self,
signal: *const i8,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_char_q_object( &self, signal: *const i8, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …, const QObject* receiver = …) const.
Sourcepub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
pub unsafe fn disconnect_char(&self, signal: *const i8) -> bool
Calls C++ function: bool QObject::disconnect(const char* signal = …) const.
Sourcepub unsafe fn disconnect(&self) -> bool
pub unsafe fn disconnect(&self) -> bool
Calls C++ function: bool QObject::disconnect() const.
Sourcepub unsafe fn disconnect_q_object(
&self,
receiver: impl CastInto<Ptr<QObject>>,
) -> bool
pub unsafe fn disconnect_q_object( &self, receiver: impl CastInto<Ptr<QObject>>, ) -> bool
Calls C++ function: bool QObject::disconnect(const QObject* receiver) const.
Sourcepub unsafe fn dump_object_info_mut(&self)
pub unsafe fn dump_object_info_mut(&self)
Calls C++ function: void QObject::dumpObjectInfo().
Sourcepub unsafe fn dump_object_info(&self)
pub unsafe fn dump_object_info(&self)
Calls C++ function: void QObject::dumpObjectInfo() const.
Sourcepub unsafe fn dump_object_tree_mut(&self)
pub unsafe fn dump_object_tree_mut(&self)
Calls C++ function: void QObject::dumpObjectTree().
Sourcepub unsafe fn dump_object_tree(&self)
pub unsafe fn dump_object_tree(&self)
Calls C++ function: void QObject::dumpObjectTree() const.
Sourcepub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
pub unsafe fn dynamic_property_names(&self) -> CppBox<QListOfQByteArray>
Calls C++ function: QList<QByteArray> QObject::dynamicPropertyNames() const.
Sourcepub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
pub unsafe fn eq(&self, p: impl CastInto<Ref<QPointerOfQObject>>) -> bool
Calls C++ function: bool operator==(QObject* o, const QPointer<QObject>& p).
Sourcepub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
pub unsafe fn event(&self, event: impl CastInto<Ptr<QEvent>>) -> bool
Calls C++ function: virtual bool QObject::event(QEvent* event).
Sourcepub unsafe fn event_filter(
&self,
watched: impl CastInto<Ptr<QObject>>,
event: impl CastInto<Ptr<QEvent>>,
) -> bool
pub unsafe fn event_filter( &self, watched: impl CastInto<Ptr<QObject>>, event: impl CastInto<Ptr<QEvent>>, ) -> bool
Calls C++ function: virtual bool QObject::eventFilter(QObject* watched, QEvent* event).
Sourcepub unsafe fn find_child_q_object_2a(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_2a( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_child_q_object_1a(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> QPtr<QObject>
pub unsafe fn find_child_q_object_1a( &self, a_name: impl CastInto<Ref<QString>>, ) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
pub unsafe fn find_child_q_object_0a(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::findChild<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_string_q_flags_find_child_option(
&self,
a_name: impl CastInto<Ref<QString>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string_q_flags_find_child_option( &self, a_name: impl CastInto<Ref<QString>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegExp>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegExp>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
options: QFlags<FindChildOption>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression_q_flags_find_child_option( &self, re: impl CastInto<Ref<QRegularExpression>>, options: QFlags<FindChildOption>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re, QFlags<Qt::FindChildOption> options = …) const.
Sourcepub unsafe fn find_children_q_object_q_string(
&self,
a_name: impl CastInto<Ref<QString>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_string( &self, a_name: impl CastInto<Ref<QString>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QString& aName = …) const.
Sourcepub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object(&self) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>() const.
Sourcepub unsafe fn find_children_q_object_q_reg_exp(
&self,
re: impl CastInto<Ref<QRegExp>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_reg_exp( &self, re: impl CastInto<Ref<QRegExp>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegExp& re) const.
Sourcepub unsafe fn find_children_q_object_q_regular_expression(
&self,
re: impl CastInto<Ref<QRegularExpression>>,
) -> CppBox<QListOfQObject>
pub unsafe fn find_children_q_object_q_regular_expression( &self, re: impl CastInto<Ref<QRegularExpression>>, ) -> CppBox<QListOfQObject>
Calls C++ function: QList<QObject*> QObject::findChildren<QObject*>(const QRegularExpression& re) const.
Sourcepub unsafe fn inherits(&self, classname: *const i8) -> bool
pub unsafe fn inherits(&self, classname: *const i8) -> bool
Calls C++ function: bool QObject::inherits(const char* classname) const.
Sourcepub unsafe fn install_event_filter(
&self,
filter_obj: impl CastInto<Ptr<QObject>>,
)
pub unsafe fn install_event_filter( &self, filter_obj: impl CastInto<Ptr<QObject>>, )
Calls C++ function: void QObject::installEventFilter(QObject* filterObj).
Sourcepub unsafe fn is_widget_type(&self) -> bool
pub unsafe fn is_widget_type(&self) -> bool
Calls C++ function: bool QObject::isWidgetType() const.
Sourcepub unsafe fn is_window_type(&self) -> bool
pub unsafe fn is_window_type(&self) -> bool
Calls C++ function: bool QObject::isWindowType() const.
Sourcepub unsafe fn kill_timer(&self, id: i32)
pub unsafe fn kill_timer(&self, id: i32)
Calls C++ function: void QObject::killTimer(int id).
Sourcepub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
pub unsafe fn meta_object(&self) -> Ptr<QMetaObject>
Calls C++ function: virtual const QMetaObject* QObject::metaObject() const.
Sourcepub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
pub unsafe fn move_to_thread(&self, thread: impl CastInto<Ptr<QThread>>)
Calls C++ function: void QObject::moveToThread(QThread* thread).
Sourcepub unsafe fn object_name(&self) -> CppBox<QString>
pub unsafe fn object_name(&self) -> CppBox<QString>
Calls C++ function: QString QObject::objectName() const.
Sourcepub unsafe fn parent(&self) -> QPtr<QObject>
pub unsafe fn parent(&self) -> QPtr<QObject>
Calls C++ function: QObject* QObject::parent() const.
Sourcepub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
pub unsafe fn property(&self, name: *const i8) -> CppBox<QVariant>
Calls C++ function: QVariant QObject::property(const char* name) const.
Sourcepub unsafe fn qt_metacall(
&self,
arg1: Call,
arg2: i32,
arg3: *mut *mut c_void,
) -> i32
pub unsafe fn qt_metacall( &self, arg1: Call, arg2: i32, arg3: *mut *mut c_void, ) -> i32
Calls C++ function: virtual int QObject::qt_metacall(QMetaObject::Call arg1, int arg2, void** arg3).
Sourcepub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
pub unsafe fn qt_metacast(&self, arg1: *const i8) -> *mut c_void
Calls C++ function: virtual void* QObject::qt_metacast(const char* arg1).
Sourcepub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
pub unsafe fn remove_event_filter(&self, obj: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::removeEventFilter(QObject* obj).
Sourcepub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
pub unsafe fn set_object_name(&self, name: impl CastInto<Ref<QString>>)
Calls C++ function: void QObject::setObjectName(const QString& name).
Sourcepub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
pub unsafe fn set_parent(&self, parent: impl CastInto<Ptr<QObject>>)
Calls C++ function: void QObject::setParent(QObject* parent).
Sourcepub unsafe fn set_property(
&self,
name: *const i8,
value: impl CastInto<Ref<QVariant>>,
) -> bool
pub unsafe fn set_property( &self, name: *const i8, value: impl CastInto<Ref<QVariant>>, ) -> bool
Calls C++ function: bool QObject::setProperty(const char* name, const QVariant& value).
Sourcepub unsafe fn signals_blocked(&self) -> bool
pub unsafe fn signals_blocked(&self) -> bool
Calls C++ function: bool QObject::signalsBlocked() const.
Sourcepub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
pub unsafe fn start_timer_2a(&self, interval: i32, timer_type: TimerType) -> i32
Calls C++ function: int QObject::startTimer(int interval, Qt::TimerType timerType = …).
Sourcepub unsafe fn start_timer_1a(&self, interval: i32) -> i32
pub unsafe fn start_timer_1a(&self, interval: i32) -> i32
Calls C++ function: int QObject::startTimer(int interval).